Method: Playwright::BrowserContext#set_extra_http_headers

Defined in:
lib/playwright_api/browser_context.rb

#set_extra_http_headers(headers) ⇒ Object Also known as: extra_http_headers=

The extra HTTP headers will be sent with every request initiated by any page in the context. These headers are merged with page-specific extra HTTP headers set with [‘method: Page.setExtraHTTPHeaders`]. If page overrides a particular header, page-specific header value will be used instead of the browser context header value.

> NOTE: [‘method: BrowserContext.setExtraHTTPHeaders`] does not guarantee the order of headers in the outgoing requests.



322
323
324
# File 'lib/playwright_api/browser_context.rb', line 322

def set_extra_http_headers(headers)
  wrap_impl(@impl.set_extra_http_headers(unwrap_impl(headers)))
end