Method: Playwright::Page#query_selector_all

Defined in:
lib/playwright_api/page.rb

#query_selector_all(selector) ⇒ Object

> NOTE: The use of ElementHandle is discouraged, use Locator objects and web-first assertions instead.

The method finds all elements matching the specified selector within the page. If no elements match the selector, the return value resolves to [].

Shortcut for main frame’s [‘method: Frame.querySelectorAll`].



842
843
844
# File 'lib/playwright_api/page.rb', line 842

def query_selector_all(selector)
  wrap_impl(@impl.query_selector_all(unwrap_impl(selector)))
end