Method: Playwright::Page#select_option

Defined in:
lib/playwright_api/page.rb

#select_option(selector, element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, strict: nil, timeout: nil) ⇒ Object

This method waits for an element matching selector, waits for [actionability](../actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.

If the target element is not a ‘<select>` element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be used instead.

Returns the array of option values that have been successfully selected.

Triggers a change and input event once all the provided options have been selected.

“‘python sync # single selection matching the value page.select_option(“select#colors”, “blue”) # single selection matching both the label page.select_option(“select#colors”, label=“blue”) # multiple selection page.select_option(“select#colors”, value=[“red”, “green”, “blue”]) “`

Shortcut for main frame’s [‘method: Frame.selectOption`].



930
931
932
933
934
935
936
937
938
939
940
941
# File 'lib/playwright_api/page.rb', line 930

def select_option(
      selector,
      element: nil,
      index: nil,
      value: nil,
      label: nil,
      force: nil,
      noWaitAfter: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.select_option(unwrap_impl(selector), element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end