Class: Playwright::AndroidDevice

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/android_device.rb

Overview

AndroidDevice represents a connected device, either real hardware or emulated. Devices can be obtained using [‘method: Android.devices`].

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#closeObject

Disconnects from the device.



11
12
13
# File 'lib/playwright_api/android_device.rb', line 11

def close
  wrap_impl(@impl.close)
end

#drag(selector, dest, speed: nil) ⇒ Object

Drags the widget defined by selector towards dest point.

Raises:

  • (NotImplementedError)


16
17
18
# File 'lib/playwright_api/android_device.rb', line 16

def drag(selector, dest, speed: nil)
  raise NotImplementedError.new('drag is not implemented yet.')
end

#fill(selector, text) ⇒ Object

Fills the specific selector input box with text.

Raises:

  • (NotImplementedError)


21
22
23
# File 'lib/playwright_api/android_device.rb', line 21

def fill(selector, text)
  raise NotImplementedError.new('fill is not implemented yet.')
end

#fling(selector, direction, speed: nil) ⇒ Object

Flings the widget defined by selector in the specified direction.

Raises:

  • (NotImplementedError)


26
27
28
# File 'lib/playwright_api/android_device.rb', line 26

def fling(selector, direction, speed: nil)
  raise NotImplementedError.new('fling is not implemented yet.')
end

#info(selector) ⇒ Object

Returns information about a widget defined by selector.



31
32
33
# File 'lib/playwright_api/android_device.rb', line 31

def info(selector)
  wrap_impl(@impl.info(unwrap_impl(selector)))
end

#inputObject

property



6
7
8
# File 'lib/playwright_api/android_device.rb', line 6

def input # property
  wrap_impl(@impl.input)
end

#install_apk(file, args: nil) ⇒ Object

Installs an apk on the device.

Raises:

  • (NotImplementedError)


36
37
38
# File 'lib/playwright_api/android_device.rb', line 36

def install_apk(file, args: nil)
  raise NotImplementedError.new('install_apk is not implemented yet.')
end

#launch_browser(acceptDownloads: nil, baseURL: nil, bypassCSP: nil, colorScheme: nil, command: nil, deviceScaleFactor: nil, extraHTTPHeaders: nil, geolocation: nil, hasTouch: nil, httpCredentials: nil, ignoreHTTPSErrors: nil, isMobile: nil, javaScriptEnabled: nil, locale: nil, noViewport: nil, offline: nil, permissions: nil, record_har_omit_content: nil, record_har_path: nil, record_video_dir: nil, record_video_size: nil, reducedMotion: nil, screen: nil, timezoneId: nil, userAgent: nil, viewport: nil, &block) ⇒ Object

Launches Chrome browser on the device, and returns its persistent context.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/playwright_api/android_device.rb', line 41

def launch_browser(
      acceptDownloads: nil,
      baseURL: nil,
      bypassCSP: nil,
      colorScheme: nil,
      command: nil,
      deviceScaleFactor: nil,
      extraHTTPHeaders: nil,
      geolocation: nil,
      hasTouch: nil,
      httpCredentials: nil,
      ignoreHTTPSErrors: nil,
      isMobile: nil,
      javaScriptEnabled: nil,
      locale: nil,
      noViewport: nil,
      offline: nil,
      permissions: nil,
      record_har_omit_content: nil,
      record_har_path: nil,
      record_video_dir: nil,
      record_video_size: nil,
      reducedMotion: nil,
      screen: nil,
      timezoneId: nil,
      userAgent: nil,
      viewport: nil,
      &block)
  wrap_impl(@impl.launch_browser(acceptDownloads: unwrap_impl(acceptDownloads), baseURL: unwrap_impl(baseURL), bypassCSP: unwrap_impl(bypassCSP), colorScheme: unwrap_impl(colorScheme), command: unwrap_impl(command), deviceScaleFactor: unwrap_impl(deviceScaleFactor), extraHTTPHeaders: unwrap_impl(extraHTTPHeaders), geolocation: unwrap_impl(geolocation), hasTouch: unwrap_impl(hasTouch), httpCredentials: unwrap_impl(httpCredentials), ignoreHTTPSErrors: unwrap_impl(ignoreHTTPSErrors), isMobile: unwrap_impl(isMobile), javaScriptEnabled: unwrap_impl(javaScriptEnabled), locale: unwrap_impl(locale), noViewport: unwrap_impl(noViewport), offline: unwrap_impl(offline), permissions: unwrap_impl(permissions), record_har_omit_content: unwrap_impl(record_har_omit_content), record_har_path: unwrap_impl(record_har_path), record_video_dir: unwrap_impl(record_video_dir), record_video_size: unwrap_impl(record_video_size), reducedMotion: unwrap_impl(reducedMotion), screen: unwrap_impl(screen), timezoneId: unwrap_impl(timezoneId), userAgent: unwrap_impl(userAgent), viewport: unwrap_impl(viewport), &wrap_block_call(block)))
end

#long_tap(selector) ⇒ Object

Performs a long tap on the widget defined by selector.

Raises:

  • (NotImplementedError)


73
74
75
# File 'lib/playwright_api/android_device.rb', line 73

def long_tap(selector)
  raise NotImplementedError.new('long_tap is not implemented yet.')
end

#modelObject

Device model.



78
79
80
# File 'lib/playwright_api/android_device.rb', line 78

def model
  wrap_impl(@impl.model)
end

#off(event, callback) ⇒ Object

– inherited from EventEmitter –



189
190
191
# File 'lib/playwright_api/android_device.rb', line 189

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

– inherited from EventEmitter –



183
184
185
# File 'lib/playwright_api/android_device.rb', line 183

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

– inherited from EventEmitter –



177
178
179
# File 'lib/playwright_api/android_device.rb', line 177

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#open(command) ⇒ Object

Launches a process in the shell on the device and returns a socket to communicate with the launched process.

Raises:

  • (NotImplementedError)


83
84
85
# File 'lib/playwright_api/android_device.rb', line 83

def open(command)
  raise NotImplementedError.new('open is not implemented yet.')
end

#pinch_close(selector, percent, speed: nil) ⇒ Object

Pinches the widget defined by selector in the closing direction.

Raises:

  • (NotImplementedError)


88
89
90
# File 'lib/playwright_api/android_device.rb', line 88

def pinch_close(selector, percent, speed: nil)
  raise NotImplementedError.new('pinch_close is not implemented yet.')
end

#pinch_open(selector, percent, speed: nil) ⇒ Object

Pinches the widget defined by selector in the open direction.

Raises:

  • (NotImplementedError)


93
94
95
# File 'lib/playwright_api/android_device.rb', line 93

def pinch_open(selector, percent, speed: nil)
  raise NotImplementedError.new('pinch_open is not implemented yet.')
end

#press(selector, key) ⇒ Object

Presses the specific key in the widget defined by selector.

Raises:

  • (NotImplementedError)


98
99
100
# File 'lib/playwright_api/android_device.rb', line 98

def press(selector, key)
  raise NotImplementedError.new('press is not implemented yet.')
end

#push(file, path, mode: nil) ⇒ Object

Copies a file to the device.

Raises:

  • (NotImplementedError)


103
104
105
# File 'lib/playwright_api/android_device.rb', line 103

def push(file, path, mode: nil)
  raise NotImplementedError.new('push is not implemented yet.')
end

#screenshot(path: nil) ⇒ Object

Returns the buffer with the captured screenshot of the device.



108
109
110
# File 'lib/playwright_api/android_device.rb', line 108

def screenshot(path: nil)
  wrap_impl(@impl.screenshot(path: unwrap_impl(path)))
end

#scroll(selector, direction, percent, speed: nil) ⇒ Object

Scrolls the widget defined by selector in the specified direction.

Raises:

  • (NotImplementedError)


113
114
115
# File 'lib/playwright_api/android_device.rb', line 113

def scroll(selector, direction, percent, speed: nil)
  raise NotImplementedError.new('scroll is not implemented yet.')
end

#serialObject

Device serial number.



118
119
120
# File 'lib/playwright_api/android_device.rb', line 118

def serial
  wrap_impl(@impl.serial)
end

#set_default_timeout(timeout) ⇒ Object Also known as: default_timeout=

This setting will change the default maximum time for all the methods accepting timeout option.

Raises:

  • (NotImplementedError)


123
124
125
# File 'lib/playwright_api/android_device.rb', line 123

def set_default_timeout(timeout)
  raise NotImplementedError.new('set_default_timeout is not implemented yet.')
end

#shell(command) ⇒ Object

Executes a shell command on the device and returns its output.



129
130
131
# File 'lib/playwright_api/android_device.rb', line 129

def shell(command)
  wrap_impl(@impl.shell(unwrap_impl(command)))
end

#swipe(selector, direction, percent, speed: nil) ⇒ Object

Swipes the widget defined by selector in the specified direction.

Raises:

  • (NotImplementedError)


134
135
136
# File 'lib/playwright_api/android_device.rb', line 134

def swipe(selector, direction, percent, speed: nil)
  raise NotImplementedError.new('swipe is not implemented yet.')
end

#tap_on(selector, duration: nil, timeout: nil) ⇒ Object



166
167
168
# File 'lib/playwright_api/android_device.rb', line 166

def tap_on(selector, duration: nil, timeout: nil)
  wrap_impl(@impl.tap_on(unwrap_impl(selector), duration: unwrap_impl(duration), timeout: unwrap_impl(timeout)))
end

#tap_point(selector, duration: nil) ⇒ Object

Taps on the widget defined by selector.

Raises:

  • (NotImplementedError)


139
140
141
# File 'lib/playwright_api/android_device.rb', line 139

def tap_point(selector, duration: nil)
  raise NotImplementedError.new('tap_point is not implemented yet.')
end

#treeObject



171
172
173
# File 'lib/playwright_api/android_device.rb', line 171

def tree
  wrap_impl(@impl.tree)
end

#wait(selector, state: nil) ⇒ Object

Waits for the specific selector to either appear or disappear, depending on the state.

Raises:

  • (NotImplementedError)


144
145
146
# File 'lib/playwright_api/android_device.rb', line 144

def wait(selector, state: nil)
  raise NotImplementedError.new('wait is not implemented yet.')
end

#wait_for_event(event, optionsOrPredicate: nil) ⇒ Object

Waits for event to fire and passes its value into the predicate function. Returns when the predicate returns truthy value.

Raises:

  • (NotImplementedError)


150
151
152
# File 'lib/playwright_api/android_device.rb', line 150

def wait_for_event(event, optionsOrPredicate: nil)
  raise NotImplementedError.new('wait_for_event is not implemented yet.')
end

#web_view(selector) ⇒ Object

This method waits until AndroidWebView matching the selector is opened and returns it. If there is already an open AndroidWebView matching the selector, returns immediately.

Raises:

  • (NotImplementedError)


156
157
158
# File 'lib/playwright_api/android_device.rb', line 156

def web_view(selector)
  raise NotImplementedError.new('web_view is not implemented yet.')
end

#web_viewsObject

Currently open WebViews.

Raises:

  • (NotImplementedError)


161
162
163
# File 'lib/playwright_api/android_device.rb', line 161

def web_views
  raise NotImplementedError.new('web_views is not implemented yet.')
end