Class: Playwright::BrowserContext

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/browser_context.rb

Overview

BrowserContexts provide a way to operate multiple independent browser sessions.

If a page opens another page, e.g. with a window.open call, the popup will belong to the parent page’s browser context.

Playwright allows creating isolated non-persistent browser contexts with [‘method: Browser.newContext`] method. Non-persistent browser contexts don’t write any browsing data to disk.

“‘python sync # create a new incognito browser context context = browser.new_context() # create a new page inside context. page = context.new_page() page.goto(“example.com”) # dispose context once it is no longer needed. context.close() “`

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#add_cookies(cookies) ⇒ Object

Adds cookies into this browser context. All pages within this context will have these cookies installed. Cookies can be obtained via [‘method: BrowserContext.cookies`].

Usage

“‘python sync browser_context.add_cookies([cookie_object1, cookie_object2]) “`



53
54
55
# File 'lib/playwright_api/browser_context.rb', line 53

def add_cookies(cookies)
  wrap_impl(@impl.add_cookies(unwrap_impl(cookies)))
end

#add_init_script(path: nil, script: nil) ⇒ Object

Adds a script which would be evaluated in one of the following scenarios:

  • Whenever a page is created in the browser context or is navigated.

  • Whenever a child frame is attached or navigated in any page in the browser context. In this case, the script is evaluated in the context of the newly attached frame.

The script is evaluated after the document was created but before any of its scripts were run. This is useful to amend the JavaScript environment, e.g. to seed Math.random.

Usage

An example of overriding Math.random before the page loads:

“‘python sync # in your playwright script, assuming the preload.js file is in same directory. browser_context.add_init_script(path=“preload.js”) “`

NOTE: The order of evaluation of multiple scripts installed via [‘method: BrowserContext.addInitScript`] and

‘method: Page.addInitScript`

is not defined.



76
77
78
# File 'lib/playwright_api/browser_context.rb', line 76

def add_init_script(path: nil, script: nil)
  wrap_impl(@impl.add_init_script(path: unwrap_impl(path), script: unwrap_impl(script)))
end

#background_pagesObject

Deprecated.

Background pages have been removed from Chromium together with Manifest V2 extensions.

Returns an empty list.



84
85
86
# File 'lib/playwright_api/browser_context.rb', line 84

def background_pages
  wrap_impl(@impl.background_pages)
end

#browserObject

Gets the browser instance that owns the context. Returns null if the context is created outside of normal browser, e.g. Android or Electron.



90
91
92
# File 'lib/playwright_api/browser_context.rb', line 90

def browser
  wrap_impl(@impl.browser)
end

#browser=(req) ⇒ Object



513
514
515
# File 'lib/playwright_api/browser_context.rb', line 513

def browser=(req)
  wrap_impl(@impl.browser=(unwrap_impl(req)))
end

#clear_cookies(domain: nil, name: nil, path: nil) ⇒ Object

Removes cookies from context. Accepts optional filter.

Usage

“‘python sync context.clear_cookies() context.clear_cookies(name=“session-id”) context.clear_cookies(domain=“my-origin.com”) context.clear_cookies(path=“/api/v1”) context.clear_cookies(name=“session-id”, domain=“my-origin.com”) “`



106
107
108
# File 'lib/playwright_api/browser_context.rb', line 106

def clear_cookies(domain: nil, name: nil, path: nil)
  wrap_impl(@impl.clear_cookies(domain: unwrap_impl(domain), name: unwrap_impl(name), path: unwrap_impl(path)))
end

#clear_permissionsObject

Clears all permission overrides for the browser context.

Usage

“‘python sync context = browser.new_context() context.grant_permissions([“clipboard-read”]) # do stuff .. context.clear_permissions() “`



121
122
123
# File 'lib/playwright_api/browser_context.rb', line 121

def clear_permissions
  wrap_impl(@impl.clear_permissions)
end

#clockObject

Playwright has ability to mock clock and passage of time.



24
25
26
# File 'lib/playwright_api/browser_context.rb', line 24

def clock # property
  wrap_impl(@impl.clock)
end

#close(reason: nil) ⇒ Object

Closes the browser context. All the pages that belong to the browser context will be closed.

NOTE: The default browser context cannot be closed.



129
130
131
# File 'lib/playwright_api/browser_context.rb', line 129

def close(reason: nil)
  wrap_impl(@impl.close(reason: unwrap_impl(reason)))
end

#closed?Boolean

Indicates that the browser context is in the process of closing or has already been closed.

Returns:

  • (Boolean)


237
238
239
# File 'lib/playwright_api/browser_context.rb', line 237

def closed?
  wrap_impl(@impl.closed?)
end

#cookies(urls: nil) ⇒ Object

If no URLs are specified, this method returns all cookies. If URLs are specified, only cookies that affect those URLs are returned.



136
137
138
# File 'lib/playwright_api/browser_context.rb', line 136

def cookies(urls: nil)
  wrap_impl(@impl.cookies(urls: unwrap_impl(urls)))
end

#debuggerObject

Debugger allows to pause and resume the execution.

Raises:

  • (NotImplementedError)


30
31
32
# File 'lib/playwright_api/browser_context.rb', line 30

def debugger # property
  raise NotImplementedError.new('debugger is not implemented yet.')
end

#enable_debug_console!Object



493
494
495
# File 'lib/playwright_api/browser_context.rb', line 493

def enable_debug_console!
  wrap_impl(@impl.enable_debug_console!)
end

#expect_console_message(predicate: nil, timeout: nil, &block) ⇒ Object

Performs action and waits for a ConsoleMessage to be logged by in the pages in the context. If predicate is provided, it passes ConsoleMessage value into the predicate function and waits for ‘predicate(message)` to return a truthy value. Will throw an error if the page is closed before the [`event: BrowserContext.console`] event is fired.



455
456
457
# File 'lib/playwright_api/browser_context.rb', line 455

def expect_console_message(predicate: nil, timeout: nil, &block)
  wrap_impl(@impl.expect_console_message(predicate: unwrap_impl(predicate), timeout: unwrap_impl(timeout), &wrap_block_call(block)))
end

#expect_event(event, predicate: nil, timeout: nil, &block) ⇒ Object

Waits for event to fire and passes its value into the predicate function. Returns when the predicate returns truthy value. Will throw an error if the context closes before the event is fired. Returns the event data value.

Usage

“‘python sync with context.expect_event(“page”) as event_info:

page.get_by_role("button").click()

page = event_info.value “‘



470
471
472
# File 'lib/playwright_api/browser_context.rb', line 470

def expect_event(event, predicate: nil, timeout: nil, &block)
  wrap_impl(@impl.expect_event(unwrap_impl(event), predicate: unwrap_impl(predicate), timeout: unwrap_impl(timeout), &wrap_block_call(block)))
end

#expect_page(predicate: nil, timeout: nil, &block) ⇒ Object

Performs action and waits for a new Page to be created in the context. If predicate is provided, it passes Page value into the predicate function and waits for ‘predicate(event)` to return a truthy value. Will throw an error if the context closes before new Page is created.



478
479
480
# File 'lib/playwright_api/browser_context.rb', line 478

def expect_page(predicate: nil, timeout: nil, &block)
  wrap_impl(@impl.expect_page(predicate: unwrap_impl(predicate), timeout: unwrap_impl(timeout), &wrap_block_call(block)))
end

#expose_binding(name, callback, handle: nil) ⇒ Object

The method adds a function called name on the window object of every frame in every page in the context. When called, the function executes callback and returns a [Promise] which resolves to the return value of callback. If the callback returns a [Promise], it will be awaited.

The first argument of the callback function contains information about the caller: ‘{ browserContext: BrowserContext, page: Page, frame: Frame }`.

See [‘method: Page.exposeBinding`] for page-only version.

Usage

An example of exposing page URL to all frames in all pages in the context:

“‘python sync from playwright.sync_api import sync_playwright, Playwright

def run(playwright: Playwright):

webkit = playwright.webkit
browser = webkit.launch(headless=False)
context = browser.new_context()
context.expose_binding("pageURL", lambda source: source["page"].url)
page = context.new_page()
page.set_content("""
<script>
  async function onClick() {
    document.querySelector('div').textContent = await window.pageURL();
  }
</script>
<button onclick="onClick()">Click me</button>
<div></div>
""")
page.get_by_role("button").click()

with sync_playwright() as playwright:

run(playwright)

“‘



177
178
179
# File 'lib/playwright_api/browser_context.rb', line 177

def expose_binding(name, callback, handle: nil)
  wrap_impl(@impl.expose_binding(unwrap_impl(name), unwrap_impl(callback), handle: unwrap_impl(handle)))
end

#expose_function(name, callback) ⇒ Object

The method adds a function called name on the window object of every frame in every page in the context. When called, the function executes callback and returns a [Promise] which resolves to the return value of callback.

If the callback returns a [Promise], it will be awaited.

See [‘method: Page.exposeFunction`] for page-only version.

Usage

An example of adding a sha256 function to all pages in the context:

“‘python sync import hashlib from playwright.sync_api import sync_playwright

def sha256(text: str) -> str:

m = hashlib.sha256()
m.update(bytes(text, "utf8"))
return m.hexdigest()

def run(playwright: Playwright):

webkit = playwright.webkit
browser = webkit.launch(headless=False)
context = browser.new_context()
context.expose_function("sha256", sha256)
page = context.new_page()
page.set_content("""
    <script>
      async function onClick() {
        document.querySelector('div').textContent = await window.sha256('PLAYWRIGHT');
      }
    </script>
    <button onclick="onClick()">Click me</button>
    <div></div>
""")
page.get_by_role("button").click()

with sync_playwright() as playwright:

run(playwright)

“‘



224
225
226
# File 'lib/playwright_api/browser_context.rb', line 224

def expose_function(name, callback)
  wrap_impl(@impl.expose_function(unwrap_impl(name), unwrap_impl(callback)))
end

#grant_permissions(permissions, origin: nil) ⇒ Object

Grants specified permissions to the browser context. Only grants corresponding permissions to the given origin if specified.



231
232
233
# File 'lib/playwright_api/browser_context.rb', line 231

def grant_permissions(permissions, origin: nil)
  wrap_impl(@impl.grant_permissions(unwrap_impl(permissions), origin: unwrap_impl(origin)))
end

#new_cdp_session(page) ⇒ Object

NOTE: CDP sessions are only supported on Chromium-based browsers.

Returns the newly created session.



245
246
247
# File 'lib/playwright_api/browser_context.rb', line 245

def new_cdp_session(page)
  wrap_impl(@impl.new_cdp_session(unwrap_impl(page)))
end

#new_page(&block) ⇒ Object

Creates a new page in the browser context.



251
252
253
# File 'lib/playwright_api/browser_context.rb', line 251

def new_page(&block)
  wrap_impl(@impl.new_page(&wrap_block_call(block)))
end

#off(event, callback) ⇒ Object

– inherited from EventEmitter –



525
526
527
# File 'lib/playwright_api/browser_context.rb', line 525

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

– inherited from EventEmitter –



519
520
521
# File 'lib/playwright_api/browser_context.rb', line 519

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

– inherited from EventEmitter –



531
532
533
# File 'lib/playwright_api/browser_context.rb', line 531

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#options=(req) ⇒ Object



508
509
510
# File 'lib/playwright_api/browser_context.rb', line 508

def options=(req)
  wrap_impl(@impl.options=(unwrap_impl(req)))
end

#owner_page=(req) ⇒ Object



503
504
505
# File 'lib/playwright_api/browser_context.rb', line 503

def owner_page=(req)
  wrap_impl(@impl.owner_page=(unwrap_impl(req)))
end

#pagesObject

Returns all open pages in the context.



257
258
259
# File 'lib/playwright_api/browser_context.rb', line 257

def pages
  wrap_impl(@impl.pages)
end

#pauseObject



498
499
500
# File 'lib/playwright_api/browser_context.rb', line 498

def pause
  wrap_impl(@impl.pause)
end

#requestObject

API testing helper associated with this context. Requests made with this API will use context cookies.



36
37
38
# File 'lib/playwright_api/browser_context.rb', line 36

def request # property
  wrap_impl(@impl.request)
end

#route(url, handler, times: nil) ⇒ Object

Routing provides the capability to modify network requests that are made by any page in the browser context. Once route is enabled, every request matching the url pattern will stall unless it’s continued, fulfilled or aborted.

NOTE: [‘method: BrowserContext.route`] will not intercept requests intercepted by Service Worker. See [this](github.com/microsoft/playwright/issues/1090) issue. We recommend disabling Service Workers when using request interception by setting serviceWorkers to `’block’‘.

Usage

An example of a naive handler that aborts all image requests:

“‘python sync context = browser.new_context() page = context.new_page() context.route(“**/*.png,jpg,jpeg”, lambda route: route.abort()) page.goto(“example.com”) browser.close() “`

or the same snippet using a regex pattern instead:

“‘python sync context = browser.new_context() page = context.new_page() context.route(re.compile(r“(\.png$)|(\.jpg$)”), lambda route: route.abort()) page = await context.new_page() page = context.new_page() page.goto(“example.com”) browser.close() “`

It is possible to examine the request to decide the route action. For example, mocking all requests that contain some post data, and leaving all other requests as is:

“‘python sync def handle_route(route: Route):

if ("my-string" in route.request.post_data):
  route.fulfill(body="mocked-data")
else:
  route.continue_()

context.route(“/api/**”, handle_route) “‘

Page routes (set up with [‘method: Page.route`]) take precedence over browser context routes when request matches both handlers.

To remove a route with its handler you can use [‘method: BrowserContext.unroute`].

NOTE: Enabling routing disables http cache.



308
309
310
# File 'lib/playwright_api/browser_context.rb', line 308

def route(url, handler, times: nil)
  wrap_impl(@impl.route(unwrap_impl(url), unwrap_impl(handler), times: unwrap_impl(times)))
end

#route_from_har(har, notFound: nil, update: nil, updateContent: nil, updateMode: nil, url: nil) ⇒ Object

If specified the network requests that are made in the context will be served from the HAR file. Read more about [Replaying from HAR](../mock.md#replaying-from-har).

Playwright will not serve requests intercepted by Service Worker from the HAR file. See [this](github.com/microsoft/playwright/issues/1090) issue. We recommend disabling Service Workers when using request interception by setting serviceWorkers to ‘’block’‘.



316
317
318
319
320
321
322
323
324
# File 'lib/playwright_api/browser_context.rb', line 316

def route_from_har(
      har,
      notFound: nil,
      update: nil,
      updateContent: nil,
      updateMode: nil,
      url: nil)
  wrap_impl(@impl.route_from_har(unwrap_impl(har), notFound: unwrap_impl(notFound), update: unwrap_impl(update), updateContent: unwrap_impl(updateContent), updateMode: unwrap_impl(updateMode), url: unwrap_impl(url)))
end

#route_web_socket(url, handler) ⇒ Object

This method allows to modify websocket connections that are made by any page in the browser context.

Note that only ‘WebSocket`s created after this method was called will be routed. It is recommended to call this method before creating any pages.

Usage

Below is an example of a simple handler that blocks some websocket messages. See WebSocketRoute for more details and examples.

“‘python sync def message_handler(ws: WebSocketRoute, message: Union[str, bytes]):

if message == "to-be-blocked":
  return
ws.send(message)

def handler(ws: WebSocketRoute):

ws.route_send(lambda message: message_handler(ws, message))
ws.connect()

context.route_web_socket(“/ws”, handler) “‘

Raises:

  • (NotImplementedError)


348
349
350
# File 'lib/playwright_api/browser_context.rb', line 348

def route_web_socket(url, handler)
  raise NotImplementedError.new('route_web_socket is not implemented yet.')
end

#service_workersObject

NOTE: Service workers are only supported on Chromium-based browsers.

All existing service workers in the context.



356
357
358
# File 'lib/playwright_api/browser_context.rb', line 356

def service_workers
  wrap_impl(@impl.service_workers)
end

#set_default_navigation_timeout(timeout) ⇒ Object Also known as: default_navigation_timeout=

This setting will change the default maximum navigation time for the following methods and related shortcuts:

  • ‘method: Page.goBack`
  • ‘method: Page.goForward`
  • ‘method: Page.goto`
  • ‘method: Page.reload`
  • ‘method: Page.setContent`
  • ‘method: Page.waitForNavigation`

NOTE: [‘method: Page.setDefaultNavigationTimeout`] and [`method: Page.setDefaultTimeout`] take priority over [`method: BrowserContext.setDefaultNavigationTimeout`].



371
372
373
# File 'lib/playwright_api/browser_context.rb', line 371

def set_default_navigation_timeout(timeout)
  wrap_impl(@impl.set_default_navigation_timeout(unwrap_impl(timeout)))
end

#set_default_timeout(timeout) ⇒ Object Also known as: default_timeout=

This setting will change the default maximum time for all the methods accepting timeout option.

NOTE: [‘method: Page.setDefaultNavigationTimeout`], [`method: Page.setDefaultTimeout`] and

‘method: BrowserContext.setDefaultNavigationTimeout`

take priority over [‘method: BrowserContext.setDefaultTimeout`].



381
382
383
# File 'lib/playwright_api/browser_context.rb', line 381

def set_default_timeout(timeout)
  wrap_impl(@impl.set_default_timeout(unwrap_impl(timeout)))
end

#set_extra_http_headers(headers) ⇒ Object Also known as: extra_http_headers=

The extra HTTP headers will be sent with every request initiated by any page in the context. These headers are merged with page-specific extra HTTP headers set with [‘method: Page.setExtraHTTPHeaders`]. If page overrides a particular header, page-specific header value will be used instead of the browser context header value.

NOTE: [‘method: BrowserContext.setExtraHTTPHeaders`] does not guarantee the order of headers in the outgoing requests.



392
393
394
# File 'lib/playwright_api/browser_context.rb', line 392

def set_extra_http_headers(headers)
  wrap_impl(@impl.set_extra_http_headers(unwrap_impl(headers)))
end

#set_geolocation(geolocation) ⇒ Object Also known as: geolocation=

Sets the context’s geolocation. Passing null or undefined emulates position unavailable.

Usage

“‘python sync browser_context.set_geolocation(59.95, “longitude”: 30.31667) “`

NOTE: Consider using [‘method: BrowserContext.grantPermissions`] to grant permissions for the browser context pages to read its geolocation.



408
409
410
# File 'lib/playwright_api/browser_context.rb', line 408

def set_geolocation(geolocation)
  wrap_impl(@impl.set_geolocation(unwrap_impl(geolocation)))
end

#set_offline(offline) ⇒ Object Also known as: offline=



413
414
415
# File 'lib/playwright_api/browser_context.rb', line 413

def set_offline(offline)
  wrap_impl(@impl.set_offline(unwrap_impl(offline)))
end

#set_storage_state(storageState) ⇒ Object Also known as: storage_state=

Clears the existing cookies, local storage and IndexedDB entries for all origins and sets the new storage state.

Usage

“‘python sync # Load storage state from a file and apply it to the context. context.set_storage_state(“state.json”) “`



433
434
435
# File 'lib/playwright_api/browser_context.rb', line 433

def set_storage_state(storageState)
  wrap_impl(@impl.set_storage_state(unwrap_impl(storageState)))
end

#storage_state(indexedDB: nil, path: nil) ⇒ Object

Returns storage state for this browser context, contains current cookies, local storage snapshot and IndexedDB snapshot.



420
421
422
# File 'lib/playwright_api/browser_context.rb', line 420

def storage_state(indexedDB: nil, path: nil)
  wrap_impl(@impl.storage_state(indexedDB: unwrap_impl(indexedDB), path: unwrap_impl(path)))
end

#tracingObject

property



40
41
42
# File 'lib/playwright_api/browser_context.rb', line 40

def tracing # property
  wrap_impl(@impl.tracing)
end

#unroute(url, handler: nil) ⇒ Object

Removes a route created with [‘method: BrowserContext.route`]. When handler is not specified, removes all routes for the url.



447
448
449
# File 'lib/playwright_api/browser_context.rb', line 447

def unroute(url, handler: nil)
  wrap_impl(@impl.unroute(unwrap_impl(url), handler: unwrap_impl(handler)))
end

#unroute_all(behavior: nil) ⇒ Object

Removes all routes created with [‘method: BrowserContext.route`] and [`method: BrowserContext.routeFromHAR`].



440
441
442
# File 'lib/playwright_api/browser_context.rb', line 440

def unroute_all(behavior: nil)
  wrap_impl(@impl.unroute_all(behavior: unwrap_impl(behavior)))
end

#wait_for_event(event, predicate: nil, timeout: nil) ⇒ Object

NOTE: In most cases, you should use [‘method: BrowserContext.waitForEvent`].

Waits for given event to fire. If predicate is provided, it passes event’s value into the predicate function and waits for ‘predicate(event)` to return a truthy value. Will throw an error if the browser context is closed before the event is fired.

Raises:

  • (NotImplementedError)


488
489
490
# File 'lib/playwright_api/browser_context.rb', line 488

def wait_for_event(event, predicate: nil, timeout: nil)
  raise NotImplementedError.new('wait_for_event is not implemented yet.')
end