Class: Playwright::Download
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Download
- Defined in:
- lib/playwright_api/download.rb,
sig/playwright.rbs
Overview
Download objects are dispatched by page via the [event: Page.download] event.
All the downloaded files belonging to the browser context are deleted when the browser context is closed.
Download event is emitted once the download starts. Download path becomes available once download completes.
# Start waiting for the download
with page.expect_download() as download_info:
# Perform the action that initiates download
page.get_by_text("Download file").click()
download = download_info.value
# Wait for the download process to complete and save the downloaded file somewhere
download.save_as("/path/to/save/at/" + download.suggested_filename)
Instance Method Summary collapse
-
#cancel ⇒ void
Cancels a download.
-
#delete ⇒ void
Deletes the downloaded file.
-
#failure ⇒ nil, String
Returns download error if any.
-
#page ⇒ Page
Get the page that the download belongs to.
-
#path ⇒ String, File
Returns path to the downloaded file for a successful download, or throws for a failed/canceled download.
-
#save_as(path) ⇒ void
Copy the download to a user-specified path.
-
#suggested_filename ⇒ String
Returns suggested filename for this download.
-
#url ⇒ String
Returns downloaded url.
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#cancel ⇒ void
This method returns an undefined value.
Cancels a download. Will not fail if the download is already finished or canceled.
Upon successful cancellations, download.failure() would resolve to 'canceled'.
25 26 27 |
# File 'lib/playwright_api/download.rb', line 25 def cancel wrap_impl(@impl.cancel) end |
#delete ⇒ void
This method returns an undefined value.
Deletes the downloaded file. Will wait for the download to finish if necessary.
31 32 33 |
# File 'lib/playwright_api/download.rb', line 31 def delete wrap_impl(@impl.delete) end |
#failure ⇒ nil, String
Returns download error if any. Will wait for the download to finish if necessary.
37 38 39 |
# File 'lib/playwright_api/download.rb', line 37 def failure wrap_impl(@impl.failure) end |
#page ⇒ Page
Get the page that the download belongs to.
43 44 45 |
# File 'lib/playwright_api/download.rb', line 43 def page wrap_impl(@impl.page) end |
#path ⇒ String, File
Returns path to the downloaded file for a successful download, or throws for a failed/canceled download. The method will wait for the download to finish if necessary. The method throws when connected remotely.
Note that the download's file name is a random GUID, use [method: Download.suggestedFilename]
to get suggested file name.
52 53 54 |
# File 'lib/playwright_api/download.rb', line 52 def path wrap_impl(@impl.path) end |
#save_as(path) ⇒ void
This method returns an undefined value.
Copy the download to a user-specified path. It is safe to call this method while the download is still in progress. Will wait for the download to finish if necessary.
Usage
download.save_as("/path/to/save/at/" + download.suggested_filename)
65 66 67 |
# File 'lib/playwright_api/download.rb', line 65 def save_as(path) wrap_impl(@impl.save_as(unwrap_impl(path))) end |
#suggested_filename ⇒ String
Returns suggested filename for this download. It is typically computed by the browser from the
Content-Disposition response header
or the download attribute. See the spec on whatwg. Different
browsers can use different logic for computing it.
74 75 76 |
# File 'lib/playwright_api/download.rb', line 74 def suggested_filename wrap_impl(@impl.suggested_filename) end |
#url ⇒ String
Returns downloaded url.
80 81 82 |
# File 'lib/playwright_api/download.rb', line 80 def url wrap_impl(@impl.url) end |