Class: Playwright::ElementHandle

Inherits:
JSHandle show all
Defined in:
lib/playwright_api/element_handle.rb,
sig/playwright.rbs

Overview

  • extends: JSHandle

ElementHandle represents an in-page DOM element. ElementHandles can be created with the [method: Page.querySelector] method.

NOTE: The use of ElementHandle is discouraged, use Locator objects and web-first assertions instead.

href_element = page.query_selector("a")
href_element.click()

ElementHandle prevents DOM element from garbage collection unless the handle is disposed with [method: JSHandle.dispose]. ElementHandles are auto-disposed when their origin frame gets navigated.

ElementHandle instances can be used as an argument in [method: Page.evalOnSelector] and [method: Page.evaluate] methods.

The difference between the Locator and ElementHandle is that the ElementHandle points to a particular element, while Locator captures the logic of how to retrieve an element.

In the example below, handle points to a particular DOM element on page. If that element changes text or is used by React to render an entirely different component, handle is still pointing to that very DOM element. This can lead to unexpected behaviors.

handle = page.query_selector("text=Submit")
handle.hover()
handle.click()

With the locator, every time the element is used, up-to-date DOM element is located in the page using the selector. So in the snippet below, underlying DOM element is going to be located twice.

locator = page.get_by_text("Submit")
locator.hover()
locator.click()

Instance Method Summary collapse

Methods inherited from JSHandle

#as_element, #dispose, #evaluate, #evaluate_handle, #get_properties, #get_property, #json_value, #to_s

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#bounding_boxnil, Hash[untyped, untyped]

This method returns the bounding box of the element, or null if the element is not visible. The bounding box is calculated relative to the main frame viewport - which is usually the same as the browser window.

Scrolling affects the returned bounding box, similarly to Element.getBoundingClientRect. That means x and/or y may be negative.

Elements from child frames return the bounding box relative to the main frame, unlike the Element.getBoundingClientRect.

Assuming the page is static, it is safe to use bounding box coordinates to perform input. For example, the following snippet should click the center of the element.

Usage

box = element_handle.bounding_box()
page.mouse.click(box["x"] + box["width"] / 2, box["y"] + box["height"] / 2)

Returns:

  • (nil, Hash[untyped, untyped])


59
60
61
# File 'lib/playwright_api/element_handle.rb', line 59

def bounding_box
  wrap_impl(@impl.bounding_box)
end

#check(force: nil, noWaitAfter: nil, position: nil, scroll: nil, timeout: nil, trial: nil) ⇒ void

This method returns an undefined value.

This method checks the element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.
  2. Wait for actionability checks on the element, unless force option is set.
  3. Scroll the element into view if needed.
  4. Use [property: Page.mouse] to click in the center of the element.
  5. Ensure that the element is now checked. If not, this method throws.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

Parameters:

  • force: (Boolean) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


75
76
77
78
79
80
81
82
83
# File 'lib/playwright_api/element_handle.rb', line 75

def check(
      force: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.check(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#checked?Boolean

Returns whether the element is checked. Throws if the element is not a checkbox or radio input.

Returns:

  • (Boolean)


294
295
296
# File 'lib/playwright_api/element_handle.rb', line 294

def checked?
  wrap_impl(@impl.checked?)
end

#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, scroll: nil, steps: nil, timeout: nil, trial: nil) ⇒ void

This method returns an undefined value.

This method clicks the element by performing the following steps:

  1. Wait for actionability checks on the element, unless force option is set.
  2. Scroll the element into view if needed.
  3. Use [property: Page.mouse] to click in the center of the element, or the specified position.
  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

Parameters:

  • button: ("left", "right", "middle") (defaults to: nil)
  • clickCount: (Integer) (defaults to: nil)
  • delay: (Float) (defaults to: nil)
  • force: (Boolean) (defaults to: nil)
  • modifiers: (Array[untyped]) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • steps: (Integer) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/playwright_api/element_handle.rb', line 96

def click(
      button: nil,
      clickCount: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      steps: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.click(button: unwrap_impl(button), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), steps: unwrap_impl(steps), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#content_framenil, Frame

Returns the content frame for element handles referencing iframe nodes, or null otherwise

Returns:



113
114
115
# File 'lib/playwright_api/element_handle.rb', line 113

def content_frame
  wrap_impl(@impl.content_frame)
end

#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, scroll: nil, steps: nil, timeout: nil, trial: nil) ⇒ void

This method returns an undefined value.

This method double clicks the element by performing the following steps:

  1. Wait for actionability checks on the element, unless force option is set.
  2. Scroll the element into view if needed.
  3. Use [property: Page.mouse] to double click in the center of the element, or the specified position.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

NOTE: elementHandle.dblclick() dispatches two click events and a single dblclick event.

Parameters:

  • button: ("left", "right", "middle") (defaults to: nil)
  • delay: (Float) (defaults to: nil)
  • force: (Boolean) (defaults to: nil)
  • modifiers: (Array[untyped]) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • steps: (Integer) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


129
130
131
132
133
134
135
136
137
138
139
140
141
# File 'lib/playwright_api/element_handle.rb', line 129

def dblclick(
      button: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      steps: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.dblclick(button: unwrap_impl(button), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), steps: unwrap_impl(steps), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#disabled?Boolean

Returns whether the element is disabled, the opposite of enabled.

Returns:

  • (Boolean)


300
301
302
# File 'lib/playwright_api/element_handle.rb', line 300

def disabled?
  wrap_impl(@impl.disabled?)
end

#dispatch_event(type, eventInit: nil) ⇒ void

This method returns an undefined value.

The snippet below dispatches the click event on the element. Regardless of the visibility state of the element, click is dispatched. This is equivalent to calling element.click().

Usage

element_handle.dispatch_event("click")

Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.

Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:

You can also specify JSHandle as the property value if you want live objects to be passed into the event:

# note you can only create data_transfer in chromium and firefox
data_transfer = page.evaluate_handle("new DataTransfer()")
element_handle.dispatch_event("#source", "dragstart", {"dataTransfer": data_transfer})

Parameters:

  • type_ (String)
  • eventInit: (Object) (defaults to: nil)


178
179
180
# File 'lib/playwright_api/element_handle.rb', line 178

def dispatch_event(type, eventInit: nil)
  wrap_impl(@impl.dispatch_event(unwrap_impl(type), eventInit: unwrap_impl(eventInit)))
end

#editable?Boolean

Returns whether the element is editable.

Returns:

  • (Boolean)


306
307
308
# File 'lib/playwright_api/element_handle.rb', line 306

def editable?
  wrap_impl(@impl.editable?)
end

#enabled?Boolean

Returns whether the element is enabled.

Returns:

  • (Boolean)


312
313
314
# File 'lib/playwright_api/element_handle.rb', line 312

def enabled?
  wrap_impl(@impl.enabled?)
end

#eval_on_selector(selector, expression, arg: nil) ⇒ Object

Returns the return value of expression.

The method finds an element matching the specified selector in the ElementHandles subtree and passes it as a first argument to expression. If no elements match the selector, the method throws an error.

If expression returns a [Promise], then [method: ElementHandle.evalOnSelector] would wait for the promise to resolve and return its value.

Usage

tweet_handle = page.query_selector(".tweet")
assert tweet_handle.eval_on_selector(".like", "node => node.innerText") == "100"
assert tweet_handle.eval_on_selector(".retweets", "node => node.innerText") == "10"

Parameters:

  • selector (String)
  • expression (String)
  • arg: (Object) (defaults to: nil)

Returns:

  • (Object)


198
199
200
# File 'lib/playwright_api/element_handle.rb', line 198

def eval_on_selector(selector, expression, arg: nil)
  wrap_impl(@impl.eval_on_selector(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#eval_on_selector_all(selector, expression, arg: nil) ⇒ Object

Returns the return value of expression.

The method finds all elements matching the specified selector in the ElementHandle's subtree and passes an array of matched elements as a first argument to expression.

If expression returns a [Promise], then [method: ElementHandle.evalOnSelectorAll] would wait for the promise to resolve and return its value.

Usage

<div class="feed">
  <div class="tweet">Hello!</div>
  <div class="tweet">Hi!</div>
</div>
feed_handle = page.query_selector(".feed")
assert feed_handle.eval_on_selector_all(".tweet", "nodes => nodes.map(n => n.innerText)") == ["hello!", "hi!"]

Parameters:

  • selector (String)
  • expression (String)
  • arg: (Object) (defaults to: nil)

Returns:

  • (Object)


224
225
226
# File 'lib/playwright_api/element_handle.rb', line 224

def eval_on_selector_all(selector, expression, arg: nil)
  wrap_impl(@impl.eval_on_selector_all(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ void

This method returns an undefined value.

This method waits for actionability checks, focuses the element, fills it and triggers an input event after filling. Note that you can pass an empty string to clear the input field.

If the target element is not an <input>, <textarea> or [contenteditable] element, this method throws an error. However, if the element is inside the <label> element that has an associated control, the control will be filled instead.

To send fine-grained keyboard events, use [method: Locator.pressSequentially].

Parameters:

  • value (String)
  • force: (Boolean) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)


234
235
236
# File 'lib/playwright_api/element_handle.rb', line 234

def fill(value, force: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.fill(unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#focusvoid

This method returns an undefined value.

Calls focus on the element.



240
241
242
# File 'lib/playwright_api/element_handle.rb', line 240

def focus
  wrap_impl(@impl.focus)
end

#get_attribute(name) ⇒ nil, String Also known as: []

Returns element attribute value.

Parameters:

  • name (String)

Returns:

  • (nil, String)


246
247
248
# File 'lib/playwright_api/element_handle.rb', line 246

def get_attribute(name)
  wrap_impl(@impl.get_attribute(unwrap_impl(name)))
end

#hidden?Boolean

Returns whether the element is hidden, the opposite of visible.

Returns:

  • (Boolean)


318
319
320
# File 'lib/playwright_api/element_handle.rb', line 318

def hidden?
  wrap_impl(@impl.hidden?)
end

#hover(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, scroll: nil, timeout: nil, trial: nil) ⇒ void

This method returns an undefined value.

This method hovers over the element by performing the following steps:

  1. Wait for actionability checks on the element, unless force option is set.
  2. Scroll the element into view if needed.
  3. Use [property: Page.mouse] to hover over the center of the element, or the specified position.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

Parameters:

  • force: (Boolean) (defaults to: nil)
  • modifiers: (Array[untyped]) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


261
262
263
264
265
266
267
268
269
270
# File 'lib/playwright_api/element_handle.rb', line 261

def hover(
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.hover(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#inner_htmlString

Returns the element.innerHTML.

Returns:

  • (String)


274
275
276
# File 'lib/playwright_api/element_handle.rb', line 274

def inner_html
  wrap_impl(@impl.inner_html)
end

#inner_textString

Returns the element.innerText.

Returns:

  • (String)


280
281
282
# File 'lib/playwright_api/element_handle.rb', line 280

def inner_text
  wrap_impl(@impl.inner_text)
end

#input_value(timeout: nil) ⇒ String

Returns input.value for the selected <input> or <textarea> or <select> element.

Throws for non-input elements. However, if the element is inside the <label> element that has an associated control, returns the value of the control.

Parameters:

  • timeout: (Float) (defaults to: nil)

Returns:

  • (String)


288
289
290
# File 'lib/playwright_api/element_handle.rb', line 288

def input_value(timeout: nil)
  wrap_impl(@impl.input_value(timeout: unwrap_impl(timeout)))
end

#off(event, callback) ⇒ Object

-- inherited from EventEmitter --



598
599
600
# File 'lib/playwright_api/element_handle.rb', line 598

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

-- inherited from EventEmitter --



592
593
594
# File 'lib/playwright_api/element_handle.rb', line 592

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

-- inherited from EventEmitter --



586
587
588
# File 'lib/playwright_api/element_handle.rb', line 586

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#owner_framenil, Frame

Returns the frame containing the given element.

Returns:



330
331
332
# File 'lib/playwright_api/element_handle.rb', line 330

def owner_frame
  wrap_impl(@impl.owner_frame)
end

#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ void

This method returns an undefined value.

Focuses the element, and then uses [method: Keyboard.down] and [method: Keyboard.up].

key can specify the intended keyboardEvent.key value or a single character to generate the text for. A superset of the key values can be found here. Examples of the keys are:

F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.

Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft, ControlOrMeta.

Holding down Shift will type the text that corresponds to the key in the upper case.

If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.

Shortcuts such as key: "Control+o", key: "Control++ or key: "Control+Shift+T" are supported as well. When specified with the modifier, modifier is pressed and being held while the subsequent key is being pressed.

Parameters:

  • key (String)
  • delay: (Float) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)


354
355
356
# File 'lib/playwright_api/element_handle.rb', line 354

def press(key, delay: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.press(unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#query_selector(selector) ⇒ nil, ElementHandle

The method finds an element matching the specified selector in the ElementHandle's subtree. If no elements match the selector, returns null.

Parameters:

  • selector (String)

Returns:



361
362
363
# File 'lib/playwright_api/element_handle.rb', line 361

def query_selector(selector)
  wrap_impl(@impl.query_selector(unwrap_impl(selector)))
end

#query_selector_all(selector) ⇒ Array[untyped]

The method finds all elements matching the specified selector in the ElementHandles subtree. If no elements match the selector, returns empty array.

Parameters:

  • selector (String)

Returns:

  • (Array[untyped])


368
369
370
# File 'lib/playwright_api/element_handle.rb', line 368

def query_selector_all(selector)
  wrap_impl(@impl.query_selector_all(unwrap_impl(selector)))
end

#screenshot(animations: nil, caret: nil, mask: nil, maskColor: nil, omitBackground: nil, path: nil, quality: nil, scale: nil, style: nil, timeout: nil, type: nil) ⇒ String

This method captures a screenshot of the page, clipped to the size and position of this particular element. If the element is covered by other elements, it will not be actually visible on the screenshot. If the element is a scrollable container, only the currently scrolled content will be visible on the screenshot.

This method waits for the actionability checks, then scrolls element into view before taking a screenshot. If the element is detached from DOM, the method throws an error.

Returns the buffer with the captured screenshot.

Parameters:

  • animations: ("disabled", "allow") (defaults to: nil)
  • caret: ("hide", "initial") (defaults to: nil)
  • mask: (Array[untyped]) (defaults to: nil)
  • maskColor: (String) (defaults to: nil)
  • omitBackground: (Boolean) (defaults to: nil)
  • path: (String, File) (defaults to: nil)
  • quality: (Integer) (defaults to: nil)
  • scale: ("css", "device") (defaults to: nil)
  • style: (String) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • type: ("png", "jpeg", "webp") (defaults to: nil)

Returns:

  • (String)


379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/playwright_api/element_handle.rb', line 379

def screenshot(
      animations: nil,
      caret: nil,
      mask: nil,
      maskColor: nil,
      omitBackground: nil,
      path: nil,
      quality: nil,
      scale: nil,
      style: nil,
      timeout: nil,
      type: nil)
  wrap_impl(@impl.screenshot(animations: unwrap_impl(animations), caret: unwrap_impl(caret), mask: unwrap_impl(mask), maskColor: unwrap_impl(maskColor), omitBackground: unwrap_impl(omitBackground), path: unwrap_impl(path), quality: unwrap_impl(quality), scale: unwrap_impl(scale), style: unwrap_impl(style), timeout: unwrap_impl(timeout), type: unwrap_impl(type)))
end

#scroll_into_view_if_needed(timeout: nil) ⇒ void

This method returns an undefined value.

This method waits for actionability checks, then tries to scroll element into view, unless it is completely visible as defined by IntersectionObserver's ratio.

Throws when elementHandle does not point to an element connected to a Document or a ShadowRoot.

See scrolling for alternative ways to scroll.

Parameters:

  • timeout: (Float) (defaults to: nil)


403
404
405
# File 'lib/playwright_api/element_handle.rb', line 403

def scroll_into_view_if_needed(timeout: nil)
  wrap_impl(@impl.scroll_into_view_if_needed(timeout: unwrap_impl(timeout)))
end

#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Array[untyped]

This method waits for actionability checks, waits until all specified options are present in the <select> element and selects these options.

If the target element is not a <select> element, this method throws an error. However, if the element is inside the <label> element that has an associated control, the control will be used instead.

Returns the array of option values that have been successfully selected.

Triggers a change and input event once all the provided options have been selected.

Usage

# Single selection matching the value or label
handle.select_option("blue")
# single selection matching both the label
handle.select_option(label="blue")
# multiple selection
handle.select_option(value=["red", "green", "blue"])

Parameters:

  • element: (ElementHandle, Array[untyped]) (defaults to: nil)
  • index: (Integer, Array[untyped]) (defaults to: nil)
  • value: (String, Array[untyped]) (defaults to: nil)
  • label: (String, Array[untyped]) (defaults to: nil)
  • force: (Boolean) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)

Returns:

  • (Array[untyped])


426
427
428
429
430
431
432
433
434
435
# File 'lib/playwright_api/element_handle.rb', line 426

def select_option(
      element: nil,
      index: nil,
      value: nil,
      label: nil,
      force: nil,
      noWaitAfter: nil,
      timeout: nil)
  wrap_impl(@impl.select_option(element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#select_text(force: nil, timeout: nil) ⇒ void

This method returns an undefined value.

This method waits for actionability checks, then focuses the element and selects all its text content.

If the element is inside the <label> element that has an associated control, focuses and selects text in the control instead.

Parameters:

  • force: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)


442
443
444
# File 'lib/playwright_api/element_handle.rb', line 442

def select_text(force: nil, timeout: nil)
  wrap_impl(@impl.select_text(force: unwrap_impl(force), timeout: unwrap_impl(timeout)))
end

#set_checked(checked, force: nil, noWaitAfter: nil, position: nil, scroll: nil, timeout: nil, trial: nil) ⇒ void Also known as: checked=

This method returns an undefined value.

This method checks or unchecks an element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method throws.
  2. If the element already has the right checked state, this method returns immediately.
  3. Wait for actionability checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.
  4. Scroll the element into view if needed.
  5. Use [property: Page.mouse] to click in the center of the element.
  6. Ensure that the element is now checked or unchecked. If not, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

Parameters:

  • checked (Boolean)
  • force: (Boolean) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


457
458
459
460
461
462
463
464
465
466
# File 'lib/playwright_api/element_handle.rb', line 457

def set_checked(
      checked,
      force: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.set_checked(unwrap_impl(checked), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ void Also known as: input_files=

This method returns an undefined value.

Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the current working directory. For empty array, clears the selected files. For inputs with a [webkitdirectory] attribute, only a single directory path is supported.

This method expects ElementHandle to point to an input element. However, if the element is inside the <label> element that has an associated control, targets the control instead.

Parameters:

  • files ((String | File), Array[untyped], Hash[untyped, untyped], Array[untyped])
  • noWaitAfter: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)


476
477
478
# File 'lib/playwright_api/element_handle.rb', line 476

def set_input_files(files, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.set_input_files(unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, scroll: nil, timeout: nil, trial: nil) ⇒ void

This method returns an undefined value.

This method taps the element by performing the following steps:

  1. Wait for actionability checks on the element, unless force option is set.
  2. Scroll the element into view if needed.
  3. Use [property: Page.touchscreen] to tap the center of the element, or the specified position.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

NOTE: elementHandle.tap() requires that the hasTouch option of the browser context be set to true.

Parameters:

  • force: (Boolean) (defaults to: nil)
  • modifiers: (Array[untyped]) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


493
494
495
496
497
498
499
500
501
502
# File 'lib/playwright_api/element_handle.rb', line 493

def tap_point(
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.tap_point(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#text_contentnil, String

Returns the node.textContent.

Returns:

  • (nil, String)


506
507
508
# File 'lib/playwright_api/element_handle.rb', line 506

def text_content
  wrap_impl(@impl.text_content)
end

#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ void

Deprecated.

In most cases, you should use [method: Locator.fill] instead. You only need to press keys one by one if there is special keyboard handling on the page - in this case use [method: Locator.pressSequentially].

This method returns an undefined value.

Focuses the element, and then sends a keydown, keypress/input, and keyup event for each character in the text.

To press a special key, like Control or ArrowDown, use [method: ElementHandle.press].

Usage

Parameters:

  • text (String)
  • delay: (Float) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)


518
519
520
# File 'lib/playwright_api/element_handle.rb', line 518

def type(text, delay: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.type(unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#uncheck(force: nil, noWaitAfter: nil, position: nil, scroll: nil, timeout: nil, trial: nil) ⇒ void

This method returns an undefined value.

This method checks the element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.
  2. Wait for actionability checks on the element, unless force option is set.
  3. Scroll the element into view if needed.
  4. Use [property: Page.mouse] to click in the center of the element.
  5. Ensure that the element is now unchecked. If not, this method throws.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

Parameters:

  • force: (Boolean) (defaults to: nil)
  • noWaitAfter: (Boolean) (defaults to: nil)
  • position: (Hash[untyped, untyped]) (defaults to: nil)
  • scroll: ("auto", "none") (defaults to: nil)
  • timeout: (Float) (defaults to: nil)
  • trial: (Boolean) (defaults to: nil)


534
535
536
537
538
539
540
541
542
# File 'lib/playwright_api/element_handle.rb', line 534

def uncheck(
      force: nil,
      noWaitAfter: nil,
      position: nil,
      scroll: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.uncheck(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), scroll: unwrap_impl(scroll), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#visible?Boolean

Returns whether the element is visible.

Returns:

  • (Boolean)


324
325
326
# File 'lib/playwright_api/element_handle.rb', line 324

def visible?
  wrap_impl(@impl.visible?)
end

#wait_for_element_state(state, timeout: nil) ⇒ void

This method returns an undefined value.

Returns when the element satisfies the state.

Depending on the state parameter, this method waits for one of the actionability checks to pass. This method throws when the element is detached while waiting, unless waiting for the "hidden" state.

  • "visible" Wait until the element is visible.
  • "hidden" Wait until the element is not visible or not attached. Note that waiting for hidden does not throw when the element detaches.
  • "stable" Wait until the element is both visible and stable.
  • "enabled" Wait until the element is enabled.
  • "disabled" Wait until the element is not enabled.
  • "editable" Wait until the element is editable.

If the element does not satisfy the condition for the timeout milliseconds, this method will throw.

Parameters:

  • state ("visible", "hidden", "stable", "enabled", "disabled", "editable")
  • timeout: (Float) (defaults to: nil)


557
558
559
# File 'lib/playwright_api/element_handle.rb', line 557

def wait_for_element_state(state, timeout: nil)
  wrap_impl(@impl.wait_for_element_state(unwrap_impl(state), timeout: unwrap_impl(timeout)))
end

#wait_for_selector(selector, state: nil, strict: nil, timeout: nil) ⇒ nil, ElementHandle

Returns element specified by selector when it satisfies state option. Returns null if waiting for hidden or detached.

Wait for the selector relative to the element handle to satisfy state option (either appear/disappear from dom, or become visible/hidden). If at the moment of calling the method selector already satisfies the condition, the method will return immediately. If the selector doesn't satisfy the condition for the timeout milliseconds, the function will throw.

Usage

page.set_content("<div><span></span></div>")
div = page.query_selector("div")
# waiting for the "span" selector relative to the div.
span = div.wait_for_selector("span", state="attached")

NOTE: This method does not work across navigations, use [method: Page.waitForSelector] instead.

Parameters:

  • selector (String)
  • state: ("attached", "detached", "visible", "hidden") (defaults to: nil)
  • strict: (Boolean) (defaults to: nil)
  • timeout: (Float) (defaults to: nil)

Returns:



580
581
582
# File 'lib/playwright_api/element_handle.rb', line 580

def wait_for_selector(selector, state: nil, strict: nil, timeout: nil)
  wrap_impl(@impl.wait_for_selector(unwrap_impl(selector), state: unwrap_impl(state), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end