Class: Playwright::Frame

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/frame.rb

Overview

At every point of time, page exposes its current frame tree via the [‘method: Page.mainFrame`] and

‘method: Frame.childFrames`

methods.

Frame object’s lifecycle is controlled by three events, dispatched on the page object:

  • ‘event: Page.frameAttached`
    • fired when the frame gets attached to the page. A Frame can be attached to the page only once.

  • ‘event: Page.frameNavigated`
    • fired when the frame commits navigation to a different URL.

  • ‘event: Page.frameDetached`
    • fired when the frame gets detached from the page. A Frame can be detached from the page only once.

An example of dumping frame tree:

“‘python sync from playwright.sync_api import sync_playwright

def run(playwright):

firefox = playwright.firefox
browser = firefox.launch()
page = browser.new_page()
page.goto("https://www.theverge.com")
dump_frame_tree(page.main_frame, "")
browser.close()

def dump_frame_tree(frame, indent):

print(indent + frame.name + '@' + frame.url)
for child in frame.child_frames:
    dump_frame_tree(child, indent + "    ")

with sync_playwright() as playwright:

run(playwright)

“‘

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#add_script_tag(content: nil, path: nil, type: nil, url: nil) ⇒ Object

Returns the added tag when the script’s onload fires or when the script content was injected into frame.

Adds a ‘<script>` tag into the page with the desired url or content.



38
39
40
# File 'lib/playwright_api/frame.rb', line 38

def add_script_tag(content: nil, path: nil, type: nil, url: nil)
  wrap_impl(@impl.add_script_tag(content: unwrap_impl(content), path: unwrap_impl(path), type: unwrap_impl(type), url: unwrap_impl(url)))
end

#add_style_tag(content: nil, path: nil, url: nil) ⇒ Object

Returns the added tag when the stylesheet’s onload fires or when the CSS content was injected into frame.

Adds a ‘<link rel=“stylesheet”>` tag into the page with the desired url or a `<style type=“text/css”>` tag with the content.



47
48
49
# File 'lib/playwright_api/frame.rb', line 47

def add_style_tag(content: nil, path: nil, url: nil)
  wrap_impl(@impl.add_style_tag(content: unwrap_impl(content), path: unwrap_impl(path), url: unwrap_impl(url)))
end

#check(selector, force: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method checks an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Ensure that matched element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.

  3. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  4. Scroll the element into view if needed.

  5. Use [‘property: Page.mouse`] to click in the center of the element.

  6. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  7. Ensure that the element is now checked. If not, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



63
64
65
66
67
68
69
70
71
72
# File 'lib/playwright_api/frame.rb', line 63

def check(
      selector,
      force: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.check(unwrap_impl(selector), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#checked?(selector, strict: nil, timeout: nil) ⇒ Boolean

Returns whether the element is checked. Throws if the element is not a checkbox or radio input.

Returns:

  • (Boolean)


531
532
533
# File 'lib/playwright_api/frame.rb', line 531

def checked?(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.checked?(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#child_framesObject



74
75
76
# File 'lib/playwright_api/frame.rb', line 74

def child_frames
  wrap_impl(@impl.child_frames)
end

#click(selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method clicks an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to click in the center of the element, or the specified position.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
# File 'lib/playwright_api/frame.rb', line 88

def click(
      selector,
      button: nil,
      clickCount: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.click(unwrap_impl(selector), button: unwrap_impl(button), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#contentObject

Gets the full HTML contents of the frame, including the doctype.



105
106
107
# File 'lib/playwright_api/frame.rb', line 105

def content
  wrap_impl(@impl.content)
end

#dblclick(selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method double clicks an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to double click in the center of the element, or the specified position.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will throw.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

NOTE: ‘frame.dblclick()` dispatches two click events and a single dblclick event.



121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/playwright_api/frame.rb', line 121

def dblclick(
      selector,
      button: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.dblclick(unwrap_impl(selector), button: unwrap_impl(button), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#detached=(req) ⇒ Object



947
948
949
# File 'lib/playwright_api/frame.rb', line 947

def detached=(req)
  wrap_impl(@impl.detached=(unwrap_impl(req)))
end

#detached?Boolean

Returns true if the frame has been detached, or false otherwise.

Returns:

  • (Boolean)


537
538
539
# File 'lib/playwright_api/frame.rb', line 537

def detached?
  wrap_impl(@impl.detached?)
end

#disabled?(selector, strict: nil, timeout: nil) ⇒ Boolean

Returns whether the element is disabled, the opposite of [enabled](../actionability.md#enabled).

Returns:

  • (Boolean)


543
544
545
# File 'lib/playwright_api/frame.rb', line 543

def disabled?(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.disabled?(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#dispatch_event(selector, type, eventInit: nil, strict: nil, timeout: nil) ⇒ Object

The snippet below dispatches the click event on the element. Regardless of the visibility state of the element, click is dispatched. This is equivalent to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).

Usage

“‘python sync frame.dispatch_event(“button#submit”, “click”) “`

Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.

Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:

You can also specify JSHandle as the property value if you want live objects to be passed into the event:

“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = frame.evaluate_handle(“new DataTransfer()”) frame.dispatch_event(“#source”, “dragstart”, { “dataTransfer”: data_transfer }) “`



167
168
169
170
171
172
173
174
# File 'lib/playwright_api/frame.rb', line 167

def dispatch_event(
      selector,
      type,
      eventInit: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.dispatch_event(unwrap_impl(selector), unwrap_impl(type), eventInit: unwrap_impl(eventInit), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#drag_and_drop(source, target, force: nil, noWaitAfter: nil, sourcePosition: nil, strict: nil, targetPosition: nil, timeout: nil, trial: nil) ⇒ Object



176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/playwright_api/frame.rb', line 176

def drag_and_drop(
      source,
      target,
      force: nil,
      noWaitAfter: nil,
      sourcePosition: nil,
      strict: nil,
      targetPosition: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.drag_and_drop(unwrap_impl(source), unwrap_impl(target), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), sourcePosition: unwrap_impl(sourcePosition), strict: unwrap_impl(strict), targetPosition: unwrap_impl(targetPosition), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#editable?(selector, strict: nil, timeout: nil) ⇒ Boolean

Returns whether the element is [editable](../actionability.md#editable).

Returns:

  • (Boolean)


549
550
551
# File 'lib/playwright_api/frame.rb', line 549

def editable?(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.editable?(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#enabled?(selector, strict: nil, timeout: nil) ⇒ Boolean

Returns whether the element is [enabled](../actionability.md#enabled).

Returns:

  • (Boolean)


555
556
557
# File 'lib/playwright_api/frame.rb', line 555

def enabled?(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.enabled?(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#eval_on_selector(selector, expression, arg: nil, strict: nil) ⇒ Object

Returns the return value of expression.

The method finds an element matching the specified selector within the frame and passes it as a first argument to expression. If no elements match the selector, the method throws an error.

If expression returns a [Promise], then [‘method: Frame.evalOnSelector`] would wait for the promise to resolve and return its value.

Usage

“‘python sync search_value = frame.eval_on_selector(“#search”, “el => el.value”) preload_href = frame.eval_on_selector(“link“, ”el => el.href“) html = frame.eval_on_selector(”.main-container“, ”(e, suffix) => e.outerHTML + suffix“, ”hello“) “`



206
207
208
# File 'lib/playwright_api/frame.rb', line 206

def eval_on_selector(selector, expression, arg: nil, strict: nil)
  wrap_impl(@impl.eval_on_selector(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg), strict: unwrap_impl(strict)))
end

#eval_on_selector_all(selector, expression, arg: nil) ⇒ Object

Returns the return value of expression.

The method finds all elements matching the specified selector within the frame and passes an array of matched elements as a first argument to expression.

If expression returns a [Promise], then [‘method: Frame.evalOnSelectorAll`] would wait for the promise to resolve and return its value.

Usage

“‘python sync divs_counts = frame.eval_on_selector_all(“div”, “(divs, min) => divs.length >= min”, 10) “`



224
225
226
# File 'lib/playwright_api/frame.rb', line 224

def eval_on_selector_all(selector, expression, arg: nil)
  wrap_impl(@impl.eval_on_selector_all(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#evaluate(expression, arg: nil) ⇒ Object

Returns the return value of expression.

If the function passed to the [‘method: Frame.evaluate`] returns a [Promise], then [`method: Frame.evaluate`] would wait for the promise to resolve and return its value.

If the function passed to the [‘method: Frame.evaluate`] returns a non- value, then

‘method: Frame.evaluate`

returns undefined. Playwright also supports transferring some

additional values that are not serializable by JSON: -0, NaN, Infinity, -Infinity.

Usage

“‘python sync result = frame.evaluate(“([x, y]) => Promise.resolve(x * y)”, [7, 8]) print(result) # prints “56” “`

A string can also be passed in instead of a function.

“‘python sync print(frame.evaluate(“1 + 2”)) # prints “3” x = 10 print(frame.evaluate(f“1 + x”)) # prints “11” “`

ElementHandle instances can be passed as an argument to the [‘method: Frame.evaluate`]:

“‘python sync body_handle = frame.evaluate(“document.body”) html = frame.evaluate(“([body, suffix]) => body.innerHTML + suffix”, [body_handle, “hello”]) body_handle.dispose() “`



260
261
262
# File 'lib/playwright_api/frame.rb', line 260

def evaluate(expression, arg: nil)
  wrap_impl(@impl.evaluate(unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#evaluate_handle(expression, arg: nil) ⇒ Object

Returns the return value of expression as a JSHandle.

The only difference between [‘method: Frame.evaluate`] and [`method: Frame.evaluateHandle`] is that

‘method: Frame.evaluateHandle`

returns JSHandle.

If the function, passed to the [‘method: Frame.evaluateHandle`], returns a [Promise], then

‘method: Frame.evaluateHandle`

would wait for the promise to resolve and return its value.

Usage

“‘python sync a_window_handle = frame.evaluate_handle(“Promise.resolve(window)”) a_window_handle # handle for the window object. “`

A string can also be passed in instead of a function.

“‘python sync a_handle = page.evaluate_handle(“document”) # handle for the “document” “`

JSHandle instances can be passed as an argument to the [‘method: Frame.evaluateHandle`]:

“‘python sync a_handle = page.evaluate_handle(“document.body”) result_handle = page.evaluate_handle(“body => body.innerHTML”, a_handle) print(result_handle.json_value()) result_handle.dispose() “`



294
295
296
# File 'lib/playwright_api/frame.rb', line 294

def evaluate_handle(expression, arg: nil)
  wrap_impl(@impl.evaluate_handle(unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#expect_navigation(timeout: nil, url: nil, waitUntil: nil, &block) ⇒ Object

Waits for the frame navigation and returns the main resource response. In case of multiple redirects, the navigation will resolve with the response of the last redirect. In case of navigation to a different anchor or navigation due to History API usage, the navigation will resolve with null.

Usage

This method waits for the frame to navigate to a new URL. It is useful for when you run code which will indirectly cause the frame to navigate. Consider this example:

“‘python sync with frame.expect_navigation():

frame.click("a.delayed-navigation") # clicking the link will indirectly cause a navigation

# Resolves after navigation has finished “‘

NOTE: Usage of the [History API](developer.mozilla.org/en-US/docs/Web/API/History_API) to change the URL is considered a navigation.



884
885
886
# File 'lib/playwright_api/frame.rb', line 884

def expect_navigation(timeout: nil, url: nil, waitUntil: nil, &block)
  wrap_impl(@impl.expect_navigation(timeout: unwrap_impl(timeout), url: unwrap_impl(url), waitUntil: unwrap_impl(waitUntil), &wrap_block_call(block)))
end

#fill(selector, value, force: nil, noWaitAfter: nil, strict: nil, timeout: nil) ⇒ Object

This method waits for an element matching selector, waits for [actionability](../actionability.md) checks, focuses the element, fills it and triggers an input event after filling. Note that you can pass an empty string to clear the input field.

If the target element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be filled instead.

To send fine-grained keyboard events, use [‘method: Frame.type`].



304
305
306
307
308
309
310
311
312
# File 'lib/playwright_api/frame.rb', line 304

def fill(
      selector,
      value,
      force: nil,
      noWaitAfter: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.fill(unwrap_impl(selector), unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#focus(selector, strict: nil, timeout: nil) ⇒ Object

This method fetches an element with selector and focuses it. If there’s no element matching selector, the method waits until a matching element appears in the DOM.



317
318
319
# File 'lib/playwright_api/frame.rb', line 317

def focus(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.focus(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#frame_elementObject

Returns the frame or iframe element handle which corresponds to this frame.

This is an inverse of [‘method: ElementHandle.contentFrame`]. Note that returned handle actually belongs to the parent frame.

This method throws an error if the frame has been detached before ‘frameElement()` returns.

Usage

“‘python sync frame_element = frame.frame_element() content_frame = frame_element.content_frame() assert frame == content_frame “`



336
337
338
# File 'lib/playwright_api/frame.rb', line 336

def frame_element
  wrap_impl(@impl.frame_element)
end

#frame_locator(selector) ⇒ Object

When working with iframes, you can create a frame locator that will enter the iframe and allow selecting elements in that iframe.

Usage

Following snippet locates element with text “Submit” in the iframe with id my-frame, like ‘<iframe id=“my-frame”>`:

“‘python sync locator = frame.frame_locator(“#my-iframe”).get_by_text(“Submit”) locator.click() “`



352
353
354
# File 'lib/playwright_api/frame.rb', line 352

def frame_locator(selector)
  wrap_impl(@impl.frame_locator(unwrap_impl(selector)))
end

#get_attribute(selector, name, strict: nil, timeout: nil) ⇒ Object

Returns element attribute value.



358
359
360
# File 'lib/playwright_api/frame.rb', line 358

def get_attribute(selector, name, strict: nil, timeout: nil)
  wrap_impl(@impl.get_attribute(unwrap_impl(selector), unwrap_impl(name), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#get_by_alt_text(text, exact: nil) ⇒ Object

Allows locating elements by their alt text. For example, this method will find the image by alt text “Castle”:

“‘html <img alt=’Castle’> “‘



368
369
370
# File 'lib/playwright_api/frame.rb', line 368

def get_by_alt_text(text, exact: nil)
  wrap_impl(@impl.get_by_alt_text(unwrap_impl(text), exact: unwrap_impl(exact)))
end

#get_by_label(text, exact: nil) ⇒ Object

Allows locating input elements by the text of the associated label. For example, this method will find the input by label text “Password” in the following DOM:

“‘html <label for=“password-input”>Password:</label> <input id=“password-input”> “`



379
380
381
# File 'lib/playwright_api/frame.rb', line 379

def get_by_label(text, exact: nil)
  wrap_impl(@impl.get_by_label(unwrap_impl(text), exact: unwrap_impl(exact)))
end

#get_by_placeholder(text, exact: nil) ⇒ Object

Allows locating input elements by the placeholder text. For example, this method will find the input by placeholder “Country”:

“‘html <input placeholder=“Country”> “`



389
390
391
# File 'lib/playwright_api/frame.rb', line 389

def get_by_placeholder(text, exact: nil)
  wrap_impl(@impl.get_by_placeholder(unwrap_impl(text), exact: unwrap_impl(exact)))
end

#get_by_role(role, checked: nil, disabled: nil, exact: nil, expanded: nil, includeHidden: nil, level: nil, name: nil, pressed: nil, selected: nil) ⇒ Object

Allows locating elements by their [ARIA role](www.w3.org/TR/wai-aria-1.2/#roles), [ARIA attributes](www.w3.org/TR/wai-aria-1.2/#aria-attributes) and [accessible name](w3c.github.io/accname/#dfn-accessible-name). Note that role selector **does not replace** accessibility audits and conformance tests, but rather gives early feedback about the ARIA guidelines.

Note that many html elements have an implicitly [defined role](w3c.github.io/html-aam/#html-element-role-mappings) that is recognized by the role selector. You can find all the [supported roles here](www.w3.org/TR/wai-aria-1.2/#role_definitions). ARIA guidelines **do not recommend** duplicating implicit roles and attributes by setting role and/or aria-* attributes to default values.



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/playwright_api/frame.rb', line 397

def get_by_role(
      role,
      checked: nil,
      disabled: nil,
      exact: nil,
      expanded: nil,
      includeHidden: nil,
      level: nil,
      name: nil,
      pressed: nil,
      selected: nil)
  wrap_impl(@impl.get_by_role(unwrap_impl(role), checked: unwrap_impl(checked), disabled: unwrap_impl(disabled), exact: unwrap_impl(exact), expanded: unwrap_impl(expanded), includeHidden: unwrap_impl(includeHidden), level: unwrap_impl(level), name: unwrap_impl(name), pressed: unwrap_impl(pressed), selected: unwrap_impl(selected)))
end

#get_by_test_id(testId) ⇒ Object

Locate element by the test id. By default, the data-testid attribute is used as a test id. Use [‘method: Selectors.setTestIdAttribute`] to configure a different test id attribute if necessary.



413
414
415
# File 'lib/playwright_api/frame.rb', line 413

def get_by_test_id(testId)
  wrap_impl(@impl.get_by_test_id(unwrap_impl(testId)))
end

#get_by_text(text, exact: nil) ⇒ Object

Allows locating elements that contain given text. Consider the following DOM structure:

“‘html <div>Hello <span>world</span></div> <div>Hello</div> “`

You can locate by text substring, exact string, or a regular expression:

“‘python sync # Matches <span> page.get_by_text(“world”)

# Matches first <div> page.get_by_text(“Hello world”)

# Matches second <div> page.get_by_text(“Hello”, exact=True)

# Matches both <div>s page.get_by_text(re.compile(“Hello”))

# Matches second <div> page.get_by_text(re.compile(“^hello$”, re.IGNORECASE)) “‘

See also [‘method: Locator.filter`] that allows to match by another criteria, like an accessible role, and then filter by the text content.

NOTE: Matching by text always normalizes whitespace, even with exact match. For example, it turns multiple spaces into one, turns line breaks into spaces and ignores leading and trailing whitespace.

NOTE: Input elements of the type button and submit are matched by their value instead of the text content. For example, locating by text ‘“Log in”` matches `<input type=button value=“Log in”>`.



449
450
451
# File 'lib/playwright_api/frame.rb', line 449

def get_by_text(text, exact: nil)
  wrap_impl(@impl.get_by_text(unwrap_impl(text), exact: unwrap_impl(exact)))
end

#get_by_title(text, exact: nil) ⇒ Object

Allows locating elements by their title. For example, this method will find the button by its title “Place the order”:

“‘html <button title=’Place the order’>Order Now</button> “‘



459
460
461
# File 'lib/playwright_api/frame.rb', line 459

def get_by_title(text, exact: nil)
  wrap_impl(@impl.get_by_title(unwrap_impl(text), exact: unwrap_impl(exact)))
end

#goto(url, referer: nil, timeout: nil, waitUntil: nil) ⇒ Object

Returns the main resource response. In case of multiple redirects, the navigation will resolve with the response of the last redirect.

The method will throw an error if:

  • there’s an SSL error (e.g. in case of self-signed certificates).

  • target URL is invalid.

  • the timeout is exceeded during navigation.

  • the remote server does not respond or is unreachable.

  • the main resource failed to load.

The method will not throw an error when any valid HTTP status code is returned by the remote server, including 404 “Not Found” and 500 “Internal Server Error”. The status code for such responses can be retrieved by calling [‘method: Response.status`].

NOTE: The method either throws an error or returns a main resource response. The only exceptions are navigation to about:blank or navigation to the same URL with a different hash, which would succeed and return null.

NOTE: Headless mode doesn’t support navigation to a PDF document. See the [upstream issue](bugs.chromium.org/p/chromium/issues/detail?id=761295).



483
484
485
# File 'lib/playwright_api/frame.rb', line 483

def goto(url, referer: nil, timeout: nil, waitUntil: nil)
  wrap_impl(@impl.goto(unwrap_impl(url), referer: unwrap_impl(referer), timeout: unwrap_impl(timeout), waitUntil: unwrap_impl(waitUntil)))
end

#hidden?(selector, strict: nil, timeout: nil) ⇒ Boolean

Returns whether the element is hidden, the opposite of [visible](../actionability.md#visible). selector that does not match any elements is considered hidden.

Returns:

  • (Boolean)


561
562
563
# File 'lib/playwright_api/frame.rb', line 561

def hidden?(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.hidden?(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#highlight(selector) ⇒ Object



952
953
954
# File 'lib/playwright_api/frame.rb', line 952

def highlight(selector)
  wrap_impl(@impl.highlight(unwrap_impl(selector)))
end

#hover(selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method hovers over an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to hover over the center of the element, or the specified position.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



497
498
499
500
501
502
503
504
505
506
507
# File 'lib/playwright_api/frame.rb', line 497

def hover(
      selector,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.hover(unwrap_impl(selector), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#inner_html(selector, strict: nil, timeout: nil) ⇒ Object

Returns element.innerHTML.



511
512
513
# File 'lib/playwright_api/frame.rb', line 511

def inner_html(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.inner_html(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#inner_text(selector, strict: nil, timeout: nil) ⇒ Object

Returns element.innerText.



517
518
519
# File 'lib/playwright_api/frame.rb', line 517

def inner_text(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.inner_text(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#input_value(selector, strict: nil, timeout: nil) ⇒ Object

Returns input.value for the selected ‘<input>` or `<textarea>` or `<select>` element.

Throws for non-input elements. However, if the element is inside the ‘<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), returns the value of the control.



525
526
527
# File 'lib/playwright_api/frame.rb', line 525

def input_value(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.input_value(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#locator(selector, has: nil, hasText: nil) ⇒ Object

The method returns an element locator that can be used to perform actions on this page / frame. Locator is resolved to the element immediately before performing an action, so a series of actions on the same locator can in fact be performed on different DOM elements. That would happen if the DOM structure between those actions has changed.

[Learn more about locators](../locators.md).

[Learn more about locators](../locators.md).



578
579
580
# File 'lib/playwright_api/frame.rb', line 578

def locator(selector, has: nil, hasText: nil)
  wrap_impl(@impl.locator(unwrap_impl(selector), has: unwrap_impl(has), hasText: unwrap_impl(hasText)))
end

#nameObject

Returns frame’s name attribute as specified in the tag.

If the name is empty, returns the id attribute instead.

NOTE: This value is calculated once when the frame is created, and will not update if the attribute is changed later.



588
589
590
# File 'lib/playwright_api/frame.rb', line 588

def name
  wrap_impl(@impl.name)
end

#off(event, callback) ⇒ Object

– inherited from EventEmitter –



970
971
972
# File 'lib/playwright_api/frame.rb', line 970

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

– inherited from EventEmitter –



964
965
966
# File 'lib/playwright_api/frame.rb', line 964

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

– inherited from EventEmitter –



958
959
960
# File 'lib/playwright_api/frame.rb', line 958

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#pageObject

Returns the page containing this frame.



594
595
596
# File 'lib/playwright_api/frame.rb', line 594

def page
  wrap_impl(@impl.page)
end

#parent_frameObject

Parent frame, if any. Detached frames and main frames return null.



600
601
602
# File 'lib/playwright_api/frame.rb', line 600

def parent_frame
  wrap_impl(@impl.parent_frame)
end

#press(selector, key, delay: nil, noWaitAfter: nil, strict: nil, timeout: nil) ⇒ Object

key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:

F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.

Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.

Holding down Shift will type the text that corresponds to the key in the upper case.

If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.

Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When specified with the modifier, modifier is pressed and being held while the subsequent key is being pressed.



622
623
624
625
626
627
628
629
630
# File 'lib/playwright_api/frame.rb', line 622

def press(
      selector,
      key,
      delay: nil,
      noWaitAfter: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.press(unwrap_impl(selector), unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#query_selector(selector, strict: nil) ⇒ Object

Returns the ElementHandle pointing to the frame element.

NOTE: The use of ElementHandle is discouraged, use Locator objects and web-first assertions instead.

The method finds an element matching the specified selector within the frame. If no elements match the selector, returns null.



639
640
641
# File 'lib/playwright_api/frame.rb', line 639

def query_selector(selector, strict: nil)
  wrap_impl(@impl.query_selector(unwrap_impl(selector), strict: unwrap_impl(strict)))
end

#query_selector_all(selector) ⇒ Object

Returns the ElementHandles pointing to the frame elements.

NOTE: The use of ElementHandle is discouraged, use Locator objects instead.

The method finds all elements matching the specified selector within the frame. If no elements match the selector, returns empty array.



650
651
652
# File 'lib/playwright_api/frame.rb', line 650

def query_selector_all(selector)
  wrap_impl(@impl.query_selector_all(unwrap_impl(selector)))
end

#select_option(selector, element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, strict: nil, timeout: nil) ⇒ Object

This method waits for an element matching selector, waits for [actionability](../actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.

If the target element is not a ‘<select>` element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be used instead.

Returns the array of option values that have been successfully selected.

Triggers a change and input event once all the provided options have been selected.

Usage

“‘python sync # single selection matching the value frame.select_option(“select#colors”, “blue”) # single selection matching both the label frame.select_option(“select#colors”, label=“blue”) # multiple selection frame.select_option(“select#colors”, value=[“red”, “green”, “blue”]) “`



673
674
675
676
677
678
679
680
681
682
683
684
# File 'lib/playwright_api/frame.rb', line 673

def select_option(
      selector,
      element: nil,
      index: nil,
      value: nil,
      label: nil,
      force: nil,
      noWaitAfter: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.select_option(unwrap_impl(selector), element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#set_checked(selector, checked, force: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method checks or unchecks an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Ensure that matched element is a checkbox or a radio input. If not, this method throws.

  3. If the element already has the right checked state, this method returns immediately.

  4. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  5. Scroll the element into view if needed.

  6. Use [‘property: Page.mouse`] to click in the center of the element.

  7. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  8. Ensure that the element is now checked or unchecked. If not, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



699
700
701
702
703
704
705
706
707
708
709
# File 'lib/playwright_api/frame.rb', line 699

def set_checked(
      selector,
      checked,
      force: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.set_checked(unwrap_impl(selector), unwrap_impl(checked), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#set_content(html, timeout: nil, waitUntil: nil) ⇒ Object Also known as: content=



711
712
713
# File 'lib/playwright_api/frame.rb', line 711

def set_content(html, timeout: nil, waitUntil: nil)
  wrap_impl(@impl.set_content(unwrap_impl(html), timeout: unwrap_impl(timeout), waitUntil: unwrap_impl(waitUntil)))
end

#set_input_files(selector, files, noWaitAfter: nil, strict: nil, timeout: nil) ⇒ Object

Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the current working directory. For empty array, clears the selected files.

This method expects selector to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input). However, if the element is inside the ‘<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), targets the control instead.



722
723
724
725
726
727
728
729
# File 'lib/playwright_api/frame.rb', line 722

def set_input_files(
      selector,
      files,
      noWaitAfter: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.set_input_files(unwrap_impl(selector), unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#tap_point(selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method taps an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified position.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

NOTE: ‘frame.tap()` requires that the hasTouch option of the browser context be set to true.



743
744
745
746
747
748
749
750
751
752
753
# File 'lib/playwright_api/frame.rb', line 743

def tap_point(
      selector,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.tap_point(unwrap_impl(selector), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#text_content(selector, strict: nil, timeout: nil) ⇒ Object

Returns element.textContent.



757
758
759
# File 'lib/playwright_api/frame.rb', line 757

def text_content(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.text_content(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#titleObject

Returns the page title.



763
764
765
# File 'lib/playwright_api/frame.rb', line 763

def title
  wrap_impl(@impl.title)
end

#type(selector, text, delay: nil, noWaitAfter: nil, strict: nil, timeout: nil) ⇒ Object

Sends a keydown, keypress/input, and keyup event for each character in the text. frame.type can be used to send fine-grained keyboard events. To fill values in form fields, use [‘method: Frame.fill`].

To press a special key, like Control or ArrowDown, use [‘method: Keyboard.press`].

Usage

“‘python sync frame.type(“#mytextarea”, “hello”) # types instantly frame.type(“#mytextarea”, “world”, delay=100) # types slower, like a user “`



779
780
781
782
783
784
785
786
787
# File 'lib/playwright_api/frame.rb', line 779

def type(
      selector,
      text,
      delay: nil,
      noWaitAfter: nil,
      strict: nil,
      timeout: nil)
  wrap_impl(@impl.type(unwrap_impl(selector), unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#uncheck(selector, force: nil, noWaitAfter: nil, position: nil, strict: nil, timeout: nil, trial: nil) ⇒ Object

This method checks an element matching selector by performing the following steps:

  1. Find an element matching selector. If there is none, wait until a matching element is attached to the DOM.

  2. Ensure that matched element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.

  3. Wait for [actionability](../actionability.md) checks on the matched element, unless force option is set. If the element is detached during the checks, the whole action is retried.

  4. Scroll the element into view if needed.

  5. Use [‘property: Page.mouse`] to click in the center of the element.

  6. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  7. Ensure that the element is now unchecked. If not, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



801
802
803
804
805
806
807
808
809
810
# File 'lib/playwright_api/frame.rb', line 801

def uncheck(
      selector,
      force: nil,
      noWaitAfter: nil,
      position: nil,
      strict: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.uncheck(unwrap_impl(selector), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#urlObject

Returns frame’s url.



814
815
816
# File 'lib/playwright_api/frame.rb', line 814

def url
  wrap_impl(@impl.url)
end

#visible?(selector, strict: nil, timeout: nil) ⇒ Boolean

Returns whether the element is [visible](../actionability.md#visible). selector that does not match any elements is considered not visible.

Returns:

  • (Boolean)


567
568
569
# File 'lib/playwright_api/frame.rb', line 567

def visible?(selector, strict: nil, timeout: nil)
  wrap_impl(@impl.visible?(unwrap_impl(selector), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#wait_for_function(expression, arg: nil, polling: nil, timeout: nil) ⇒ Object

Returns when the expression returns a truthy value, returns that value.

Usage

The [‘method: Frame.waitForFunction`] can be used to observe viewport size change:

“‘python sync from playwright.sync_api import sync_playwright

def run(playwright):

webkit = playwright.webkit
browser = webkit.launch()
page = browser.new_page()
page.evaluate("window.x = 0; setTimeout(() => { window.x = 100 }, 1000);")
page.main_frame.wait_for_function("() => window.x > 0")
browser.close()

with sync_playwright() as playwright:

run(playwright)

“‘

To pass an argument to the predicate of frame.waitForFunction function:

“‘python sync selector = “.foo” frame.wait_for_function(“selector => !!document.querySelector(selector)”, selector) “`



846
847
848
# File 'lib/playwright_api/frame.rb', line 846

def wait_for_function(expression, arg: nil, polling: nil, timeout: nil)
  wrap_impl(@impl.wait_for_function(unwrap_impl(expression), arg: unwrap_impl(arg), polling: unwrap_impl(polling), timeout: unwrap_impl(timeout)))
end

#wait_for_load_state(state: nil, timeout: nil) ⇒ Object

Waits for the required load state to be reached.

This returns when the frame reaches a required load state, load by default. The navigation must have been committed when this method is called. If current document has already reached the required state, resolves immediately.

Usage

“‘python sync frame.click(“button”) # click triggers navigation. frame.wait_for_load_state() # the promise resolves after “load” event. “`



862
863
864
# File 'lib/playwright_api/frame.rb', line 862

def wait_for_load_state(state: nil, timeout: nil)
  wrap_impl(@impl.wait_for_load_state(state: unwrap_impl(state), timeout: unwrap_impl(timeout)))
end

#wait_for_selector(selector, state: nil, strict: nil, timeout: nil) ⇒ Object

Returns when element specified by selector satisfies state option. Returns null if waiting for hidden or detached.

NOTE: Playwright automatically waits for element to be ready before performing an action. Using Locator objects and web-first assertions make the code wait-for-selector-free.

Wait for the selector to satisfy state option (either appear/disappear from dom, or become visible/hidden). If at the moment of calling the method selector already satisfies the condition, the method will return immediately. If the selector doesn’t satisfy the condition for the timeout milliseconds, the function will throw.

Usage

This method works across navigations:

“‘python sync from playwright.sync_api import sync_playwright

def run(playwright):

chromium = playwright.chromium
browser = chromium.launch()
page = browser.new_page()
for current_url in ["https://google.com", "https://bbc.com"]:
    page.goto(current_url, wait_until="domcontentloaded")
    element = page.main_frame.wait_for_selector("img")
    print("Loaded image: " + str(element.get_attribute("src")))
browser.close()

with sync_playwright() as playwright:

run(playwright)

“‘



920
921
922
# File 'lib/playwright_api/frame.rb', line 920

def wait_for_selector(selector, state: nil, strict: nil, timeout: nil)
  wrap_impl(@impl.wait_for_selector(unwrap_impl(selector), state: unwrap_impl(state), strict: unwrap_impl(strict), timeout: unwrap_impl(timeout)))
end

#wait_for_timeout(timeout) ⇒ Object

Waits for the given timeout in milliseconds.

Note that ‘frame.waitForTimeout()` should only be used for debugging. Tests using the timer in production are going to be flaky. Use signals such as network events, selectors becoming visible and others instead.



929
930
931
# File 'lib/playwright_api/frame.rb', line 929

def wait_for_timeout(timeout)
  wrap_impl(@impl.wait_for_timeout(unwrap_impl(timeout)))
end

#wait_for_url(url, timeout: nil, waitUntil: nil) ⇒ Object

Waits for the frame to navigate to the given URL.

Usage

“‘python sync frame.click(“a.delayed-navigation”) # clicking the link will indirectly cause a navigation frame.wait_for_url(“**/target.html”) “`



942
943
944
# File 'lib/playwright_api/frame.rb', line 942

def wait_for_url(url, timeout: nil, waitUntil: nil)
  wrap_impl(@impl.wait_for_url(unwrap_impl(url), timeout: unwrap_impl(timeout), waitUntil: unwrap_impl(waitUntil)))
end