Class: Playwright::Touchscreen

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/touchscreen.rb,
sig/playwright.rbs

Overview

The Touchscreen class operates in main-frame CSS pixels relative to the top-left corner of the viewport. Methods on the touchscreen can only be used in browser contexts that have been initialized with hasTouch set to true.

This class is limited to emulating tap gestures. For examples of other gestures simulated by manually dispatching touch events, see the emulating legacy touch events page.

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#tap_point(x, y) ⇒ void

This method returns an undefined value.

Dispatches a touchstart and touchend event with a single touch at the position (x,y).

NOTE: [method: Touchscreen.tap] will throw if the hasTouch option of the browser context is false.

Parameters:

  • x (Float)
  • y (Float)


13
14
15
# File 'lib/playwright_api/touchscreen.rb', line 13

def tap_point(x, y)
  wrap_impl(@impl.tap_point(unwrap_impl(x), unwrap_impl(y)))
end