Class: Playwright::AndroidDevice
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::AndroidDevice
- Defined in:
- lib/playwright_api/android_device.rb
Overview
AndroidDevice represents a connected device, either real hardware or emulated. Devices can be obtained using [‘method: Android.devices`].
Instance Method Summary collapse
-
#close ⇒ Object
Disconnects from the device.
-
#drag(selector, dest, speed: nil) ⇒ Object
Drags the widget defined by
selectortowardsdestpoint. -
#fill(selector, text) ⇒ Object
Fills the specific
selectorinput box withtext. -
#fling(selector, direction, speed: nil) ⇒ Object
Flings the widget defined by
selectorin the specifieddirection. -
#info(selector) ⇒ Object
Returns information about a widget defined by
selector. -
#input ⇒ Object
property.
-
#install_apk(file, args: nil) ⇒ Object
Installs an apk on the device.
-
#launch_browser(acceptDownloads: nil, bypassCSP: nil, colorScheme: nil, command: nil, deviceScaleFactor: nil, extraHTTPHeaders: nil, geolocation: nil, hasTouch: nil, httpCredentials: nil, ignoreHTTPSErrors: nil, isMobile: nil, javaScriptEnabled: nil, locale: nil, noViewport: nil, offline: nil, permissions: nil, record_har_omit_content: nil, record_har_path: nil, record_video_dir: nil, record_video_size: nil, reducedMotion: nil, screen: nil, timezoneId: nil, userAgent: nil, viewport: nil, &block) ⇒ Object
Launches Chrome browser on the device, and returns its persistent context.
-
#long_tap(selector) ⇒ Object
Performs a long tap on the widget defined by
selector. -
#model ⇒ Object
Device model.
-
#off(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#on(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#once(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#open(command) ⇒ Object
Launches a process in the shell on the device and returns a socket to communicate with the launched process.
-
#pinch_close(selector, percent, speed: nil) ⇒ Object
Pinches the widget defined by
selectorin the closing direction. -
#pinch_open(selector, percent, speed: nil) ⇒ Object
Pinches the widget defined by
selectorin the open direction. -
#press(selector, key) ⇒ Object
Presses the specific
keyin the widget defined byselector. -
#push(file, path, mode: nil) ⇒ Object
Copies a file to the device.
-
#screenshot(path: nil) ⇒ Object
Returns the buffer with the captured screenshot of the device.
-
#scroll(selector, direction, percent, speed: nil) ⇒ Object
Scrolls the widget defined by
selectorin the specifieddirection. -
#serial ⇒ Object
Device serial number.
-
#set_default_timeout(timeout) ⇒ Object
(also: #default_timeout=)
This setting will change the default maximum time for all the methods accepting
timeoutoption. -
#shell(command) ⇒ Object
Executes a shell command on the device and returns its output.
-
#swipe(selector, direction, percent, speed: nil) ⇒ Object
Swipes the widget defined by
selectorin the specifieddirection. - #tap_on(selector, duration: nil, timeout: nil) ⇒ Object
-
#tap_point(selector, duration: nil) ⇒ Object
Taps on the widget defined by
selector. - #tree ⇒ Object
-
#wait(selector, state: nil) ⇒ Object
Waits for the specific
selectorto either appear or disappear, depending on thestate. -
#wait_for_event(event, optionsOrPredicate: nil) ⇒ Object
Waits for event to fire and passes its value into the predicate function.
-
#web_view(selector) ⇒ Object
This method waits until
AndroidWebViewmatching theselectoris opened and returns it. -
#web_views ⇒ Object
Currently open WebViews.
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#close ⇒ Object
Disconnects from the device.
11 12 13 |
# File 'lib/playwright_api/android_device.rb', line 11 def close wrap_impl(@impl.close) end |
#drag(selector, dest, speed: nil) ⇒ Object
Drags the widget defined by selector towards dest point.
16 17 18 |
# File 'lib/playwright_api/android_device.rb', line 16 def drag(selector, dest, speed: nil) raise NotImplementedError.new('drag is not implemented yet.') end |
#fill(selector, text) ⇒ Object
Fills the specific selector input box with text.
21 22 23 |
# File 'lib/playwright_api/android_device.rb', line 21 def fill(selector, text) raise NotImplementedError.new('fill is not implemented yet.') end |
#fling(selector, direction, speed: nil) ⇒ Object
Flings the widget defined by selector in the specified direction.
26 27 28 |
# File 'lib/playwright_api/android_device.rb', line 26 def fling(selector, direction, speed: nil) raise NotImplementedError.new('fling is not implemented yet.') end |
#info(selector) ⇒ Object
Returns information about a widget defined by selector.
31 32 33 |
# File 'lib/playwright_api/android_device.rb', line 31 def info(selector) wrap_impl(@impl.info(unwrap_impl(selector))) end |
#input ⇒ Object
property
6 7 8 |
# File 'lib/playwright_api/android_device.rb', line 6 def input # property wrap_impl(@impl.input) end |
#install_apk(file, args: nil) ⇒ Object
Installs an apk on the device.
36 37 38 |
# File 'lib/playwright_api/android_device.rb', line 36 def install_apk(file, args: nil) raise NotImplementedError.new('install_apk is not implemented yet.') end |
#launch_browser(acceptDownloads: nil, bypassCSP: nil, colorScheme: nil, command: nil, deviceScaleFactor: nil, extraHTTPHeaders: nil, geolocation: nil, hasTouch: nil, httpCredentials: nil, ignoreHTTPSErrors: nil, isMobile: nil, javaScriptEnabled: nil, locale: nil, noViewport: nil, offline: nil, permissions: nil, record_har_omit_content: nil, record_har_path: nil, record_video_dir: nil, record_video_size: nil, reducedMotion: nil, screen: nil, timezoneId: nil, userAgent: nil, viewport: nil, &block) ⇒ Object
Launches Chrome browser on the device, and returns its persistent context.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 |
# File 'lib/playwright_api/android_device.rb', line 41 def launch_browser( acceptDownloads: nil, bypassCSP: nil, colorScheme: nil, command: nil, deviceScaleFactor: nil, extraHTTPHeaders: nil, geolocation: nil, hasTouch: nil, httpCredentials: nil, ignoreHTTPSErrors: nil, isMobile: nil, javaScriptEnabled: nil, locale: nil, noViewport: nil, offline: nil, permissions: nil, record_har_omit_content: nil, record_har_path: nil, record_video_dir: nil, record_video_size: nil, reducedMotion: nil, screen: nil, timezoneId: nil, userAgent: nil, viewport: nil, &block) wrap_impl(@impl.launch_browser(acceptDownloads: unwrap_impl(acceptDownloads), bypassCSP: unwrap_impl(bypassCSP), colorScheme: unwrap_impl(colorScheme), command: unwrap_impl(command), deviceScaleFactor: unwrap_impl(deviceScaleFactor), extraHTTPHeaders: unwrap_impl(extraHTTPHeaders), geolocation: unwrap_impl(geolocation), hasTouch: unwrap_impl(hasTouch), httpCredentials: unwrap_impl(httpCredentials), ignoreHTTPSErrors: unwrap_impl(ignoreHTTPSErrors), isMobile: unwrap_impl(isMobile), javaScriptEnabled: unwrap_impl(javaScriptEnabled), locale: unwrap_impl(locale), noViewport: unwrap_impl(noViewport), offline: unwrap_impl(offline), permissions: unwrap_impl(), record_har_omit_content: unwrap_impl(record_har_omit_content), record_har_path: unwrap_impl(record_har_path), record_video_dir: unwrap_impl(record_video_dir), record_video_size: unwrap_impl(record_video_size), reducedMotion: unwrap_impl(reducedMotion), screen: unwrap_impl(screen), timezoneId: unwrap_impl(timezoneId), userAgent: unwrap_impl(userAgent), viewport: unwrap_impl(), &wrap_block_call(block))) end |
#long_tap(selector) ⇒ Object
Performs a long tap on the widget defined by selector.
72 73 74 |
# File 'lib/playwright_api/android_device.rb', line 72 def long_tap(selector) raise NotImplementedError.new('long_tap is not implemented yet.') end |
#model ⇒ Object
Device model.
77 78 79 |
# File 'lib/playwright_api/android_device.rb', line 77 def model wrap_impl(@impl.model) end |
#off(event, callback) ⇒ Object
– inherited from EventEmitter –
188 189 190 |
# File 'lib/playwright_api/android_device.rb', line 188 def off(event, callback) event_emitter_proxy.off(event, callback) end |
#on(event, callback) ⇒ Object
– inherited from EventEmitter –
182 183 184 |
# File 'lib/playwright_api/android_device.rb', line 182 def on(event, callback) event_emitter_proxy.on(event, callback) end |
#once(event, callback) ⇒ Object
– inherited from EventEmitter –
176 177 178 |
# File 'lib/playwright_api/android_device.rb', line 176 def once(event, callback) event_emitter_proxy.once(event, callback) end |
#open(command) ⇒ Object
Launches a process in the shell on the device and returns a socket to communicate with the launched process.
82 83 84 |
# File 'lib/playwright_api/android_device.rb', line 82 def open(command) raise NotImplementedError.new('open is not implemented yet.') end |
#pinch_close(selector, percent, speed: nil) ⇒ Object
Pinches the widget defined by selector in the closing direction.
87 88 89 |
# File 'lib/playwright_api/android_device.rb', line 87 def pinch_close(selector, percent, speed: nil) raise NotImplementedError.new('pinch_close is not implemented yet.') end |
#pinch_open(selector, percent, speed: nil) ⇒ Object
Pinches the widget defined by selector in the open direction.
92 93 94 |
# File 'lib/playwright_api/android_device.rb', line 92 def pinch_open(selector, percent, speed: nil) raise NotImplementedError.new('pinch_open is not implemented yet.') end |
#press(selector, key) ⇒ Object
Presses the specific key in the widget defined by selector.
97 98 99 |
# File 'lib/playwright_api/android_device.rb', line 97 def press(selector, key) raise NotImplementedError.new('press is not implemented yet.') end |
#push(file, path, mode: nil) ⇒ Object
Copies a file to the device.
102 103 104 |
# File 'lib/playwright_api/android_device.rb', line 102 def push(file, path, mode: nil) raise NotImplementedError.new('push is not implemented yet.') end |
#screenshot(path: nil) ⇒ Object
Returns the buffer with the captured screenshot of the device.
107 108 109 |
# File 'lib/playwright_api/android_device.rb', line 107 def screenshot(path: nil) wrap_impl(@impl.screenshot(path: unwrap_impl(path))) end |
#scroll(selector, direction, percent, speed: nil) ⇒ Object
Scrolls the widget defined by selector in the specified direction.
112 113 114 |
# File 'lib/playwright_api/android_device.rb', line 112 def scroll(selector, direction, percent, speed: nil) raise NotImplementedError.new('scroll is not implemented yet.') end |
#serial ⇒ Object
Device serial number.
117 118 119 |
# File 'lib/playwright_api/android_device.rb', line 117 def serial wrap_impl(@impl.serial) end |
#set_default_timeout(timeout) ⇒ Object Also known as: default_timeout=
This setting will change the default maximum time for all the methods accepting timeout option.
122 123 124 |
# File 'lib/playwright_api/android_device.rb', line 122 def set_default_timeout(timeout) raise NotImplementedError.new('set_default_timeout is not implemented yet.') end |
#shell(command) ⇒ Object
Executes a shell command on the device and returns its output.
128 129 130 |
# File 'lib/playwright_api/android_device.rb', line 128 def shell(command) wrap_impl(@impl.shell(unwrap_impl(command))) end |
#swipe(selector, direction, percent, speed: nil) ⇒ Object
Swipes the widget defined by selector in the specified direction.
133 134 135 |
# File 'lib/playwright_api/android_device.rb', line 133 def swipe(selector, direction, percent, speed: nil) raise NotImplementedError.new('swipe is not implemented yet.') end |
#tap_on(selector, duration: nil, timeout: nil) ⇒ Object
170 171 172 |
# File 'lib/playwright_api/android_device.rb', line 170 def tap_on(selector, duration: nil, timeout: nil) wrap_impl(@impl.tap_on(unwrap_impl(selector), duration: unwrap_impl(duration), timeout: unwrap_impl(timeout))) end |
#tap_point(selector, duration: nil) ⇒ Object
Taps on the widget defined by selector.
138 139 140 |
# File 'lib/playwright_api/android_device.rb', line 138 def tap_point(selector, duration: nil) raise NotImplementedError.new('tap_point is not implemented yet.') end |
#tree ⇒ Object
165 166 167 |
# File 'lib/playwright_api/android_device.rb', line 165 def tree wrap_impl(@impl.tree) end |
#wait(selector, state: nil) ⇒ Object
Waits for the specific selector to either appear or disappear, depending on the state.
143 144 145 |
# File 'lib/playwright_api/android_device.rb', line 143 def wait(selector, state: nil) raise NotImplementedError.new('wait is not implemented yet.') end |
#wait_for_event(event, optionsOrPredicate: nil) ⇒ Object
Waits for event to fire and passes its value into the predicate function. Returns when the predicate returns truthy value.
149 150 151 |
# File 'lib/playwright_api/android_device.rb', line 149 def wait_for_event(event, optionsOrPredicate: nil) raise NotImplementedError.new('wait_for_event is not implemented yet.') end |
#web_view(selector) ⇒ Object
This method waits until AndroidWebView matching the selector is opened and returns it. If there is already an open AndroidWebView matching the selector, returns immediately.
155 156 157 |
# File 'lib/playwright_api/android_device.rb', line 155 def web_view(selector) raise NotImplementedError.new('web_view is not implemented yet.') end |
#web_views ⇒ Object
Currently open WebViews.
160 161 162 |
# File 'lib/playwright_api/android_device.rb', line 160 def web_views raise NotImplementedError.new('web_views is not implemented yet.') end |