Class: Playwright::ConsoleMessage

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/console_message.rb

Overview

ConsoleMessage objects are dispatched by page via the [event: Page.console] event.

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#argsObject

List of arguments passed to a console function call. See also [event: Page.console].



6
7
8
# File 'lib/playwright_api/console_message.rb', line 6

def args
  wrap_impl(@impl.args)
end

#locationObject



10
11
12
# File 'lib/playwright_api/console_message.rb', line 10

def location
  wrap_impl(@impl.location)
end

#off(event, callback) ⇒ Object

-- inherited from EventEmitter --



28
29
30
# File 'lib/playwright_api/console_message.rb', line 28

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

-- inherited from EventEmitter --



40
41
42
# File 'lib/playwright_api/console_message.rb', line 40

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

-- inherited from EventEmitter --



34
35
36
# File 'lib/playwright_api/console_message.rb', line 34

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#textObject

The text of the console message.



15
16
17
# File 'lib/playwright_api/console_message.rb', line 15

def text
  wrap_impl(@impl.text)
end

#typeObject

One of the following values: 'log', 'debug', 'info', 'error', 'warning', 'dir', 'dirxml', 'table', 'trace', 'clear', 'startGroup', 'startGroupCollapsed', 'endGroup', 'assert', 'profile', 'profileEnd', 'count', 'timeEnd'.



22
23
24
# File 'lib/playwright_api/console_message.rb', line 22

def type
  wrap_impl(@impl.type)
end