Class: Playwright::ElementHandle

Inherits:
JSHandle show all
Defined in:
lib/playwright_api/element_handle.rb

Overview

  • extends: JSHandle

ElementHandle represents an in-page DOM element. ElementHandles can be created with the [‘method: Page.querySelector`] method.

“‘python sync href_element = page.query_selector(“a”) href_element.click() “`

ElementHandle prevents DOM element from garbage collection unless the handle is disposed with [‘method: JSHandle.dispose`]. ElementHandles are auto-disposed when their origin frame gets navigated.

ElementHandle instances can be used as an argument in [‘method: Page.evalOnSelector`] and [`method: Page.evaluate`] methods.

> NOTE: In most cases, you would want to use the Locator object instead. You should only use ElementHandle if you want to retain a handle to a particular DOM Node that you intend to pass into [‘method: Page.evaluate`] as an argument.

The difference between the Locator and ElementHandle is that the ElementHandle points to a particular element, while Locator captures the logic of how to retrieve an element.

In the example below, handle points to a particular DOM element on page. If that element changes text or is used by React to render an entirely different component, handle is still pointing to that very DOM element. This can lead to unexpected behaviors.

“‘python sync handle = page.query_selector(“text=Submit”) handle.hover() handle.click() “`

With the locator, every time the element is used, up-to-date DOM element is located in the page using the selector. So in the snippet below, underlying DOM element is going to be located twice.

“‘python sync locator = page.locator(“text=Submit”) locator.hover() locator.click() “`

Instance Method Summary collapse

Methods inherited from JSHandle

#as_element, #dispose, #evaluate, #evaluate_handle, #get_properties, #get_property, #json_value, #to_s

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#bounding_boxObject

This method returns the bounding box of the element, or null if the element is not visible. The bounding box is calculated relative to the main frame viewport - which is usually the same as the browser window.

Scrolling affects the returned bonding box, similarly to [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect). That means x and/or y may be negative.

Elements from child frames return the bounding box relative to the main frame, unlike the [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect).

Assuming the page is static, it is safe to use bounding box coordinates to perform input. For example, the following snippet should click the center of the element.

“‘python sync box = element_handle.bounding_box() page.mouse.click(box + box / 2, box + box / 2) “`



63
64
65
# File 'lib/playwright_api/element_handle.rb', line 63

def bounding_box
  wrap_impl(@impl.bounding_box)
end

#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object

This method checks the element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.

  2. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to click in the center of the element.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  6. Ensure that the element is now checked. If not, this method throws.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



80
81
82
83
84
85
86
87
# File 'lib/playwright_api/element_handle.rb', line 80

def check(
      force: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.check(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#checked?Boolean

Returns whether the element is checked. Throws if the element is not a checkbox or radio input.

Returns:

  • (Boolean)


277
278
279
# File 'lib/playwright_api/element_handle.rb', line 277

def checked?
  wrap_impl(@impl.checked?)
end

#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object

This method clicks the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.mouse`] to click in the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/playwright_api/element_handle.rb', line 99

def click(
      button: nil,
      clickCount: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.click(button: unwrap_impl(button), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#content_frameObject

Returns the content frame for element handles referencing iframe nodes, or null otherwise



113
114
115
# File 'lib/playwright_api/element_handle.rb', line 113

def content_frame
  wrap_impl(@impl.content_frame)
end

#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object

This method double clicks the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.mouse`] to double click in the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will throw.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

> NOTE: ‘elementHandle.dblclick()` dispatches two click events and a single dblclick event.



130
131
132
133
134
135
136
137
138
139
140
# File 'lib/playwright_api/element_handle.rb', line 130

def dblclick(
      button: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.dblclick(button: unwrap_impl(button), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#disabled?Boolean

Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).

Returns:

  • (Boolean)


282
283
284
# File 'lib/playwright_api/element_handle.rb', line 282

def disabled?
  wrap_impl(@impl.disabled?)
end

#dispatch_event(type, eventInit: nil) ⇒ Object

The snippet below dispatches the click event on the element. Regardless of the visibility state of the element, click is dispatched. This is equivalent to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).

“‘python sync element_handle.dispatch_event(“click”) “`

Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.

Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:

You can also specify JSHandle as the property value if you want live objects to be passed into the event:

“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = page.evaluate_handle(“new DataTransfer()”) element_handle.dispatch_event(“#source”, “dragstart”, data_transfer) “`



169
170
171
# File 'lib/playwright_api/element_handle.rb', line 169

def dispatch_event(type, eventInit: nil)
  wrap_impl(@impl.dispatch_event(unwrap_impl(type), eventInit: unwrap_impl(eventInit)))
end

#editable?Boolean

Returns whether the element is [editable](./actionability.md#editable).

Returns:

  • (Boolean)


287
288
289
# File 'lib/playwright_api/element_handle.rb', line 287

def editable?
  wrap_impl(@impl.editable?)
end

#enabled?Boolean

Returns whether the element is [enabled](./actionability.md#enabled).

Returns:

  • (Boolean)


292
293
294
# File 'lib/playwright_api/element_handle.rb', line 292

def enabled?
  wrap_impl(@impl.enabled?)
end

#eval_on_selector(selector, expression, arg: nil) ⇒ Object

Returns the return value of expression.

The method finds an element matching the specified selector in the ‘ElementHandle`s subtree and passes it as a first argument to expression. See [Working with selectors](./selectors.md) for more details. If no elements match the selector, the method throws an error.

If expression returns a [Promise], then [‘method: ElementHandle.evalOnSelector`] would wait for the promise to resolve and return its value.

Examples:

“‘python sync tweet_handle = page.query_selector(“.tweet”) assert tweet_handle.eval_on_selector(“.like”, “node => node.innerText”) == “100” assert tweet_handle.eval_on_selector(“.retweets”, “node => node.innerText”) = “10” “`



189
190
191
# File 'lib/playwright_api/element_handle.rb', line 189

def eval_on_selector(selector, expression, arg: nil)
  wrap_impl(@impl.eval_on_selector(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#eval_on_selector_all(selector, expression, arg: nil) ⇒ Object

Returns the return value of expression.

The method finds all elements matching the specified selector in the ElementHandle‘s subtree and passes an array of matched elements as a first argument to expression. See [Working with selectors](./selectors.md) for more details.

If expression returns a [Promise], then [‘method: ElementHandle.evalOnSelectorAll`] would wait for the promise to resolve and return its value.

Examples:

“‘html <div class=“feed”>

<div class="tweet">Hello!</div>
<div class="tweet">Hi!</div>

</div> “‘

“‘python sync feed_handle = page.query_selector(“.feed”) assert feed_handle.eval_on_selector_all(“.tweet”, “nodes => nodes.map(n => n.innerText)”) == [“hello!”, “hi!”] “`



214
215
216
# File 'lib/playwright_api/element_handle.rb', line 214

def eval_on_selector_all(selector, expression, arg: nil)
  wrap_impl(@impl.eval_on_selector_all(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg)))
end

#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers an input event after filling. Note that you can pass an empty string to clear the input field.

If the target element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be filled instead.

To send fine-grained keyboard events, use [‘method: ElementHandle.type`].



227
228
229
# File 'lib/playwright_api/element_handle.rb', line 227

def fill(value, force: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.fill(unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#focusObject



232
233
234
# File 'lib/playwright_api/element_handle.rb', line 232

def focus
  wrap_impl(@impl.focus)
end

#get_attribute(name) ⇒ Object Also known as: []

Returns element attribute value.



237
238
239
# File 'lib/playwright_api/element_handle.rb', line 237

def get_attribute(name)
  wrap_impl(@impl.get_attribute(unwrap_impl(name)))
end

#hidden?Boolean

Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).

Returns:

  • (Boolean)


297
298
299
# File 'lib/playwright_api/element_handle.rb', line 297

def hidden?
  wrap_impl(@impl.hidden?)
end

#hover(force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object

This method hovers over the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.mouse`] to hover over the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



252
253
254
255
256
257
258
259
# File 'lib/playwright_api/element_handle.rb', line 252

def hover(
      force: nil,
      modifiers: nil,
      position: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.hover(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#inner_htmlObject

Returns the element.innerHTML.



262
263
264
# File 'lib/playwright_api/element_handle.rb', line 262

def inner_html
  wrap_impl(@impl.inner_html)
end

#inner_textObject

Returns the element.innerText.



267
268
269
# File 'lib/playwright_api/element_handle.rb', line 267

def inner_text
  wrap_impl(@impl.inner_text)
end

#input_value(timeout: nil) ⇒ Object

Returns input.value for ‘<input>` or `<textarea>` element. Throws for non-input elements.



272
273
274
# File 'lib/playwright_api/element_handle.rb', line 272

def input_value(timeout: nil)
  wrap_impl(@impl.input_value(timeout: unwrap_impl(timeout)))
end

#off(event, callback) ⇒ Object

– inherited from EventEmitter –



546
547
548
# File 'lib/playwright_api/element_handle.rb', line 546

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

– inherited from EventEmitter –



540
541
542
# File 'lib/playwright_api/element_handle.rb', line 540

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

– inherited from EventEmitter –



534
535
536
# File 'lib/playwright_api/element_handle.rb', line 534

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#owner_frameObject

Returns the frame containing the given element.



307
308
309
# File 'lib/playwright_api/element_handle.rb', line 307

def owner_frame
  wrap_impl(@impl.owner_frame)
end

#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

Focuses the element, and then uses [‘method: Keyboard.down`] and [`method: Keyboard.up`].

key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:

F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.

Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.

Holding down Shift will type the text that corresponds to the key in the upper case.

If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.

Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When specified with the modifier, modifier is pressed and being held while the subsequent key is being pressed.



329
330
331
# File 'lib/playwright_api/element_handle.rb', line 329

def press(key, delay: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.press(unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#query_selector(selector) ⇒ Object

The method finds an element matching the specified selector in the ElementHandle‘s subtree. See [Working with selectors](./selectors.md) for more details. If no elements match the selector, returns null.



335
336
337
# File 'lib/playwright_api/element_handle.rb', line 335

def query_selector(selector)
  wrap_impl(@impl.query_selector(unwrap_impl(selector)))
end

#query_selector_all(selector) ⇒ Object

The method finds all elements matching the specified selector in the ‘ElementHandle`s subtree. See [Working with selectors](./selectors.md) for more details. If no elements match the selector, returns empty array.



341
342
343
# File 'lib/playwright_api/element_handle.rb', line 341

def query_selector_all(selector)
  wrap_impl(@impl.query_selector_all(unwrap_impl(selector)))
end

#screenshot(omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) ⇒ Object

Returns the buffer with the captured screenshot.

This method waits for the [actionability](./actionability.md) checks, then scrolls element into view before taking a screenshot. If the element is detached from DOM, the method throws an error.



349
350
351
352
353
354
355
356
# File 'lib/playwright_api/element_handle.rb', line 349

def screenshot(
      omitBackground: nil,
      path: nil,
      quality: nil,
      timeout: nil,
      type: nil)
  wrap_impl(@impl.screenshot(omitBackground: unwrap_impl(omitBackground), path: unwrap_impl(path), quality: unwrap_impl(quality), timeout: unwrap_impl(timeout), type: unwrap_impl(type)))
end

#scroll_into_view_if_needed(timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, then tries to scroll element into view, unless it is completely visible as defined by [IntersectionObserver](developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API)‘s ratio.

Throws when elementHandle does not point to an element [connected](developer.mozilla.org/en-US/docs/Web/API/Node/isConnected) to a Document or a ShadowRoot.



364
365
366
# File 'lib/playwright_api/element_handle.rb', line 364

def scroll_into_view_if_needed(timeout: nil)
  wrap_impl(@impl.scroll_into_view_if_needed(timeout: unwrap_impl(timeout)))
end

#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.

If the target element is not a ‘<select>` element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be used instead.

Returns the array of option values that have been successfully selected.

Triggers a change and input event once all the provided options have been selected.

“‘python sync # single selection matching the value handle.select_option(“blue”) # single selection matching both the label handle.select_option(label=“blue”) # multiple selection handle.select_option(value=[“red”, “green”, “blue”]) “`

“‘python sync # single selection matching the value handle.select_option(“blue”) # single selection matching both the value and the label handle.select_option(label=“blue”) # multiple selection handle.select_option(“red”, “green”, “blue”) # multiple selection for blue, red and second option handle.select_option(value=“blue”, { index: 2 }, “red”) “`



398
399
400
401
402
403
404
405
406
407
# File 'lib/playwright_api/element_handle.rb', line 398

def select_option(
      element: nil,
      index: nil,
      value: nil,
      label: nil,
      force: nil,
      noWaitAfter: nil,
      timeout: nil)
  wrap_impl(@impl.select_option(element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#select_text(force: nil, timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, then focuses the element and selects all its text content.



411
412
413
# File 'lib/playwright_api/element_handle.rb', line 411

def select_text(force: nil, timeout: nil)
  wrap_impl(@impl.select_text(force: unwrap_impl(force), timeout: unwrap_impl(timeout)))
end

#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object Also known as: input_files=

This method expects elementHandle to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input).

Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the the current working directory. For empty array, clears the selected files.



420
421
422
# File 'lib/playwright_api/element_handle.rb', line 420

def set_input_files(files, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.set_input_files(unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object

This method taps the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.

> NOTE: ‘elementHandle.tap()` requires that the hasTouch option of the browser context be set to true.



437
438
439
440
441
442
443
444
445
# File 'lib/playwright_api/element_handle.rb', line 437

def tap_point(
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.tap_point(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#text_contentObject

Returns the node.textContent.



448
449
450
# File 'lib/playwright_api/element_handle.rb', line 448

def text_content
  wrap_impl(@impl.text_content)
end

#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

Focuses the element, and then sends a keydown, keypress/input, and keyup event for each character in the text.

To press a special key, like Control or ArrowDown, use [‘method: ElementHandle.press`].

“‘python sync element_handle.type(“hello”) # types instantly element_handle.type(“world”, delay=100) # types slower, like a user “`

An example of typing into a text field and then submitting the form:

“‘python sync element_handle = page.query_selector(“input”) element_handle.type(“some text”) element_handle.press(“Enter”) “`



468
469
470
# File 'lib/playwright_api/element_handle.rb', line 468

def type(text, delay: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.type(unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout)))
end

#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object

This method checks the element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.

  2. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to click in the center of the element.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  6. Ensure that the element is now unchecked. If not, this method throws.

If the element is detached from the DOM at any moment during the action, this method throws.

When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.



485
486
487
488
489
490
491
492
# File 'lib/playwright_api/element_handle.rb', line 485

def uncheck(
      force: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil,
      trial: nil)
  wrap_impl(@impl.uncheck(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial)))
end

#visible?Boolean

Returns whether the element is [visible](./actionability.md#visible).

Returns:

  • (Boolean)


302
303
304
# File 'lib/playwright_api/element_handle.rb', line 302

def visible?
  wrap_impl(@impl.visible?)
end

#wait_for_element_state(state, timeout: nil) ⇒ Object

Returns when the element satisfies the state.

Depending on the state parameter, this method waits for one of the [actionability](./actionability.md) checks to pass. This method throws when the element is detached while waiting, unless waiting for the ‘“hidden”` state.

  • ‘“visible”` Wait until the element is [visible](./actionability.md#visible).

  • ‘“hidden”` Wait until the element is [not visible](./actionability.md#visible) or [not attached](./actionability.md#attached). Note that waiting for hidden does not throw when the element detaches.

  • ‘“stable”` Wait until the element is both [visible](./actionability.md#visible) and [stable](./actionability.md#stable).

  • ‘“enabled”` Wait until the element is [enabled](./actionability.md#enabled).

  • ‘“disabled”` Wait until the element is [not enabled](./actionability.md#enabled).

  • ‘“editable”` Wait until the element is [editable](./actionability.md#editable).

If the element does not satisfy the condition for the timeout milliseconds, this method will throw.



508
509
510
# File 'lib/playwright_api/element_handle.rb', line 508

def wait_for_element_state(state, timeout: nil)
  wrap_impl(@impl.wait_for_element_state(unwrap_impl(state), timeout: unwrap_impl(timeout)))
end

#wait_for_selector(selector, state: nil, timeout: nil) ⇒ Object

Returns element specified by selector when it satisfies state option. Returns null if waiting for hidden or detached.

Wait for the selector relative to the element handle to satisfy state option (either appear/disappear from dom, or become visible/hidden). If at the moment of calling the method selector already satisfies the condition, the method will return immediately. If the selector doesn’t satisfy the condition for the timeout milliseconds, the function will throw.

“‘python sync page.set_content(“<div><span></span></div>”) div = page.query_selector(“div”) # waiting for the “span” selector relative to the div. span = div.wait_for_selector(“span”, state=“attached”) “`

> NOTE: This method does not work across navigations, use [‘method: Page.waitForSelector`] instead.



528
529
530
# File 'lib/playwright_api/element_handle.rb', line 528

def wait_for_selector(selector, state: nil, timeout: nil)
  wrap_impl(@impl.wait_for_selector(unwrap_impl(selector), state: unwrap_impl(state), timeout: unwrap_impl(timeout)))
end