Class: Playwright::ElementHandle

Inherits:
JSHandle show all
Defined in:
lib/playwright_api/element_handle.rb

Overview

  • extends: JSHandle

ElementHandle represents an in-page DOM element. ElementHandles can be created with the [‘method: Page.$`] method.

“‘js const { chromium } = require(’playwright’); // Or ‘firefox’ or ‘webkit’.

(async () =>

const browser = await chromium.launch();
const page = await browser.newPage();
await page.goto('https://example.com');
const hrefElement = await page.$('a');
await hrefElement.click();
// ...

)(); “‘

“‘python async import asyncio from playwright.async_api import async_playwright

async def run(playwright):

chromium = playwright.chromium
browser = await chromium.launch()
page = await browser.new_page()
await page.goto("https://example.com")
href_element = await page.query_selector("a")
await href_element.click()
# ...

async def main():

async with async_playwright() as playwright:
    await run(playwright)

asyncio.run(main()) “‘

“‘python sync from playwright.sync_api import sync_playwright

def run(playwright):

chromium = playwright.chromium
browser = chromium.launch()
page = browser.new_page()
page.goto("https://example.com")
href_element = page.query_selector("a")
href_element.click()
# ...

with sync_playwright() as playwright:

run(playwright)

“‘

ElementHandle prevents DOM element from garbage collection unless the handle is disposed with [‘method: JSHandle.dispose`]. ElementHandles are auto-disposed when their origin frame gets navigated.

ElementHandle instances can be used as an argument in [‘method: Page.$eval`] and [`method: Page.evaluate`] methods.

Instance Method Summary collapse

Methods inherited from JSHandle

#as_element, #dispose, #evaluate, #evaluate_handle, #get_properties, #get_property, #json_value

Methods inherited from PlaywrightApi

#==, from_channel_owner, #initialize

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#bounding_boxObject

This method returns the bounding box of the element, or null if the element is not visible. The bounding box is calculated relative to the main frame viewport - which is usually the same as the browser window.

Scrolling affects the returned bonding box, similarly to [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect). That means x and/or y may be negative.

Elements from child frames return the bounding box relative to the main frame, unlike the [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect).

Assuming the page is static, it is safe to use bounding box coordinates to perform input. For example, the following snippet should click the center of the element.

“‘js const box = await elementHandle.boundingBox(); await page.mouse.click(box.x + box.width / 2, box.y + box.height / 2); “`

“‘python async box = await element_handle.bounding_box() await page.mouse.click(box + box / 2, box + box / 2) “`

“‘python sync box = element_handle.bounding_box() page.mouse.click(box + box / 2, box + box / 2) “`

Raises:

  • (NotImplementedError)


174
175
176
# File 'lib/playwright_api/element_handle.rb', line 174

def bounding_box
  raise NotImplementedError.new('bounding_box is not implemented yet.')
end

#check(force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

This method checks the element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method rejects. If the element is already checked, this method returns immediately.

  2. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to click in the center of the element.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  6. Ensure that the element is now checked. If not, this method rejects.

If the element is detached from the DOM at any moment during the action, this method rejects.

When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.

Raises:

  • (NotImplementedError)


191
192
193
# File 'lib/playwright_api/element_handle.rb', line 191

def check(force: nil, noWaitAfter: nil, timeout: nil)
  raise NotImplementedError.new('check is not implemented yet.')
end

#checked?Boolean

Returns whether the element is checked. Throws if the element is not a checkbox or radio input.

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


341
342
343
# File 'lib/playwright_api/element_handle.rb', line 341

def checked?
  raise NotImplementedError.new('checked? is not implemented yet.')
end

#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object

This method clicks the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.mouse`] to click in the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method rejects.

When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.



205
206
207
208
209
210
211
212
213
214
215
# File 'lib/playwright_api/element_handle.rb', line 205

def click(
      button: nil,
      clickCount: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil)
  wrap_impl(@impl.click(button: button, clickCount: clickCount, delay: delay, force: force, modifiers: modifiers, noWaitAfter: noWaitAfter, position: position, timeout: timeout))
end

#content_frameObject

Returns the content frame for element handles referencing iframe nodes, or null otherwise

Raises:

  • (NotImplementedError)


218
219
220
# File 'lib/playwright_api/element_handle.rb', line 218

def content_frame
  raise NotImplementedError.new('content_frame is not implemented yet.')
end

#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object

This method double clicks the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.mouse`] to double click in the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will reject.

If the element is detached from the DOM at any moment during the action, this method rejects.

When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.

> NOTE: ‘elementHandle.dblclick()` dispatches two click events and a single dblclick event.

Raises:

  • (NotImplementedError)


235
236
237
238
239
240
241
242
243
244
# File 'lib/playwright_api/element_handle.rb', line 235

def dblclick(
      button: nil,
      delay: nil,
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil)
  raise NotImplementedError.new('dblclick is not implemented yet.')
end

#disabled?Boolean

Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


346
347
348
# File 'lib/playwright_api/element_handle.rb', line 346

def disabled?
  raise NotImplementedError.new('disabled? is not implemented yet.')
end

#dispatch_event(type, eventInit: nil) ⇒ Object

The snippet below dispatches the click event on the element. Regardless of the visibility state of the elment, click is dispatched. This is equivalend to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).

“‘js await elementHandle.dispatchEvent(’click’); “‘

“‘python async await element_handle.dispatch_event(“click”) “`

“‘python sync element_handle.dispatch_event(“click”) “`

Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.

Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:

You can also specify JSHandle as the property value if you want live objects to be passed into the event:

“‘js // Note you can only create DataTransfer in Chromium and Firefox const dataTransfer = await page.evaluateHandle(() => new DataTransfer()); await elementHandle.dispatchEvent(’dragstart’, { dataTransfer }); “‘

“‘python async # note you can only create data_transfer in chromium and firefox data_transfer = await page.evaluate_handle(“new DataTransfer()”) await element_handle.dispatch_event(“#source”, “dragstart”, data_transfer) “`

“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = page.evaluate_handle(“new DataTransfer()”) element_handle.dispatch_event(“#source”, “dragstart”, data_transfer) “`

Raises:

  • (NotImplementedError)


295
296
297
# File 'lib/playwright_api/element_handle.rb', line 295

def dispatch_event(type, eventInit: nil)
  raise NotImplementedError.new('dispatch_event is not implemented yet.')
end

#editable?Boolean

Returns whether the element is [editable](./actionability.md#editable).

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


351
352
353
# File 'lib/playwright_api/element_handle.rb', line 351

def editable?
  raise NotImplementedError.new('editable? is not implemented yet.')
end

#enabled?Boolean

Returns whether the element is [enabled](./actionability.md#enabled).

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


356
357
358
# File 'lib/playwright_api/element_handle.rb', line 356

def enabled?
  raise NotImplementedError.new('enabled? is not implemented yet.')
end

#eval_on_selector(selector, pageFunction, arg: nil) ⇒ Object

Returns the return value of pageFunction

The method finds an element matching the specified selector in the ‘ElementHandle`s subtree and passes it as a first argument to pageFunction. See [Working with selectors](./selectors.md#working-with-selectors) for more details. If no elements match the selector, the method throws an error.

If pageFunction returns a [Promise], then ‘frame.$eval` would wait for the promise to resolve and return its value.

Examples:

“‘js const tweetHandle = await page.$(’.tweet’); expect(await tweetHandle.$eval(‘.like’, node => node.innerText)).toBe(‘100’); expect(await tweetHandle.$eval(‘.retweets’, node => node.innerText)).toBe(‘10’); “‘

“‘python async tweet_handle = await page.query_selector(“.tweet”) assert await tweet_handle.eval_on_selector(“.like”, “node => node.innerText”) == “100” assert await tweet_handle.eval_on_selector(“.retweets”, “node => node.innerText”) = “10” “`

“‘python sync tweet_handle = page.query_selector(“.tweet”) assert tweet_handle.eval_on_selector(“.like”, “node => node.innerText”) == “100” assert tweet_handle.eval_on_selector(“.retweets”, “node => node.innerText”) = “10” “`



105
106
107
# File 'lib/playwright_api/element_handle.rb', line 105

def eval_on_selector(selector, pageFunction, arg: nil)
  wrap_impl(@impl.eval_on_selector(selector, pageFunction, arg: arg))
end

#eval_on_selector_all(selector, pageFunction, arg: nil) ⇒ Object

Returns the return value of pageFunction

The method finds all elements matching the specified selector in the ElementHandle‘s subtree and passes an array of matched elements as a first argument to pageFunction. See [Working with selectors](./selectors.md#working-with-selectors) for more details.

If pageFunction returns a [Promise], then ‘frame.$$eval` would wait for the promise to resolve and return its value.

Examples:

“‘html <div class=“feed”>

<div class="tweet">Hello!</div>
<div class="tweet">Hi!</div>

</div> “‘

“‘js const feedHandle = await page.$(’.feed’); expect(await feedHandle.$$eval(‘.tweet’, nodes => nodes.map(n => n.innerText))).toEqual([‘Hello!’, ‘Hi!’]); “‘

“‘python async # FIXME feed_handle = await page.query_selector(“.feed”) assert await feed_handle.eval_on_selector_all(“.tweet”, “nodes => nodes.map(n => n.innerText)”) == [“hello!”, “hi!”] “`

“‘python sync feed_handle = page.query_selector(“.feed”) assert feed_handle.eval_on_selector_all(“.tweet”, “nodes => nodes.map(n => n.innerText)”) == [“hello!”, “hi!”] “`



142
143
144
# File 'lib/playwright_api/element_handle.rb', line 142

def eval_on_selector_all(selector, pageFunction, arg: nil)
  wrap_impl(@impl.eval_on_selector_all(selector, pageFunction, arg: arg))
end

#fill(value, noWaitAfter: nil, timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers an input event after filling. If the element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. Note that you can pass an empty string to clear the input field.

Raises:

  • (NotImplementedError)


302
303
304
# File 'lib/playwright_api/element_handle.rb', line 302

def fill(value, noWaitAfter: nil, timeout: nil)
  raise NotImplementedError.new('fill is not implemented yet.')
end

#focusObject

Raises:

  • (NotImplementedError)


307
308
309
# File 'lib/playwright_api/element_handle.rb', line 307

def focus
  raise NotImplementedError.new('focus is not implemented yet.')
end

#get_attribute(name) ⇒ Object

Returns element attribute value.

Raises:

  • (NotImplementedError)


312
313
314
# File 'lib/playwright_api/element_handle.rb', line 312

def get_attribute(name)
  raise NotImplementedError.new('get_attribute is not implemented yet.')
end

#hidden?Boolean

Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


361
362
363
# File 'lib/playwright_api/element_handle.rb', line 361

def hidden?
  raise NotImplementedError.new('hidden? is not implemented yet.')
end

#hover(force: nil, modifiers: nil, position: nil, timeout: nil) ⇒ Object

This method hovers over the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.mouse`] to hover over the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method rejects.

When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.

Raises:

  • (NotImplementedError)


326
327
328
# File 'lib/playwright_api/element_handle.rb', line 326

def hover(force: nil, modifiers: nil, position: nil, timeout: nil)
  raise NotImplementedError.new('hover is not implemented yet.')
end

#inner_htmlObject

Returns the element.innerHTML.

Raises:

  • (NotImplementedError)


331
332
333
# File 'lib/playwright_api/element_handle.rb', line 331

def inner_html
  raise NotImplementedError.new('inner_html is not implemented yet.')
end

#inner_textObject

Returns the element.innerText.

Raises:

  • (NotImplementedError)


336
337
338
# File 'lib/playwright_api/element_handle.rb', line 336

def inner_text
  raise NotImplementedError.new('inner_text is not implemented yet.')
end

#off(event, callback) ⇒ Object

– inherited from EventEmitter –



636
637
638
# File 'lib/playwright_api/element_handle.rb', line 636

def off(event, callback)
  wrap_impl(@impl.off(event, callback))
end

#on(event, callback) ⇒ Object

– inherited from EventEmitter –



630
631
632
# File 'lib/playwright_api/element_handle.rb', line 630

def on(event, callback)
  wrap_impl(@impl.on(event, callback))
end

#once(event, callback) ⇒ Object

– inherited from EventEmitter –



642
643
644
# File 'lib/playwright_api/element_handle.rb', line 642

def once(event, callback)
  wrap_impl(@impl.once(event, callback))
end

#owner_frameObject

Returns the frame containing the given element.

Raises:

  • (NotImplementedError)


371
372
373
# File 'lib/playwright_api/element_handle.rb', line 371

def owner_frame
  raise NotImplementedError.new('owner_frame is not implemented yet.')
end

#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

Focuses the element, and then uses [‘method: Keyboard.down`] and [`method: Keyboard.up`].

key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:

F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.

Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.

Holding down Shift will type the text that corresponds to the key in the upper case.

If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.

Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When speficied with the modifier, modifier is pressed and being held while the subsequent key is being pressed.



393
394
395
# File 'lib/playwright_api/element_handle.rb', line 393

def press(key, delay: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.press(key, delay: delay, noWaitAfter: noWaitAfter, timeout: timeout))
end

#query_selector(selector) ⇒ Object

The method finds an element matching the specified selector in the ElementHandle‘s subtree. See [Working with selectors](./selectors.md#working-with-selectors) for more details. If no elements match the selector, returns null.



66
67
68
# File 'lib/playwright_api/element_handle.rb', line 66

def query_selector(selector)
  wrap_impl(@impl.query_selector(selector))
end

#query_selector_all(selector) ⇒ Object

The method finds all elements matching the specified selector in the ‘ElementHandle`s subtree. See [Working with selectors](./selectors.md#working-with-selectors) for more details. If no elements match the selector, returns empty array.



73
74
75
# File 'lib/playwright_api/element_handle.rb', line 73

def query_selector_all(selector)
  wrap_impl(@impl.query_selector_all(selector))
end

#screenshot(omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) ⇒ Object

Returns the buffer with the captured screenshot.

This method waits for the [actionability](./actionability.md) checks, then scrolls element into view before taking a screenshot. If the element is detached from DOM, the method throws an error.

Raises:

  • (NotImplementedError)


401
402
403
404
405
406
407
408
# File 'lib/playwright_api/element_handle.rb', line 401

def screenshot(
      omitBackground: nil,
      path: nil,
      quality: nil,
      timeout: nil,
      type: nil)
  raise NotImplementedError.new('screenshot is not implemented yet.')
end

#scroll_into_view_if_needed(timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, then tries to scroll element into view, unless it is completely visible as defined by [IntersectionObserver](developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API)‘s ratio.

Throws when elementHandle does not point to an element [connected](developer.mozilla.org/en-US/docs/Web/API/Node/isConnected) to a Document or a ShadowRoot.

Raises:

  • (NotImplementedError)


416
417
418
# File 'lib/playwright_api/element_handle.rb', line 416

def scroll_into_view_if_needed(timeout: nil)
  raise NotImplementedError.new('scroll_into_view_if_needed is not implemented yet.')
end

#select_option(values, noWaitAfter: nil, timeout: nil) ⇒ Object

Returns the array of option values that have been successfully selected.

Triggers a change and input event once all the provided options have been selected. If element is not a ‘<select>` element, the method throws an error.

Will wait until all specified options are present in the ‘<select>` element.

“‘js // single selection matching the value handle.selectOption(’blue’);

// single selection matching the label handle.selectOption({ label: ‘Blue’ });

// multiple selection handle.selectOption([‘red’, ‘green’, ‘blue’]); “‘

“‘python async # single selection matching the value await handle.select_option(“blue”) # single selection matching the label await handle.select_option(label=“blue”) # multiple selection await handle.select_option(value=[“red”, “green”, “blue”]) “`

“‘python sync # single selection matching the value handle.select_option(“blue”) # single selection matching both the label handle.select_option(label=“blue”) # multiple selection handle.select_option(value=[“red”, “green”, “blue”]) “`

“‘python sync # FIXME # single selection matching the value handle.select_option(“blue”) # single selection matching both the value and the label handle.select_option(label=“blue”) # multiple selection handle.select_option(“red”, “green”, “blue”) # multiple selection for blue, red and second option handle.select_option(value=“blue”, { index: 2 }, “red”) “`

Raises:

  • (NotImplementedError)


468
469
470
# File 'lib/playwright_api/element_handle.rb', line 468

def select_option(values, noWaitAfter: nil, timeout: nil)
  raise NotImplementedError.new('select_option is not implemented yet.')
end

#select_text(timeout: nil) ⇒ Object

This method waits for [actionability](./actionability.md) checks, then focuses the element and selects all its text content.

Raises:

  • (NotImplementedError)


474
475
476
# File 'lib/playwright_api/element_handle.rb', line 474

def select_text(timeout: nil)
  raise NotImplementedError.new('select_text is not implemented yet.')
end

#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object Also known as: input_files=

This method expects elementHandle to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input).

Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the the current working directory. For empty array, clears the selected files.

Raises:

  • (NotImplementedError)


483
484
485
# File 'lib/playwright_api/element_handle.rb', line 483

def set_input_files(files, noWaitAfter: nil, timeout: nil)
  raise NotImplementedError.new('set_input_files is not implemented yet.')
end

#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object

This method taps the element by performing the following steps:

  1. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  2. Scroll the element into view if needed.

  3. Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified position.

  4. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

If the element is detached from the DOM at any moment during the action, this method rejects.

When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.

> NOTE: ‘elementHandle.tap()` requires that the hasTouch option of the browser context be set to true.

Raises:

  • (NotImplementedError)


500
501
502
503
504
505
506
507
# File 'lib/playwright_api/element_handle.rb', line 500

def tap_point(
      force: nil,
      modifiers: nil,
      noWaitAfter: nil,
      position: nil,
      timeout: nil)
  raise NotImplementedError.new('tap_point is not implemented yet.')
end

#text_contentObject

Returns the node.textContent.

Raises:

  • (NotImplementedError)


510
511
512
# File 'lib/playwright_api/element_handle.rb', line 510

def text_content
  raise NotImplementedError.new('text_content is not implemented yet.')
end

#type_text(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

Focuses the element, and then sends a keydown, keypress/input, and keyup event for each character in the text.

To press a special key, like Control or ArrowDown, use [‘method: ElementHandle.press`].

“‘js await elementHandle.type(’Hello’); // Types instantly await elementHandle.type(‘World’, 100); // Types slower, like a user “‘

“‘python async await element_handle.type(“hello”) # types instantly await element_handle.type(“world”, delay=100) # types slower, like a user “`

“‘python sync element_handle.type(“hello”) # types instantly element_handle.type(“world”, delay=100) # types slower, like a user “`

An example of typing into a text field and then submitting the form:

“‘js const elementHandle = await page.$(’input’); await elementHandle.type(‘some text’); await elementHandle.press(‘Enter’); “‘

“‘python async element_handle = await page.query_selector(“input”) await element_handle.type(“some text”) await element_handle.press(“Enter”) “`

“‘python sync element_handle = page.query_selector(“input”) element_handle.type(“some text”) element_handle.press(“Enter”) “`



554
555
556
# File 'lib/playwright_api/element_handle.rb', line 554

def type_text(text, delay: nil, noWaitAfter: nil, timeout: nil)
  wrap_impl(@impl.type_text(text, delay: delay, noWaitAfter: noWaitAfter, timeout: timeout))
end

#uncheck(force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object

This method checks the element by performing the following steps:

  1. Ensure that element is a checkbox or a radio input. If not, this method rejects. If the element is already unchecked, this method returns immediately.

  2. Wait for [actionability](./actionability.md) checks on the element, unless force option is set.

  3. Scroll the element into view if needed.

  4. Use [‘property: Page.mouse`] to click in the center of the element.

  5. Wait for initiated navigations to either succeed or fail, unless noWaitAfter option is set.

  6. Ensure that the element is now unchecked. If not, this method rejects.

If the element is detached from the DOM at any moment during the action, this method rejects.

When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.

Raises:

  • (NotImplementedError)


571
572
573
# File 'lib/playwright_api/element_handle.rb', line 571

def uncheck(force: nil, noWaitAfter: nil, timeout: nil)
  raise NotImplementedError.new('uncheck is not implemented yet.')
end

#visible?Boolean

Returns whether the element is [visible](./actionability.md#visible).

Returns:

  • (Boolean)

Raises:

  • (NotImplementedError)


366
367
368
# File 'lib/playwright_api/element_handle.rb', line 366

def visible?
  raise NotImplementedError.new('visible? is not implemented yet.')
end

#wait_for_element_state(state, timeout: nil) ⇒ Object

Returns when the element satisfies the state.

Depending on the state parameter, this method waits for one of the [actionability](./actionability.md) checks to pass. This method throws when the element is detached while waiting, unless waiting for the ‘“hidden”` state.

  • ‘“visible”` Wait until the element is [visible](./actionability.md#visible).

  • ‘“hidden”` Wait until the element is [not visible](./actionability.md#visible) or [not attached](./actionability.md#attached). Note that waiting for hidden does not throw when the element detaches.

  • ‘“stable”` Wait until the element is both [visible](./actionability.md#visible) and [stable](./actionability.md#stable).

  • ‘“enabled”` Wait until the element is [enabled](./actionability.md#enabled).

  • ‘“disabled”` Wait until the element is [not enabled](./actionability.md#enabled).

  • ‘“editable”` Wait until the element is [editable](./actionability.md#editable).

If the element does not satisfy the condition for the timeout milliseconds, this method will throw.

Raises:

  • (NotImplementedError)


589
590
591
# File 'lib/playwright_api/element_handle.rb', line 589

def wait_for_element_state(state, timeout: nil)
  raise NotImplementedError.new('wait_for_element_state is not implemented yet.')
end

#wait_for_selector(selector, state: nil, timeout: nil) ⇒ Object

Returns element specified by selector when it satisfies state option. Returns null if waiting for hidden or detached.

Wait for the selector relative to the element handle to satisfy state option (either appear/disappear from dom, or become visible/hidden). If at the moment of calling the method selector already satisfies the condition, the method will return immediately. If the selector doesn’t satisfy the condition for the timeout milliseconds, the function will throw.

“‘js await page.setContent(`<div><span></span></div>`); const div = await page.$(’div’); // Waiting for the ‘span’ selector relative to the div. const span = await div.waitForSelector(‘span’, { state: ‘attached’ }); “‘

“‘python async await page.set_content(“<div><span></span></div>”) div = await page.query_selector(“div”) # waiting for the “span” selector relative to the div. span = await div.wait_for_selector(“span”, state=“attached”) “`

“‘python sync page.set_content(“<div><span></span></div>”) div = page.query_selector(“div”) # waiting for the “span” selector relative to the div. span = div.wait_for_selector(“span”, state=“attached”) “`

> NOTE: This method does not work across navigations, use [‘method: Page.waitForSelector`] instead.

Raises:

  • (NotImplementedError)


624
625
626
# File 'lib/playwright_api/element_handle.rb', line 624

def wait_for_selector(selector, state: nil, timeout: nil)
  raise NotImplementedError.new('wait_for_selector is not implemented yet.')
end