Class: Playwright::Frame
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Frame
- Defined in:
- lib/playwright_api/frame.rb
Overview
At every point of time, page exposes its current frame tree via the [‘method: Page.mainFrame`] and
- ‘method: Frame.childFrames`
-
methods.
Frame object’s lifecycle is controlled by three events, dispatched on the page object:
- ‘event: Page.frameAttached`
-
fired when the frame gets attached to the page. A Frame can be attached to the page
-
only once.
- ‘event: Page.frameNavigated`
-
fired when the frame commits navigation to a different URL.
-
- ‘event: Page.frameDetached`
-
fired when the frame gets detached from the page. A Frame can be detached from the
-
page only once.
An example of dumping frame tree:
“‘python sync from playwright.sync_api import sync_playwright
def run(playwright):
firefox = playwright.firefox
browser = firefox.launch()
page = browser.new_page()
page.goto("https://www.theverge.com")
dump_frame_tree(page.main_frame, "")
browser.close()
def dump_frame_tree(frame, indent):
print(indent + frame.name + '@' + frame.url)
for child in frame.child_frames:
dump_frame_tree(child, indent + " ")
with sync_playwright() as playwright:
run(playwright)
“‘
Instance Method Summary collapse
-
#add_script_tag(content: nil, path: nil, type: nil, url: nil) ⇒ Object
Returns the added tag when the script’s onload fires or when the script content was injected into frame.
-
#add_style_tag(content: nil, path: nil, url: nil) ⇒ Object
Returns the added tag when the stylesheet’s onload fires or when the CSS content was injected into frame.
-
#check(selector, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks an element matching
selectorby performing the following steps: 1. -
#checked?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is checked.
- #child_frames ⇒ Object
-
#click(selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method clicks an element matching
selectorby performing the following steps: 1. -
#content ⇒ Object
Gets the full HTML contents of the frame, including the doctype.
-
#dblclick(selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method double clicks an element matching
selectorby performing the following steps: 1. - #detached=(req) ⇒ Object
-
#detached? ⇒ Boolean
Returns
trueif the frame has been detached, orfalseotherwise. -
#disabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).
-
#dispatch_event(selector, type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the
clickevent on the element. -
#editable?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [editable](./actionability.md#editable).
-
#enabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](./actionability.md#enabled).
-
#eval_on_selector(selector, expression, arg: nil) ⇒ Object
Returns the return value of
expression. -
#eval_on_selector_all(selector, expression, arg: nil) ⇒ Object
Returns the return value of
expression. -
#evaluate(expression, arg: nil) ⇒ Object
Returns the return value of
expression. -
#evaluate_handle(expression, arg: nil) ⇒ Object
Returns the return value of
expressionas aJSHandle. -
#expect_navigation(timeout: nil, url: nil, waitUntil: nil, &block) ⇒ Object
Waits for the frame navigation and returns the main resource response.
-
#fill(selector, value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for an element matching
selector, waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers aninputevent after filling. -
#focus(selector, timeout: nil) ⇒ Object
This method fetches an element with
selectorand focuses it. -
#frame_element ⇒ Object
Returns the
frameoriframeelement handle which corresponds to this frame. -
#get_attribute(selector, name, timeout: nil) ⇒ Object
Returns element attribute value.
-
#goto(url, referer: nil, timeout: nil, waitUntil: nil) ⇒ Object
Returns the main resource response.
-
#hidden?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).
-
#hover(selector, force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method hovers over an element matching
selectorby performing the following steps: 1. -
#inner_html(selector, timeout: nil) ⇒ Object
Returns
element.innerHTML. -
#inner_text(selector, timeout: nil) ⇒ Object
Returns
element.innerText. -
#input_value(selector, timeout: nil) ⇒ Object
Returns
input.valuefor the selected ‘<input>` or `<textarea>` element. -
#name ⇒ Object
Returns frame’s name attribute as specified in the tag.
-
#off(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#on(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#once(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#page ⇒ Object
Returns the page containing this frame.
-
#parent_frame ⇒ Object
Parent frame, if any.
-
#press(selector, key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
keycan specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. -
#query_selector(selector) ⇒ Object
Returns the ElementHandle pointing to the frame element.
-
#query_selector_all(selector) ⇒ Object
Returns the ElementHandles pointing to the frame elements.
-
#select_option(selector, element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for an element matching
selector, waits for [actionability](./actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options. - #set_content(html, timeout: nil, waitUntil: nil) ⇒ Object (also: #content=)
-
#set_input_files(selector, files, noWaitAfter: nil, timeout: nil) ⇒ Object
This method expects
selectorto point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input). -
#tap_point(selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method taps an element matching
selectorby performing the following steps: 1. -
#text_content(selector, timeout: nil) ⇒ Object
Returns
element.textContent. -
#title ⇒ Object
Returns the page title.
-
#type(selector, text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Sends a
keydown,keypress/input, andkeyupevent for each character in the text. -
#uncheck(selector, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks an element matching
selectorby performing the following steps: 1. -
#url ⇒ Object
Returns frame’s url.
-
#visible?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [visible](./actionability.md#visible).
-
#wait_for_function(expression, arg: nil, polling: nil, timeout: nil) ⇒ Object
Returns when the
expressionreturns a truthy value, returns that value. -
#wait_for_load_state(state: nil, timeout: nil) ⇒ Object
Waits for the required load state to be reached.
-
#wait_for_selector(selector, state: nil, timeout: nil) ⇒ Object
Returns when element specified by selector satisfies
stateoption. -
#wait_for_timeout(timeout) ⇒ Object
Waits for the given
timeoutin milliseconds. -
#wait_for_url(url, timeout: nil, waitUntil: nil) ⇒ Object
Waits for the frame to navigate to the given URL.
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#add_script_tag(content: nil, path: nil, type: nil, url: nil) ⇒ Object
Returns the added tag when the script’s onload fires or when the script content was injected into frame.
Adds a ‘<script>` tag into the page with the desired url or content.
38 39 40 |
# File 'lib/playwright_api/frame.rb', line 38 def add_script_tag(content: nil, path: nil, type: nil, url: nil) wrap_impl(@impl.add_script_tag(content: unwrap_impl(content), path: unwrap_impl(path), type: unwrap_impl(type), url: unwrap_impl(url))) end |
#add_style_tag(content: nil, path: nil, url: nil) ⇒ Object
Returns the added tag when the stylesheet’s onload fires or when the CSS content was injected into frame.
Adds a ‘<link rel=“stylesheet”>` tag into the page with the desired url or a `<style type=“text/css”>` tag with the content.
46 47 48 |
# File 'lib/playwright_api/frame.rb', line 46 def add_style_tag(content: nil, path: nil, url: nil) wrap_impl(@impl.add_style_tag(content: unwrap_impl(content), path: unwrap_impl(path), url: unwrap_impl(url))) end |
#check(selector, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks an element matching selector by performing the following steps:
-
Find an element matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Ensure that matched element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.
-
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now checked. If not, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
63 64 65 66 67 68 69 70 71 |
# File 'lib/playwright_api/frame.rb', line 63 def check( selector, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.check(unwrap_impl(selector), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#checked?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is checked. Throws if the element is not a checkbox or radio input.
368 369 370 |
# File 'lib/playwright_api/frame.rb', line 368 def checked?(selector, timeout: nil) wrap_impl(@impl.checked?(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#child_frames ⇒ Object
73 74 75 |
# File 'lib/playwright_api/frame.rb', line 73 def child_frames wrap_impl(@impl.child_frames) end |
#click(selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method clicks an element matching selector by performing the following steps:
-
Find an element matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
87 88 89 90 91 92 93 94 95 96 97 98 99 |
# File 'lib/playwright_api/frame.rb', line 87 def click( selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.click(unwrap_impl(selector), button: unwrap_impl(), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#content ⇒ Object
Gets the full HTML contents of the frame, including the doctype.
102 103 104 |
# File 'lib/playwright_api/frame.rb', line 102 def content wrap_impl(@impl.content) end |
#dblclick(selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method double clicks an element matching selector by performing the following steps:
-
Find an element matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to double click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will throw.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
> NOTE: ‘frame.dblclick()` dispatches two click events and a single dblclick event.
119 120 121 122 123 124 125 126 127 128 129 130 |
# File 'lib/playwright_api/frame.rb', line 119 def dblclick( selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.dblclick(unwrap_impl(selector), button: unwrap_impl(), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#detached=(req) ⇒ Object
697 698 699 |
# File 'lib/playwright_api/frame.rb', line 697 def detached=(req) wrap_impl(@impl.detached=(unwrap_impl(req))) end |
#detached? ⇒ Boolean
Returns true if the frame has been detached, or false otherwise.
373 374 375 |
# File 'lib/playwright_api/frame.rb', line 373 def detached? wrap_impl(@impl.detached?) end |
#disabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).
378 379 380 |
# File 'lib/playwright_api/frame.rb', line 378 def disabled?(selector, timeout: nil) wrap_impl(@impl.disabled?(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#dispatch_event(selector, type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the click event on the element. Regardless of the visibility state of the element, click is dispatched. This is equivalent to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).
“‘python sync frame.dispatch_event(“button#submit”, “click”) “`
Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.
Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:
-
[DragEvent](developer.mozilla.org/en-US/docs/Web/API/DragEvent/DragEvent)
-
[FocusEvent](developer.mozilla.org/en-US/docs/Web/API/FocusEvent/FocusEvent)
-
[KeyboardEvent](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/KeyboardEvent)
-
[MouseEvent](developer.mozilla.org/en-US/docs/Web/API/MouseEvent/MouseEvent)
-
[PointerEvent](developer.mozilla.org/en-US/docs/Web/API/PointerEvent/PointerEvent)
-
[TouchEvent](developer.mozilla.org/en-US/docs/Web/API/TouchEvent/TouchEvent)
-
[Event](developer.mozilla.org/en-US/docs/Web/API/Event/Event)
You can also specify JSHandle as the property value if you want live objects to be passed into the event:
“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = frame.evaluate_handle(“new DataTransfer()”) frame.dispatch_event(“#source”, “dragstart”, { “dataTransfer”: data_transfer }) “`
159 160 161 |
# File 'lib/playwright_api/frame.rb', line 159 def dispatch_event(selector, type, eventInit: nil, timeout: nil) wrap_impl(@impl.dispatch_event(unwrap_impl(selector), unwrap_impl(type), eventInit: unwrap_impl(eventInit), timeout: unwrap_impl(timeout))) end |
#editable?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [editable](./actionability.md#editable).
383 384 385 |
# File 'lib/playwright_api/frame.rb', line 383 def editable?(selector, timeout: nil) wrap_impl(@impl.editable?(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#enabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](./actionability.md#enabled).
388 389 390 |
# File 'lib/playwright_api/frame.rb', line 388 def enabled?(selector, timeout: nil) wrap_impl(@impl.enabled?(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#eval_on_selector(selector, expression, arg: nil) ⇒ Object
Returns the return value of expression.
The method finds an element matching the specified selector within the frame and passes it as a first argument to expression. See [Working with selectors](./selectors.md) for more details. If no elements match the selector, the method throws an error.
If expression returns a [Promise], then [‘method: Frame.evalOnSelector`] would wait for the promise to resolve and return its value.
Examples:
“‘python sync search_value = frame.eval_on_selector(“#search”, “el => el.value”) preload_href = frame.eval_on_selector(“link“, ”el => el.href“) html = frame.eval_on_selector(”.main-container“, ”(e, suffix) => e.outerHTML + suffix“, ”hello“) “`
179 180 181 |
# File 'lib/playwright_api/frame.rb', line 179 def eval_on_selector(selector, expression, arg: nil) wrap_impl(@impl.eval_on_selector(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#eval_on_selector_all(selector, expression, arg: nil) ⇒ Object
Returns the return value of expression.
The method finds all elements matching the specified selector within the frame and passes an array of matched elements as a first argument to expression. See [Working with selectors](./selectors.md) for more details.
If expression returns a [Promise], then [‘method: Frame.evalOnSelectorAll`] would wait for the promise to resolve and return its value.
Examples:
“‘python sync divs_counts = frame.eval_on_selector_all(“div”, “(divs, min) => divs.length >= min”, 10) “`
196 197 198 |
# File 'lib/playwright_api/frame.rb', line 196 def eval_on_selector_all(selector, expression, arg: nil) wrap_impl(@impl.eval_on_selector_all(unwrap_impl(selector), unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#evaluate(expression, arg: nil) ⇒ Object
Returns the return value of expression.
If the function passed to the [‘method: Frame.evaluate`] returns a [Promise], then [`method: Frame.evaluate`] would wait for the promise to resolve and return its value.
If the function passed to the [‘method: Frame.evaluate`] returns a non- value, then
- ‘method: Frame.evaluate`
-
returns
undefined. Playwright also supports transferring some additional values that are
not serializable by JSON: -0, NaN, Infinity, -Infinity.
“‘python sync result = frame.evaluate(“([x, y]) => Promise.resolve(x * y)”, [7, 8]) print(result) # prints “56” “`
A string can also be passed in instead of a function.
“‘python sync print(frame.evaluate(“1 + 2”)) # prints “3” x = 10 print(frame.evaluate(f“1 + x”)) # prints “11” “`
ElementHandle instances can be passed as an argument to the [‘method: Frame.evaluate`]:
“‘python sync body_handle = frame.query_selector(“body”) html = frame.evaluate(“([body, suffix]) => body.innerHTML + suffix”, [body_handle, “hello”]) body_handle.dispose() “`
229 230 231 |
# File 'lib/playwright_api/frame.rb', line 229 def evaluate(expression, arg: nil) wrap_impl(@impl.evaluate(unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#evaluate_handle(expression, arg: nil) ⇒ Object
Returns the return value of expression as a JSHandle.
The only difference between [‘method: Frame.evaluate`] and [`method: Frame.evaluateHandle`] is that
- ‘method: Frame.evaluateHandle`
-
returns
JSHandle.
If the function, passed to the [‘method: Frame.evaluateHandle`], returns a [Promise], then
- ‘method: Frame.evaluateHandle`
-
would wait for the promise to resolve and return its value.
“‘python sync a_window_handle = frame.evaluate_handle(“Promise.resolve(window)”) a_window_handle # handle for the window object. “`
A string can also be passed in instead of a function.
“‘python sync a_handle = page.evaluate_handle(“document”) # handle for the “document” “`
JSHandle instances can be passed as an argument to the [‘method: Frame.evaluateHandle`]:
“‘python sync a_handle = page.evaluate_handle(“document.body”) result_handle = page.evaluate_handle(“body => body.innerHTML”, a_handle) print(result_handle.json_value()) result_handle.dispose() “`
260 261 262 |
# File 'lib/playwright_api/frame.rb', line 260 def evaluate_handle(expression, arg: nil) wrap_impl(@impl.evaluate_handle(unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#expect_navigation(timeout: nil, url: nil, waitUntil: nil, &block) ⇒ Object
Waits for the frame navigation and returns the main resource response. In case of multiple redirects, the navigation will resolve with the response of the last redirect. In case of navigation to a different anchor or navigation due to History API usage, the navigation will resolve with null.
This method waits for the frame to navigate to a new URL. It is useful for when you run code which will indirectly cause the frame to navigate. Consider this example:
“‘python sync with frame.expect_navigation():
frame.click("a.delayed-navigation") # clicking the link will indirectly cause a navigation
# Resolves after navigation has finished “‘
> NOTE: Usage of the [History API](developer.mozilla.org/en-US/docs/Web/API/History_API) to change the URL is considered a navigation.
645 646 647 |
# File 'lib/playwright_api/frame.rb', line 645 def (timeout: nil, url: nil, waitUntil: nil, &block) wrap_impl(@impl.(timeout: unwrap_impl(timeout), url: unwrap_impl(url), waitUntil: unwrap_impl(waitUntil), &wrap_block_call(block))) end |
#fill(selector, value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for an element matching selector, waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers an input event after filling. Note that you can pass an empty string to clear the input field.
If the target element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be filled instead.
To send fine-grained keyboard events, use [‘method: Frame.type`].
274 275 276 277 278 279 280 281 |
# File 'lib/playwright_api/frame.rb', line 274 def fill( selector, value, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.fill(unwrap_impl(selector), unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#focus(selector, timeout: nil) ⇒ Object
This method fetches an element with selector and focuses it. If there’s no element matching selector, the method waits until a matching element appears in the DOM.
285 286 287 |
# File 'lib/playwright_api/frame.rb', line 285 def focus(selector, timeout: nil) wrap_impl(@impl.focus(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#frame_element ⇒ Object
Returns the frame or iframe element handle which corresponds to this frame.
This is an inverse of [‘method: ElementHandle.contentFrame`]. Note that returned handle actually belongs to the parent frame.
This method throws an error if the frame has been detached before ‘frameElement()` returns.
“‘python sync frame_element = frame.frame_element() content_frame = frame_element.content_frame() assert frame == content_frame “`
301 302 303 |
# File 'lib/playwright_api/frame.rb', line 301 def frame_element wrap_impl(@impl.frame_element) end |
#get_attribute(selector, name, timeout: nil) ⇒ Object
Returns element attribute value.
306 307 308 |
# File 'lib/playwright_api/frame.rb', line 306 def get_attribute(selector, name, timeout: nil) wrap_impl(@impl.get_attribute(unwrap_impl(selector), unwrap_impl(name), timeout: unwrap_impl(timeout))) end |
#goto(url, referer: nil, timeout: nil, waitUntil: nil) ⇒ Object
Returns the main resource response. In case of multiple redirects, the navigation will resolve with the response of the last redirect.
frame.goto will throw an error if:
-
there’s an SSL error (e.g. in case of self-signed certificates).
-
target URL is invalid.
-
the
timeoutis exceeded during navigation. -
the remote server does not respond or is unreachable.
-
the main resource failed to load.
frame.goto will not throw an error when any valid HTTP status code is returned by the remote server, including 404 “Not Found” and 500 “Internal Server Error”. The status code for such responses can be retrieved by calling [‘method: Response.status`].
> NOTE: frame.goto either throws an error or returns a main resource response. The only exceptions are navigation to about:blank or navigation to the same URL with a different hash, which would succeed and return null. > NOTE: Headless mode doesn’t support navigation to a PDF document. See the [upstream issue](bugs.chromium.org/p/chromium/issues/detail?id=761295).
328 329 330 |
# File 'lib/playwright_api/frame.rb', line 328 def goto(url, referer: nil, timeout: nil, waitUntil: nil) wrap_impl(@impl.goto(unwrap_impl(url), referer: unwrap_impl(referer), timeout: unwrap_impl(timeout), waitUntil: unwrap_impl(waitUntil))) end |
#hidden?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible). selector that does not match any elements is considered hidden.
394 395 396 |
# File 'lib/playwright_api/frame.rb', line 394 def hidden?(selector, timeout: nil) wrap_impl(@impl.hidden?(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#hover(selector, force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method hovers over an element matching selector by performing the following steps:
-
Find an element matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to hover over the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
342 343 344 345 346 347 348 349 350 |
# File 'lib/playwright_api/frame.rb', line 342 def hover( selector, force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.hover(unwrap_impl(selector), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#inner_html(selector, timeout: nil) ⇒ Object
Returns element.innerHTML.
353 354 355 |
# File 'lib/playwright_api/frame.rb', line 353 def inner_html(selector, timeout: nil) wrap_impl(@impl.inner_html(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#inner_text(selector, timeout: nil) ⇒ Object
Returns element.innerText.
358 359 360 |
# File 'lib/playwright_api/frame.rb', line 358 def inner_text(selector, timeout: nil) wrap_impl(@impl.inner_text(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#input_value(selector, timeout: nil) ⇒ Object
Returns input.value for the selected ‘<input>` or `<textarea>` element. Throws for non-input elements.
363 364 365 |
# File 'lib/playwright_api/frame.rb', line 363 def input_value(selector, timeout: nil) wrap_impl(@impl.input_value(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#name ⇒ Object
Returns frame’s name attribute as specified in the tag.
If the name is empty, returns the id attribute instead.
> NOTE: This value is calculated once when the frame is created, and will not update if the attribute is changed later.
409 410 411 |
# File 'lib/playwright_api/frame.rb', line 409 def name wrap_impl(@impl.name) end |
#off(event, callback) ⇒ Object
– inherited from EventEmitter –
703 704 705 |
# File 'lib/playwright_api/frame.rb', line 703 def off(event, callback) event_emitter_proxy.off(event, callback) end |
#on(event, callback) ⇒ Object
– inherited from EventEmitter –
715 716 717 |
# File 'lib/playwright_api/frame.rb', line 715 def on(event, callback) event_emitter_proxy.on(event, callback) end |
#once(event, callback) ⇒ Object
– inherited from EventEmitter –
709 710 711 |
# File 'lib/playwright_api/frame.rb', line 709 def once(event, callback) event_emitter_proxy.once(event, callback) end |
#page ⇒ Object
Returns the page containing this frame.
414 415 416 |
# File 'lib/playwright_api/frame.rb', line 414 def page wrap_impl(@impl.page) end |
#parent_frame ⇒ Object
Parent frame, if any. Detached frames and main frames return null.
419 420 421 |
# File 'lib/playwright_api/frame.rb', line 419 def parent_frame wrap_impl(@impl.parent_frame) end |
#press(selector, key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:
F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.
Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.
Holding down Shift will type the text that corresponds to the key in the upper case.
If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.
Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When specified with the modifier, modifier is pressed and being held while the subsequent key is being pressed.
439 440 441 442 443 444 445 446 |
# File 'lib/playwright_api/frame.rb', line 439 def press( selector, key, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.press(unwrap_impl(selector), unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#query_selector(selector) ⇒ Object
Returns the ElementHandle pointing to the frame element.
The method finds an element matching the specified selector within the frame. See [Working with selectors](./selectors.md) for more details. If no elements match the selector, returns null.
452 453 454 |
# File 'lib/playwright_api/frame.rb', line 452 def query_selector(selector) wrap_impl(@impl.query_selector(unwrap_impl(selector))) end |
#query_selector_all(selector) ⇒ Object
Returns the ElementHandles pointing to the frame elements.
The method finds all elements matching the specified selector within the frame. See [Working with selectors](./selectors.md) for more details. If no elements match the selector, returns empty array.
460 461 462 |
# File 'lib/playwright_api/frame.rb', line 460 def query_selector_all(selector) wrap_impl(@impl.query_selector_all(unwrap_impl(selector))) end |
#select_option(selector, element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for an element matching selector, waits for [actionability](./actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.
If the target element is not a ‘<select>` element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be used instead.
Returns the array of option values that have been successfully selected.
Triggers a change and input event once all the provided options have been selected.
“‘python sync # single selection matching the value frame.select_option(“select#colors”, “blue”) # single selection matching both the label frame.select_option(“select#colors”, label=“blue”) # multiple selection frame.select_option(“select#colors”, value=[“red”, “green”, “blue”]) “`
483 484 485 486 487 488 489 490 491 492 493 |
# File 'lib/playwright_api/frame.rb', line 483 def select_option( selector, element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.select_option(unwrap_impl(selector), element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#set_content(html, timeout: nil, waitUntil: nil) ⇒ Object Also known as: content=
495 496 497 |
# File 'lib/playwright_api/frame.rb', line 495 def set_content(html, timeout: nil, waitUntil: nil) wrap_impl(@impl.set_content(unwrap_impl(html), timeout: unwrap_impl(timeout), waitUntil: unwrap_impl(waitUntil))) end |
#set_input_files(selector, files, noWaitAfter: nil, timeout: nil) ⇒ Object
This method expects selector to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input).
Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the the current working directory. For empty array, clears the selected files.
505 506 507 |
# File 'lib/playwright_api/frame.rb', line 505 def set_input_files(selector, files, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.set_input_files(unwrap_impl(selector), unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#tap_point(selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method taps an element matching selector by performing the following steps:
-
Find an element matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
> NOTE: ‘frame.tap()` requires that the hasTouch option of the browser context be set to true.
521 522 523 524 525 526 527 528 529 530 |
# File 'lib/playwright_api/frame.rb', line 521 def tap_point( selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.tap_point(unwrap_impl(selector), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#text_content(selector, timeout: nil) ⇒ Object
Returns element.textContent.
533 534 535 |
# File 'lib/playwright_api/frame.rb', line 533 def text_content(selector, timeout: nil) wrap_impl(@impl.text_content(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#title ⇒ Object
Returns the page title.
538 539 540 |
# File 'lib/playwright_api/frame.rb', line 538 def title wrap_impl(@impl.title) end |
#type(selector, text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Sends a keydown, keypress/input, and keyup event for each character in the text. frame.type can be used to send fine-grained keyboard events. To fill values in form fields, use [‘method: Frame.fill`].
To press a special key, like Control or ArrowDown, use [‘method: Keyboard.press`].
“‘python sync frame.type(“#mytextarea”, “hello”) # types instantly frame.type(“#mytextarea”, “world”, delay=100) # types slower, like a user “`
551 552 553 554 555 556 557 558 |
# File 'lib/playwright_api/frame.rb', line 551 def type( selector, text, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.type(unwrap_impl(selector), unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#uncheck(selector, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks an element matching selector by performing the following steps:
-
Find an element matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Ensure that matched element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.
-
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now unchecked. If not, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
573 574 575 576 577 578 579 580 581 |
# File 'lib/playwright_api/frame.rb', line 573 def uncheck( selector, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.uncheck(unwrap_impl(selector), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#url ⇒ Object
Returns frame’s url.
584 585 586 |
# File 'lib/playwright_api/frame.rb', line 584 def url wrap_impl(@impl.url) end |
#visible?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [visible](./actionability.md#visible). selector that does not match any elements is considered not visible.
400 401 402 |
# File 'lib/playwright_api/frame.rb', line 400 def visible?(selector, timeout: nil) wrap_impl(@impl.visible?(unwrap_impl(selector), timeout: unwrap_impl(timeout))) end |
#wait_for_function(expression, arg: nil, polling: nil, timeout: nil) ⇒ Object
Returns when the expression returns a truthy value, returns that value.
The [‘method: Frame.waitForFunction`] can be used to observe viewport size change:
“‘python sync from playwright.sync_api import sync_playwright
def run(playwright):
webkit = playwright.webkit
browser = webkit.launch()
page = browser.new_page()
page.evaluate("window.x = 0; setTimeout(() => { window.x = 100 }, 1000);")
page.main_frame.wait_for_function("() => window.x > 0")
browser.close()
with sync_playwright() as playwright:
run(playwright)
“‘
To pass an argument to the predicate of frame.waitForFunction function:
“‘python sync selector = “.foo” frame.wait_for_function(“selector => !!document.querySelector(selector)”, selector) “`
613 614 615 |
# File 'lib/playwright_api/frame.rb', line 613 def wait_for_function(expression, arg: nil, polling: nil, timeout: nil) wrap_impl(@impl.wait_for_function(unwrap_impl(expression), arg: unwrap_impl(arg), polling: unwrap_impl(polling), timeout: unwrap_impl(timeout))) end |
#wait_for_load_state(state: nil, timeout: nil) ⇒ Object
Waits for the required load state to be reached.
This returns when the frame reaches a required load state, load by default. The navigation must have been committed when this method is called. If current document has already reached the required state, resolves immediately.
“‘python sync frame.click(“button”) # click triggers navigation. frame.wait_for_load_state() # the promise resolves after “load” event. “`
626 627 628 |
# File 'lib/playwright_api/frame.rb', line 626 def wait_for_load_state(state: nil, timeout: nil) wrap_impl(@impl.wait_for_load_state(state: unwrap_impl(state), timeout: unwrap_impl(timeout))) end |
#wait_for_selector(selector, state: nil, timeout: nil) ⇒ Object
Returns when element specified by selector satisfies state option. Returns null if waiting for hidden or detached.
Wait for the selector to satisfy state option (either appear/disappear from dom, or become visible/hidden). If at the moment of calling the method selector already satisfies the condition, the method will return immediately. If the selector doesn’t satisfy the condition for the timeout milliseconds, the function will throw.
This method works across navigations:
“‘python sync from playwright.sync_api import sync_playwright
def run(playwright):
chromium = playwright.chromium
browser = chromium.launch()
page = browser.new_page()
for current_url in ["https://google.com", "https://bbc.com"]:
page.goto(current_url, wait_until="domcontentloaded")
element = page.main_frame.wait_for_selector("img")
print("Loaded image: " + str(element.get_attribute("src")))
browser.close()
with sync_playwright() as playwright:
run(playwright)
“‘
674 675 676 |
# File 'lib/playwright_api/frame.rb', line 674 def wait_for_selector(selector, state: nil, timeout: nil) wrap_impl(@impl.wait_for_selector(unwrap_impl(selector), state: unwrap_impl(state), timeout: unwrap_impl(timeout))) end |
#wait_for_timeout(timeout) ⇒ Object
Waits for the given timeout in milliseconds.
Note that ‘frame.waitForTimeout()` should only be used for debugging. Tests using the timer in production are going to be flaky. Use signals such as network events, selectors becoming visible and others instead.
682 683 684 |
# File 'lib/playwright_api/frame.rb', line 682 def wait_for_timeout(timeout) raise NotImplementedError.new('wait_for_timeout is not implemented yet.') end |
#wait_for_url(url, timeout: nil, waitUntil: nil) ⇒ Object
Waits for the frame to navigate to the given URL.
“‘python sync frame.click(“a.delayed-navigation”) # clicking the link will indirectly cause a navigation frame.wait_for_url(“**/target.html”) “`
692 693 694 |
# File 'lib/playwright_api/frame.rb', line 692 def wait_for_url(url, timeout: nil, waitUntil: nil) wrap_impl(@impl.wait_for_url(unwrap_impl(url), timeout: unwrap_impl(timeout), waitUntil: unwrap_impl(waitUntil))) end |