Class: Playwright::Frame
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Frame
- Defined in:
- lib/playwright_api/frame.rb
Overview
At every point of time, page exposes its current frame tree via the [‘method: Page.mainFrame`] and
- ‘method: Frame.childFrames`
-
methods.
Frame object’s lifecycle is controlled by three events, dispatched on the page object:
- ‘event: Page.frameattached`
-
fired when the frame gets attached to the page. A Frame can be attached to the page
-
only once.
- ‘event: Page.framenavigated`
-
fired when the frame commits navigation to a different URL.
-
- ‘event: Page.framedetached`
-
fired when the frame gets detached from the page. A Frame can be detached from the
-
page only once.
An example of dumping frame tree:
“‘js const { firefox } = require(’playwright’); // Or ‘chromium’ or ‘webkit’.
(async () => {
const browser = await firefox.launch();
const page = await browser.newPage();
await page.goto('https://www.google.com/chrome/browser/canary.html');
dumpFrameTree(page.mainFrame(), '');
await browser.close();
function dumpFrameTree(frame, indent) {
console.log(indent + frame.url());
for (const child of frame.childFrames()) {
dumpFrameTree(child, indent + ' ');
}
}
})(); “‘
“‘python async import asyncio from playwright.async_api import async_playwright
async def run(playwright):
firefox = playwright.firefox
browser = await firefox.launch()
page = await browser.new_page()
await page.goto("https://www.theverge.com")
dump_frame_tree(page.main_frame, "")
await browser.close()
def dump_frame_tree(frame, indent):
print(indent + frame.name + '@' + frame.url)
for child in frame.child_frames:
dump_frame_tree(child, indent + " ")
async def main():
async with async_playwright() as playwright:
await run(playwright)
asyncio.run(main()) “‘
“‘python sync from playwright.sync_api import sync_playwright
def run(playwright):
firefox = playwright.firefox
browser = firefox.launch()
page = browser.new_page()
page.goto("https://www.theverge.com")
dump_frame_tree(page.main_frame, "")
browser.close()
def dump_frame_tree(frame, indent):
print(indent + frame.name + '@' + frame.url)
for child in frame.child_frames:
dump_frame_tree(child, indent + " ")
with sync_playwright() as playwright:
run(playwright)
“‘
Instance Method Summary collapse
-
#add_script_tag(content: nil, path: nil, type: nil, url: nil) ⇒ Object
Returns the added tag when the script’s onload fires or when the script content was injected into frame.
-
#add_style_tag(content: nil, path: nil, url: nil) ⇒ Object
Returns the added tag when the stylesheet’s onload fires or when the CSS content was injected into frame.
- #after_initialize ⇒ Object
-
#check(selector, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method checks an element matching
selectorby performing the following steps: 1. -
#checked?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is checked.
- #child_frames ⇒ Object
-
#click(selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object
This method clicks an element matching
selectorby performing the following steps: 1. -
#content ⇒ Object
Gets the full HTML contents of the frame, including the doctype.
-
#dblclick(selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object
This method double clicks an element matching
selectorby performing the following steps: 1. - #detached=(req) ⇒ Object
-
#detached? ⇒ Boolean
Returns
trueif the frame has been detached, orfalseotherwise. -
#disabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).
-
#dispatch_event(selector, type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the
clickevent on the element. -
#editable?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [editable](./actionability.md#editable).
-
#enabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](./actionability.md#enabled).
-
#eval_on_selector(selector, pageFunction, arg: nil) ⇒ Object
Returns the return value of
pageFunction. -
#eval_on_selector_all(selector, pageFunction, arg: nil) ⇒ Object
Returns the return value of
pageFunction. -
#evaluate(pageFunction, arg: nil) ⇒ Object
Returns the return value of
pageFunction. -
#evaluate_handle(pageFunction, arg: nil) ⇒ Object
Returns the return value of
pageFunctionas in-page object (JSHandle). -
#expect_navigation(timeout: nil, url: nil, waitUntil: nil) ⇒ Object
Waits for the frame navigation and returns the main resource response.
-
#fill(selector, value, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for an element matching
selector, waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers aninputevent after filling. -
#focus(selector, timeout: nil) ⇒ Object
This method fetches an element with
selectorand focuses it. -
#frame_element ⇒ Object
Returns the
frameoriframeelement handle which corresponds to this frame. -
#get_attribute(selector, name, timeout: nil) ⇒ Object
Returns element attribute value.
-
#goto(url, referer: nil, timeout: nil, waitUntil: nil) ⇒ Object
Returns the main resource response.
-
#hidden?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).
-
#hover(selector, force: nil, modifiers: nil, position: nil, timeout: nil) ⇒ Object
This method hovers over an element matching
selectorby performing the following steps: 1. -
#inner_html(selector, timeout: nil) ⇒ Object
Returns
element.innerHTML. -
#inner_text(selector, timeout: nil) ⇒ Object
Returns
element.innerText. -
#name ⇒ Object
Returns frame’s name attribute as specified in the tag.
-
#off(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#on(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#once(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#page ⇒ Object
Returns the page containing this frame.
-
#parent_frame ⇒ Object
Parent frame, if any.
-
#press(selector, key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
keycan specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. -
#query_selector(selector) ⇒ Object
Returns the ElementHandle pointing to the frame element.
-
#query_selector_all(selector) ⇒ Object
Returns the ElementHandles pointing to the frame elements.
-
#select_option(selector, values, noWaitAfter: nil, timeout: nil) ⇒ Object
Returns the array of option values that have been successfully selected.
- #set_content(html, timeout: nil, waitUntil: nil) ⇒ Object (also: #content=)
-
#set_input_files(selector, files, noWaitAfter: nil, timeout: nil) ⇒ Object
This method expects
selectorto point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input). -
#tap_point(selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object
This method taps an element matching
selectorby performing the following steps: 1. -
#text_content(selector, timeout: nil) ⇒ Object
Returns
element.textContent. -
#title ⇒ Object
Returns the page title.
-
#type_text(selector, text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Sends a
keydown,keypress/input, andkeyupevent for each character in the text. -
#uncheck(selector, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method checks an element matching
selectorby performing the following steps: 1. -
#url ⇒ Object
Returns frame’s url.
-
#visible?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [visible](./actionability.md#visible).
-
#wait_for_function(pageFunction, arg: nil, polling: nil, timeout: nil) ⇒ Object
Returns when the
pageFunctionreturns a truthy value, returns that value. -
#wait_for_load_state(state: nil, timeout: nil) ⇒ Object
Waits for the required load state to be reached.
- #wait_for_navigation(timeout: nil, url: nil, waitUntil: nil, &block) ⇒ Object
-
#wait_for_selector(selector, state: nil, timeout: nil) ⇒ Object
Returns when element specified by selector satisfies
stateoption. -
#wait_for_timeout(timeout) ⇒ Object
Waits for the given
timeoutin milliseconds.
Methods inherited from PlaywrightApi
#==, from_channel_owner, #initialize
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#add_script_tag(content: nil, path: nil, type: nil, url: nil) ⇒ Object
Returns the added tag when the script’s onload fires or when the script content was injected into frame.
Adds a ‘<script>` tag into the page with the desired url or content.
157 158 159 |
# File 'lib/playwright_api/frame.rb', line 157 def add_script_tag(content: nil, path: nil, type: nil, url: nil) raise NotImplementedError.new('add_script_tag is not implemented yet.') end |
#add_style_tag(content: nil, path: nil, url: nil) ⇒ Object
Returns the added tag when the stylesheet’s onload fires or when the CSS content was injected into frame.
Adds a ‘<link rel=“stylesheet”>` tag into the page with the desired url or a `<style type=“text/css”>` tag with the content.
165 166 167 |
# File 'lib/playwright_api/frame.rb', line 165 def add_style_tag(content: nil, path: nil, url: nil) raise NotImplementedError.new('add_style_tag is not implemented yet.') end |
#after_initialize ⇒ Object
958 959 960 |
# File 'lib/playwright_api/frame.rb', line 958 def after_initialize wrap_impl(@impl.after_initialize) end |
#check(selector, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method checks an element matching selector by performing the following steps:
-
Find an element match matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Ensure that matched element is a checkbox or a radio input. If not, this method rejects. If the element is already checked, this method returns immediately.
-
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now checked. If not, this method rejects.
When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.
182 183 184 |
# File 'lib/playwright_api/frame.rb', line 182 def check(selector, force: nil, noWaitAfter: nil, timeout: nil) raise NotImplementedError.new('check is not implemented yet.') end |
#checked?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is checked. Throws if the element is not a checkbox or radio input.
535 536 537 |
# File 'lib/playwright_api/frame.rb', line 535 def checked?(selector, timeout: nil) raise NotImplementedError.new('checked? is not implemented yet.') end |
#child_frames ⇒ Object
186 187 188 |
# File 'lib/playwright_api/frame.rb', line 186 def child_frames wrap_impl(@impl.child_frames) end |
#click(selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object
This method clicks an element matching selector by performing the following steps:
-
Find an element match matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.
200 201 202 203 204 205 206 207 208 209 210 211 |
# File 'lib/playwright_api/frame.rb', line 200 def click( selector, button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) wrap_impl(@impl.click(selector, button: , clickCount: clickCount, delay: delay, force: force, modifiers: modifiers, noWaitAfter: noWaitAfter, position: position, timeout: timeout)) end |
#content ⇒ Object
Gets the full HTML contents of the frame, including the doctype.
214 215 216 |
# File 'lib/playwright_api/frame.rb', line 214 def content wrap_impl(@impl.content) end |
#dblclick(selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object
This method double clicks an element matching selector by performing the following steps:
-
Find an element match matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to double click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will reject.
When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.
> NOTE: ‘frame.dblclick()` dispatches two click events and a single dblclick event.
231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/playwright_api/frame.rb', line 231 def dblclick( selector, button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) raise NotImplementedError.new('dblclick is not implemented yet.') end |
#detached=(req) ⇒ Object
963 964 965 |
# File 'lib/playwright_api/frame.rb', line 963 def detached=(req) wrap_impl(@impl.detached=(req)) end |
#detached? ⇒ Boolean
Returns true if the frame has been detached, or false otherwise.
540 541 542 |
# File 'lib/playwright_api/frame.rb', line 540 def detached? raise NotImplementedError.new('detached? is not implemented yet.') end |
#disabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).
545 546 547 |
# File 'lib/playwright_api/frame.rb', line 545 def disabled?(selector, timeout: nil) raise NotImplementedError.new('disabled? is not implemented yet.') end |
#dispatch_event(selector, type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the click event on the element. Regardless of the visibility state of the elment, click is dispatched. This is equivalend to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).
“‘js await frame.dispatchEvent(’button#submit’, ‘click’); “‘
“‘python async await frame.dispatch_event(“button#submit”, “click”) “`
“‘python sync frame.dispatch_event(“button#submit”, “click”) “`
Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.
Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:
-
[DragEvent](developer.mozilla.org/en-US/docs/Web/API/DragEvent/DragEvent)
-
[FocusEvent](developer.mozilla.org/en-US/docs/Web/API/FocusEvent/FocusEvent)
-
[KeyboardEvent](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/KeyboardEvent)
-
[MouseEvent](developer.mozilla.org/en-US/docs/Web/API/MouseEvent/MouseEvent)
-
[PointerEvent](developer.mozilla.org/en-US/docs/Web/API/PointerEvent/PointerEvent)
-
[TouchEvent](developer.mozilla.org/en-US/docs/Web/API/TouchEvent/TouchEvent)
-
[Event](developer.mozilla.org/en-US/docs/Web/API/Event/Event)
You can also specify JSHandle as the property value if you want live objects to be passed into the event:
“‘js // Note you can only create DataTransfer in Chromium and Firefox const dataTransfer = await frame.evaluateHandle(() => new DataTransfer()); await frame.dispatchEvent(’#source’, ‘dragstart’, { dataTransfer }); “‘
“‘python async # note you can only create data_transfer in chromium and firefox data_transfer = await frame.evaluate_handle(“new DataTransfer()”) await frame.dispatch_event(“#source”, “dragstart”, { “dataTransfer”: data_transfer }) “`
“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = frame.evaluate_handle(“new DataTransfer()”) frame.dispatch_event(“#source”, “dragstart”, { “dataTransfer”: data_transfer }) “`
292 293 294 |
# File 'lib/playwright_api/frame.rb', line 292 def dispatch_event(selector, type, eventInit: nil, timeout: nil) raise NotImplementedError.new('dispatch_event is not implemented yet.') end |
#editable?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [editable](./actionability.md#editable).
550 551 552 |
# File 'lib/playwright_api/frame.rb', line 550 def editable?(selector, timeout: nil) raise NotImplementedError.new('editable? is not implemented yet.') end |
#enabled?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](./actionability.md#enabled).
555 556 557 |
# File 'lib/playwright_api/frame.rb', line 555 def enabled?(selector, timeout: nil) raise NotImplementedError.new('enabled? is not implemented yet.') end |
#eval_on_selector(selector, pageFunction, arg: nil) ⇒ Object
Returns the return value of pageFunction
The method finds an element matching the specified selector within the frame and passes it as a first argument to pageFunction. See [Working with selectors](./selectors.md#working-with-selectors) for more details. If no elements match the selector, the method throws an error.
If pageFunction returns a [Promise], then ‘frame.$eval` would wait for the promise to resolve and return its value.
Examples:
“‘js const searchValue = await frame.$eval(’#search’, el => el.value); const preloadHref = await frame.$eval(‘link’, el => el.href); const html = await frame.$eval(‘.main-container’, (e, suffix) => e.outerHTML + suffix, ‘hello’); “‘
“‘python async search_value = await frame.eval_on_selector(“#search”, “el => el.value”) preload_href = await frame.eval_on_selector(“link“, ”el => el.href“) html = await frame.eval_on_selector(”.main-container“, ”(e, suffix) => e.outerHTML + suffix“, ”hello“) “`
“‘python sync search_value = frame.eval_on_selector(“#search”, “el => el.value”) preload_href = frame.eval_on_selector(“link“, ”el => el.href“) html = frame.eval_on_selector(”.main-container“, ”(e, suffix) => e.outerHTML + suffix“, ”hello“) “`
124 125 126 |
# File 'lib/playwright_api/frame.rb', line 124 def eval_on_selector(selector, pageFunction, arg: nil) wrap_impl(@impl.eval_on_selector(selector, pageFunction, arg: arg)) end |
#eval_on_selector_all(selector, pageFunction, arg: nil) ⇒ Object
Returns the return value of pageFunction
The method finds all elements matching the specified selector within the frame and passes an array of matched elements as a first argument to pageFunction. See [Working with selectors](./selectors.md#working-with-selectors) for more details.
If pageFunction returns a [Promise], then ‘frame.$$eval` would wait for the promise to resolve and return its value.
Examples:
“‘js const divsCounts = await frame.$$eval(’div’, (divs, min) => divs.length >= min, 10); “‘
“‘python async divs_counts = await frame.eval_on_selector_all(“div”, “(divs, min) => divs.length >= min”, 10) “`
“‘python sync divs_counts = frame.eval_on_selector_all(“div”, “(divs, min) => divs.length >= min”, 10) “`
150 151 152 |
# File 'lib/playwright_api/frame.rb', line 150 def eval_on_selector_all(selector, pageFunction, arg: nil) wrap_impl(@impl.eval_on_selector_all(selector, pageFunction, arg: arg)) end |
#evaluate(pageFunction, arg: nil) ⇒ Object
Returns the return value of pageFunction
If the function passed to the [‘method: Frame.evaluate`] returns a [Promise], then [`method: Frame.evaluate`] would wait for the promise to resolve and return its value.
If the function passed to the [‘method: Frame.evaluate`] returns a non- value, then[ method: Frame.evaluate] returns undefined. DevTools Protocol also supports transferring some additional values that are not serializable by JSON: -0, NaN, Infinity, -Infinity, and bigint literals.
“‘js const result = await frame.evaluate(([x, y]) =>
return Promise.resolve(x * y);
, [7, 8]); console.log(result); // prints “56” “‘
“‘python async result = await frame.evaluate(“([x, y]) => Promise.resolve(x * y)”, [7, 8]) print(result) # prints “56” “`
“‘python sync result = frame.evaluate(“([x, y]) => Promise.resolve(x * y)”, [7, 8]) print(result) # prints “56” “`
A string can also be passed in instead of a function.
“‘js console.log(await frame.evaluate(’1 + 2’)); // prints “3” “‘
“‘python async print(await frame.evaluate(“1 + 2”)) # prints “3” x = 10 print(await frame.evaluate(f“1 + x”)) # prints “11” “`
“‘python sync print(frame.evaluate(“1 + 2”)) # prints “3” x = 10 print(frame.evaluate(f“1 + x”)) # prints “11” “`
ElementHandle instances can be passed as an argument to the [‘method: Frame.evaluate`]:
“‘js const bodyHandle = await frame.$(’body’); const html = await frame.evaluate(([body, suffix]) => body.innerHTML + suffix, [bodyHandle, ‘hello’]); await bodyHandle.dispose(); “‘
“‘python async body_handle = await frame.query_selector(“body”) html = await frame.evaluate(“([body, suffix]) => body.innerHTML + suffix”, [body_handle, “hello”]) await body_handle.dispose() “`
“‘python sync body_handle = frame.query_selector(“body”) html = frame.evaluate(“([body, suffix]) => body.innerHTML + suffix”, [body_handle, “hello”]) body_handle.dispose() “`
362 363 364 |
# File 'lib/playwright_api/frame.rb', line 362 def evaluate(pageFunction, arg: nil) wrap_impl(@impl.evaluate(pageFunction, arg: arg)) end |
#evaluate_handle(pageFunction, arg: nil) ⇒ Object
Returns the return value of pageFunction as in-page object (JSHandle).
The only difference between [‘method: Frame.evaluate`] and [`method: Frame.evaluateHandle`] is that[ method: Fframe.evaluateHandle`] returns in-page object (JSHandle).
If the function, passed to the [‘method: Frame.evaluateHandle`], returns a [Promise], then[ method: Fframe.evaluateHandle`] would wait for the promise to resolve and return its value.
“‘js const aWindowHandle = await frame.evaluateHandle(() => Promise.resolve(window)); aWindowHandle; // Handle for the window object. “`
“‘python async # FIXME a_window_handle = await frame.evaluate_handle(“Promise.resolve(window)”) a_window_handle # handle for the window object. “`
“‘python sync a_window_handle = frame.evaluate_handle(“Promise.resolve(window)”) a_window_handle # handle for the window object. “`
A string can also be passed in instead of a function.
“‘js const aHandle = await frame.evaluateHandle(’document’); // Handle for the ‘document’. “‘
“‘python async a_handle = await page.evaluate_handle(“document”) # handle for the “document” “`
“‘python sync a_handle = page.evaluate_handle(“document”) # handle for the “document” “`
JSHandle instances can be passed as an argument to the [‘method: Frame.evaluateHandle`]:
“‘js const aHandle = await frame.evaluateHandle(() => document.body); const resultHandle = await frame.evaluateHandle(([body, suffix]) => body.innerHTML + suffix, [aHandle, ’hello’]); console.log(await resultHandle.jsonValue()); await resultHandle.dispose(); “‘
“‘python async a_handle = await page.evaluate_handle(“document.body”) result_handle = await page.evaluate_handle(“body => body.innerHTML”, a_handle) print(await result_handle.json_value()) await result_handle.dispose() “`
“‘python sync a_handle = page.evaluate_handle(“document.body”) result_handle = page.evaluate_handle(“body => body.innerHTML”, a_handle) print(result_handle.json_value()) result_handle.dispose() “`
429 430 431 |
# File 'lib/playwright_api/frame.rb', line 429 def evaluate_handle(pageFunction, arg: nil) wrap_impl(@impl.evaluate_handle(pageFunction, arg: arg)) end |
#expect_navigation(timeout: nil, url: nil, waitUntil: nil) ⇒ Object
Waits for the frame navigation and returns the main resource response. In case of multiple redirects, the navigation will resolve with the response of the last redirect. In case of navigation to a different anchor or navigation due to History API usage, the navigation will resolve with null.
This method waits for the frame to navigate to a new URL. It is useful for when you run code which will indirectly cause the frame to navigate. Consider this example:
“‘js const [response] = await Promise.all([
frame.waitForNavigation(), // The promise resolves after navigation has finished
frame.click('a.delayed-navigation'), // Clicking the link will indirectly cause a navigation
]); “‘
“‘python async async with frame.expect_navigation():
await frame.click("a.delayed-navigation") # clicking the link will indirectly cause a navigation
# Resolves after navigation has finished “‘
“‘python sync with frame.expect_navigation():
frame.click("a.delayed-navigation") # clicking the link will indirectly cause a navigation
# Resolves after navigation has finished “‘
> NOTE: Usage of the [History API](developer.mozilla.org/en-US/docs/Web/API/History_API) to change the URL is considered a navigation.
875 876 877 |
# File 'lib/playwright_api/frame.rb', line 875 def (timeout: nil, url: nil, waitUntil: nil) raise NotImplementedError.new('expect_navigation is not implemented yet.') end |
#fill(selector, value, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for an element matching selector, waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers an input event after filling. If the element matching selector is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. Note that you can pass an empty string to clear the input field.
To send fine-grained keyboard events, use [‘method: Frame.type`].
439 440 441 |
# File 'lib/playwright_api/frame.rb', line 439 def fill(selector, value, noWaitAfter: nil, timeout: nil) raise NotImplementedError.new('fill is not implemented yet.') end |
#focus(selector, timeout: nil) ⇒ Object
This method fetches an element with selector and focuses it. If there’s no element matching selector, the method waits until a matching element appears in the DOM.
445 446 447 |
# File 'lib/playwright_api/frame.rb', line 445 def focus(selector, timeout: nil) wrap_impl(@impl.focus(selector, timeout: timeout)) end |
#frame_element ⇒ Object
Returns the frame or iframe element handle which corresponds to this frame.
This is an inverse of [‘method: ElementHandle.contentFrame`]. Note that returned handle actually belongs to the parent frame.
This method throws an error if the frame has been detached before ‘frameElement()` returns.
“‘js const frameElement = await frame.frameElement(); const contentFrame = await frameElement.contentFrame(); console.log(frame === contentFrame); // -> true “`
“‘python async frame_element = await frame.frame_element() content_frame = await frame_element.content_frame() assert frame == content_frame “`
“‘python sync frame_element = frame.frame_element() content_frame = frame_element.content_frame() assert frame == content_frame “`
474 475 476 |
# File 'lib/playwright_api/frame.rb', line 474 def frame_element raise NotImplementedError.new('frame_element is not implemented yet.') end |
#get_attribute(selector, name, timeout: nil) ⇒ Object
Returns element attribute value.
479 480 481 |
# File 'lib/playwright_api/frame.rb', line 479 def get_attribute(selector, name, timeout: nil) raise NotImplementedError.new('get_attribute is not implemented yet.') end |
#goto(url, referer: nil, timeout: nil, waitUntil: nil) ⇒ Object
Returns the main resource response. In case of multiple redirects, the navigation will resolve with the response of the last redirect.
frame.goto will throw an error if:
-
there’s an SSL error (e.g. in case of self-signed certificates).
-
target URL is invalid.
-
the
timeoutis exceeded during navigation. -
the remote server does not respond or is unreachable.
-
the main resource failed to load.
frame.goto will not throw an error when any valid HTTP status code is returned by the remote server, including 404 “Not Found” and 500 “Internal Server Error”. The status code for such responses can be retrieved by calling [‘method: Response.status`].
> NOTE: frame.goto either throws an error or returns a main resource response. The only exceptions are navigation to about:blank or navigation to the same URL with a different hash, which would succeed and return null. > NOTE: Headless mode doesn’t support navigation to a PDF document. See the [upstream issue](bugs.chromium.org/p/chromium/issues/detail?id=761295).
501 502 503 |
# File 'lib/playwright_api/frame.rb', line 501 def goto(url, referer: nil, timeout: nil, waitUntil: nil) wrap_impl(@impl.goto(url, referer: referer, timeout: timeout, waitUntil: waitUntil)) end |
#hidden?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).
560 561 562 |
# File 'lib/playwright_api/frame.rb', line 560 def hidden?(selector, timeout: nil) raise NotImplementedError.new('hidden? is not implemented yet.') end |
#hover(selector, force: nil, modifiers: nil, position: nil, timeout: nil) ⇒ Object
This method hovers over an element matching selector by performing the following steps:
-
Find an element match matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to hover over the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.
515 516 517 518 519 520 521 522 |
# File 'lib/playwright_api/frame.rb', line 515 def hover( selector, force: nil, modifiers: nil, position: nil, timeout: nil) raise NotImplementedError.new('hover is not implemented yet.') end |
#inner_html(selector, timeout: nil) ⇒ Object
Returns element.innerHTML.
525 526 527 |
# File 'lib/playwright_api/frame.rb', line 525 def inner_html(selector, timeout: nil) raise NotImplementedError.new('inner_html is not implemented yet.') end |
#inner_text(selector, timeout: nil) ⇒ Object
Returns element.innerText.
530 531 532 |
# File 'lib/playwright_api/frame.rb', line 530 def inner_text(selector, timeout: nil) raise NotImplementedError.new('inner_text is not implemented yet.') end |
#name ⇒ Object
Returns frame’s name attribute as specified in the tag.
If the name is empty, returns the id attribute instead.
> NOTE: This value is calculated once when the frame is created, and will not update if the attribute is changed later.
574 575 576 |
# File 'lib/playwright_api/frame.rb', line 574 def name wrap_impl(@impl.name) end |
#off(event, callback) ⇒ Object
– inherited from EventEmitter –
975 976 977 |
# File 'lib/playwright_api/frame.rb', line 975 def off(event, callback) wrap_impl(@impl.off(event, callback)) end |
#on(event, callback) ⇒ Object
– inherited from EventEmitter –
969 970 971 |
# File 'lib/playwright_api/frame.rb', line 969 def on(event, callback) wrap_impl(@impl.on(event, callback)) end |
#once(event, callback) ⇒ Object
– inherited from EventEmitter –
981 982 983 |
# File 'lib/playwright_api/frame.rb', line 981 def once(event, callback) wrap_impl(@impl.once(event, callback)) end |
#page ⇒ Object
Returns the page containing this frame.
579 580 581 |
# File 'lib/playwright_api/frame.rb', line 579 def page wrap_impl(@impl.page) end |
#parent_frame ⇒ Object
Parent frame, if any. Detached frames and main frames return null.
584 585 586 |
# File 'lib/playwright_api/frame.rb', line 584 def parent_frame wrap_impl(@impl.parent_frame) end |
#press(selector, key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:
F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.
Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.
Holding down Shift will type the text that corresponds to the key in the upper case.
If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.
Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When speficied with the modifier, modifier is pressed and being held while the subsequent key is being pressed.
604 605 606 607 608 609 610 611 |
# File 'lib/playwright_api/frame.rb', line 604 def press( selector, key, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.press(selector, key, delay: delay, noWaitAfter: noWaitAfter, timeout: timeout)) end |
#query_selector(selector) ⇒ Object
Returns the ElementHandle pointing to the frame element.
The method finds an element matching the specified selector within the frame. See [Working with selectors](./selectors.md#working-with-selectors) for more details. If no elements match the selector, returns null.
83 84 85 |
# File 'lib/playwright_api/frame.rb', line 83 def query_selector(selector) wrap_impl(@impl.query_selector(selector)) end |
#query_selector_all(selector) ⇒ Object
Returns the ElementHandles pointing to the frame elements.
The method finds all elements matching the specified selector within the frame. See [Working with selectors](./selectors.md#working-with-selectors) for more details. If no elements match the selector, returns empty array.
92 93 94 |
# File 'lib/playwright_api/frame.rb', line 92 def query_selector_all(selector) wrap_impl(@impl.query_selector_all(selector)) end |
#select_option(selector, values, noWaitAfter: nil, timeout: nil) ⇒ Object
Returns the array of option values that have been successfully selected.
Triggers a change and input event once all the provided options have been selected. If there’s no ‘<select>` element matching selector, the method throws an error.
Will wait until all specified options are present in the ‘<select>` element.
“‘js // single selection matching the value frame.selectOption(’select#colors’, ‘blue’);
// single selection matching both the value and the label frame.selectOption(‘select#colors’, { label: ‘Blue’ });
// multiple selection frame.selectOption(‘select#colors’, ‘red’, ‘green’, ‘blue’); “‘
“‘python async # single selection matching the value await frame.select_option(“select#colors”, “blue”) # single selection matching the label await frame.select_option(“select#colors”, label=“blue”) # multiple selection await frame.select_option(“select#colors”, value=[“red”, “green”, “blue”]) “`
“‘python sync # single selection matching the value frame.select_option(“select#colors”, “blue”) # single selection matching both the label frame.select_option(“select#colors”, label=“blue”) # multiple selection frame.select_option(“select#colors”, value=[“red”, “green”, “blue”]) “`
649 650 651 |
# File 'lib/playwright_api/frame.rb', line 649 def select_option(selector, values, noWaitAfter: nil, timeout: nil) raise NotImplementedError.new('select_option is not implemented yet.') end |
#set_content(html, timeout: nil, waitUntil: nil) ⇒ Object Also known as: content=
653 654 655 |
# File 'lib/playwright_api/frame.rb', line 653 def set_content(html, timeout: nil, waitUntil: nil) wrap_impl(@impl.set_content(html, timeout: timeout, waitUntil: waitUntil)) end |
#set_input_files(selector, files, noWaitAfter: nil, timeout: nil) ⇒ Object
This method expects selector to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input).
Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the the current working directory. For empty array, clears the selected files.
663 664 665 |
# File 'lib/playwright_api/frame.rb', line 663 def set_input_files(selector, files, noWaitAfter: nil, timeout: nil) raise NotImplementedError.new('set_input_files is not implemented yet.') end |
#tap_point(selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) ⇒ Object
This method taps an element matching selector by performing the following steps:
-
Find an element match matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.
> NOTE: ‘frame.tap()` requires that the hasTouch option of the browser context be set to true.
679 680 681 682 683 684 685 686 687 |
# File 'lib/playwright_api/frame.rb', line 679 def tap_point( selector, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil) raise NotImplementedError.new('tap_point is not implemented yet.') end |
#text_content(selector, timeout: nil) ⇒ Object
Returns element.textContent.
690 691 692 |
# File 'lib/playwright_api/frame.rb', line 690 def text_content(selector, timeout: nil) raise NotImplementedError.new('text_content is not implemented yet.') end |
#title ⇒ Object
Returns the page title.
695 696 697 |
# File 'lib/playwright_api/frame.rb', line 695 def title wrap_impl(@impl.title) end |
#type_text(selector, text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Sends a keydown, keypress/input, and keyup event for each character in the text. frame.type can be used to send fine-grained keyboard events. To fill values in form fields, use [‘method: Frame.fill`].
To press a special key, like Control or ArrowDown, use [‘method: Keyboard.press`].
“‘js await frame.type(’#mytextarea’, ‘Hello’); // Types instantly await frame.type(‘#mytextarea’, ‘World’, 100); // Types slower, like a user “‘
“‘python async await frame.type(“#mytextarea”, “hello”) # types instantly await frame.type(“#mytextarea”, “world”, delay=100) # types slower, like a user “`
“‘python sync frame.type(“#mytextarea”, “hello”) # types instantly frame.type(“#mytextarea”, “world”, delay=100) # types slower, like a user “`
719 720 721 722 723 724 725 726 |
# File 'lib/playwright_api/frame.rb', line 719 def type_text( selector, text, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.type_text(selector, text, delay: delay, noWaitAfter: noWaitAfter, timeout: timeout)) end |
#uncheck(selector, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method checks an element matching selector by performing the following steps:
-
Find an element match matching
selector. If there is none, wait until a matching element is attached to the DOM. -
Ensure that matched element is a checkbox or a radio input. If not, this method rejects. If the element is already unchecked, this method returns immediately.
-
Wait for [actionability](./actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now unchecked. If not, this method rejects.
When all steps combined have not finished during the specified timeout, this method rejects with a TimeoutError. Passing zero timeout disables this.
741 742 743 |
# File 'lib/playwright_api/frame.rb', line 741 def uncheck(selector, force: nil, noWaitAfter: nil, timeout: nil) raise NotImplementedError.new('uncheck is not implemented yet.') end |
#url ⇒ Object
Returns frame’s url.
746 747 748 |
# File 'lib/playwright_api/frame.rb', line 746 def url wrap_impl(@impl.url) end |
#visible?(selector, timeout: nil) ⇒ Boolean
Returns whether the element is [visible](./actionability.md#visible).
565 566 567 |
# File 'lib/playwright_api/frame.rb', line 565 def visible?(selector, timeout: nil) raise NotImplementedError.new('visible? is not implemented yet.') end |
#wait_for_function(pageFunction, arg: nil, polling: nil, timeout: nil) ⇒ Object
Returns when the pageFunction returns a truthy value, returns that value.
The waitForFunction can be used to observe viewport size change:
“‘js const { firefox } = require(’playwright’); // Or ‘chromium’ or ‘webkit’.
(async () =>
const browser = await firefox.launch();
const page = await browser.newPage();
const watchDog = page.mainFrame().waitForFunction('window.innerWidth < 100');
page.setViewportSize({width: 50, height: 50);
await watchDog;
await browser.close();
})(); “‘
“‘python async import asyncio from playwright.async_api import async_playwright
async def run(playwright):
webkit = playwright.webkit
browser = await webkit.launch()
page = await browser.new_page()
await page.evaluate("window.x = 0; setTimeout(() => { window.x = 100 }, 1000);", force_expr=True)
await page.main_frame.wait_for_function("() => window.x > 0")
await browser.close()
async def main():
async with async_playwright() as playwright:
await run(playwright)
asyncio.run(main()) “‘
“‘python sync from playwright.sync_api import sync_playwright
def run(playwright):
webkit = playwright.webkit
browser = webkit.launch()
page = browser.new_page()
page.evaluate("window.x = 0; setTimeout(() => { window.x = 100 }, 1000);", force_expr=True)
page.main_frame.wait_for_function("() => window.x > 0")
browser.close()
with sync_playwright() as playwright:
run(playwright)
“‘
To pass an argument to the predicate of frame.waitForFunction function:
“‘js const selector = ’.foo’; await frame.waitForFunction(selector => !!document.querySelector(selector), selector); “‘
“‘python async selector = “.foo” await frame.wait_for_function(“selector => !!document.querySelector(selector)”, selector) “`
“‘python sync selector = “.foo” frame.wait_for_function(“selector => !!document.querySelector(selector)”, selector) “`
818 819 820 |
# File 'lib/playwright_api/frame.rb', line 818 def wait_for_function(pageFunction, arg: nil, polling: nil, timeout: nil) raise NotImplementedError.new('wait_for_function is not implemented yet.') end |
#wait_for_load_state(state: nil, timeout: nil) ⇒ Object
Waits for the required load state to be reached.
This returns when the frame reaches a required load state, load by default. The navigation must have been committed when this method is called. If current document has already reached the required state, resolves immediately.
“‘js await frame.click(’button’); // Click triggers navigation. await frame.waitForLoadState(); // Waits for ‘load’ state by default. “‘
“‘python async await frame.click(“button”) # click triggers navigation. await frame.wait_for_load_state() # the promise resolves after “load” event. “`
“‘python sync frame.click(“button”) # click triggers navigation. frame.wait_for_load_state() # the promise resolves after “load” event. “`
842 843 844 |
# File 'lib/playwright_api/frame.rb', line 842 def wait_for_load_state(state: nil, timeout: nil) wrap_impl(@impl.wait_for_load_state(state: state, timeout: timeout)) end |
#wait_for_navigation(timeout: nil, url: nil, waitUntil: nil, &block) ⇒ Object
953 954 955 |
# File 'lib/playwright_api/frame.rb', line 953 def (timeout: nil, url: nil, waitUntil: nil, &block) wrap_impl(@impl.(timeout: timeout, url: url, waitUntil: waitUntil, &wrap_block_call(block))) end |
#wait_for_selector(selector, state: nil, timeout: nil) ⇒ Object
Returns when element specified by selector satisfies state option. Returns null if waiting for hidden or detached.
Wait for the selector to satisfy state option (either appear/disappear from dom, or become visible/hidden). If at the moment of calling the method selector already satisfies the condition, the method will return immediately. If the selector doesn’t satisfy the condition for the timeout milliseconds, the function will throw.
This method works across navigations:
“‘js const { chromium } = require(’playwright’); // Or ‘firefox’ or ‘webkit’.
(async () => {
const browser = await chromium.launch();
const page = await browser.newPage();
for (let currentURL of ['https://google.com', 'https://bbc.com']) {
await page.goto(currentURL);
const element = await page.mainFrame().waitForSelector('img');
console.log('Loaded image: ' + await element.getAttribute('src'));
}
await browser.close();
})(); “‘
“‘python async import asyncio from playwright.async_api import async_playwright
async def run(playwright):
chromium = playwright.chromium
browser = await chromium.launch()
page = await browser.new_page()
for current_url in ["https://google.com", "https://bbc.com"]:
await page.goto(current_url, wait_until="domcontentloaded")
element = await page.main_frame.wait_for_selector("img")
print("Loaded image: " + str(await element.get_attribute("src")))
await browser.close()
async def main():
async with async_playwright() as playwright:
await run(playwright)
asyncio.run(main()) “‘
“‘python sync from playwright.sync_api import sync_playwright
def run(playwright):
chromium = playwright.chromium
browser = chromium.launch()
page = browser.new_page()
for current_url in ["https://google.com", "https://bbc.com"]:
page.goto(current_url, wait_until="domcontentloaded")
element = page.main_frame.wait_for_selector("img")
print("Loaded image: " + str(element.get_attribute("src")))
browser.close()
with sync_playwright() as playwright:
run(playwright)
“‘
940 941 942 |
# File 'lib/playwright_api/frame.rb', line 940 def wait_for_selector(selector, state: nil, timeout: nil) raise NotImplementedError.new('wait_for_selector is not implemented yet.') end |
#wait_for_timeout(timeout) ⇒ Object
Waits for the given timeout in milliseconds.
Note that ‘frame.waitForTimeout()` should only be used for debugging. Tests using the timer in production are going to be flaky. Use signals such as network events, selectors becoming visible and others instead.
948 949 950 |
# File 'lib/playwright_api/frame.rb', line 948 def wait_for_timeout(timeout) raise NotImplementedError.new('wait_for_timeout is not implemented yet.') end |