Class: Playwright::Locator
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Locator
- Defined in:
- lib/playwright_api/locator.rb
Overview
Locators are the central piece of Playwright’s auto-waiting and retry-ability. In a nutshell, locators represent a way to find element(s) on the page at any moment. Locator can be created with the [‘method: Page.locator`] method.
[Learn more about locators](../locators.md).
Instance Method Summary collapse
-
#all ⇒ Object
When locator points to a list of elements, returns array of locators, pointing to respective elements.
-
#all_inner_texts ⇒ Object
Returns an array of
node.innerTextvalues for all matching nodes. -
#all_text_contents ⇒ Object
Returns an array of
node.textContentvalues for all matching nodes. -
#blur(timeout: nil) ⇒ Object
Calls [blur](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/blur) on the element.
-
#bounding_box(timeout: nil) ⇒ Object
This method returns the bounding box of the element matching the locator, or
nullif the element is not visible. -
#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Ensure that checkbox or radio element is checked.
-
#checked?(timeout: nil) ⇒ Boolean
Returns whether the element is checked.
-
#clear(force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Clear the input field.
-
#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Click an element.
-
#count ⇒ Object
Returns the number of elements matching the locator.
-
#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Double-click an element.
-
#disabled?(timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](../actionability.md#enabled).
-
#dispatch_event(type, eventInit: nil, timeout: nil) ⇒ Object
Programmatically dispatch an event on the matching element.
-
#drag_to(target, force: nil, noWaitAfter: nil, sourcePosition: nil, targetPosition: nil, timeout: nil, trial: nil) ⇒ Object
Drag the source element towards the target element and drop it.
-
#editable?(timeout: nil) ⇒ Boolean
Returns whether the element is [editable](../actionability.md#editable).
-
#element_handle(timeout: nil) ⇒ Object
Resolves given locator to the first matching DOM element.
-
#element_handles ⇒ Object
Resolves given locator to all matching DOM elements.
-
#enabled?(timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](../actionability.md#enabled).
-
#evaluate(expression, arg: nil, timeout: nil) ⇒ Object
Execute JavaScript code in the page, taking the matching element as an argument.
-
#evaluate_all(expression, arg: nil) ⇒ Object
Execute JavaScript code in the page, taking all matching elements as an argument.
-
#evaluate_handle(expression, arg: nil, timeout: nil) ⇒ Object
Execute JavaScript code in the page, taking the matching element as an argument, and return a
JSHandlewith the result. -
#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Set a value to the input field.
-
#filter(has: nil, hasNot: nil, hasNotText: nil, hasText: nil) ⇒ Object
This method narrows existing locator according to the options, for example filters by text.
-
#first ⇒ Object
Returns locator to the first matching element.
-
#focus(timeout: nil) ⇒ Object
Calls [focus](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/focus) on the matching element.
-
#frame_locator(selector) ⇒ Object
When working with iframes, you can create a frame locator that will enter the iframe and allow locating elements in that iframe:.
-
#get_attribute(name, timeout: nil) ⇒ Object
(also: #[])
Returns the matching element’s attribute value.
-
#get_by_alt_text(text, exact: nil) ⇒ Object
Allows locating elements by their alt text.
-
#get_by_label(text, exact: nil) ⇒ Object
Allows locating input elements by the text of the associated ‘<label>` or
aria-labelledbyelement, or by thearia-labelattribute. -
#get_by_placeholder(text, exact: nil) ⇒ Object
Allows locating input elements by the placeholder text.
-
#get_by_role(role, checked: nil, disabled: nil, exact: nil, expanded: nil, includeHidden: nil, level: nil, name: nil, pressed: nil, selected: nil) ⇒ Object
Allows locating elements by their [ARIA role](www.w3.org/TR/wai-aria-1.2/#roles), [ARIA attributes](www.w3.org/TR/wai-aria-1.2/#aria-attributes) and [accessible name](w3c.github.io/accname/#dfn-accessible-name).
-
#get_by_test_id(testId) ⇒ Object
Locate element by the test id.
-
#get_by_text(text, exact: nil) ⇒ Object
Allows locating elements that contain given text.
-
#get_by_title(text, exact: nil) ⇒ Object
Allows locating elements by their title attribute.
-
#hidden?(timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](../actionability.md#visible).
-
#highlight ⇒ Object
Highlight the corresponding element(s) on the screen.
-
#hover(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Hover over the matching element.
-
#inner_html(timeout: nil) ⇒ Object
Returns the [
element.innerHTML](developer.mozilla.org/en-US/docs/Web/API/Element/innerHTML). -
#inner_text(timeout: nil) ⇒ Object
Returns the [
element.innerText](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/innerText). -
#input_value(timeout: nil) ⇒ Object
Returns the value for the matching ‘<input>` or `<textarea>` or `<select>` element.
-
#last ⇒ Object
Returns locator to the last matching element.
-
#locator(selectorOrLocator, has: nil, hasNot: nil, hasNotText: nil, hasText: nil) ⇒ Object
The method finds an element matching the specified selector in the locator’s subtree.
-
#nth(index) ⇒ Object
Returns locator to the n-th matching element.
-
#or(locator) ⇒ Object
Creates a locator that matches either of the two locators.
-
#page ⇒ Object
A page this locator belongs to.
-
#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the matching element and presses a combination of the keys.
-
#screenshot(animations: nil, caret: nil, mask: nil, omitBackground: nil, path: nil, quality: nil, scale: nil, timeout: nil, type: nil) ⇒ Object
Take a screenshot of the element matching the locator.
-
#scroll_into_view_if_needed(timeout: nil) ⇒ Object
This method waits for [actionability](../actionability.md) checks, then tries to scroll element into view, unless it is completely visible as defined by [IntersectionObserver](developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API)‘s
ratio. -
#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Selects option or options in ‘<select>`.
-
#select_text(force: nil, timeout: nil) ⇒ Object
This method waits for [actionability](../actionability.md) checks, then focuses the element and selects all its text content.
-
#set_checked(checked, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
(also: #checked=)
Set the state of a checkbox or a radio element.
-
#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object
(also: #input_files=)
Upload file or multiple files into ‘<input type=file>`.
-
#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Perform a tap gesture on the element matching the locator.
-
#text_content(timeout: nil) ⇒ Object
Returns the [
node.textContent](developer.mozilla.org/en-US/docs/Web/API/Node/textContent). - #to_s ⇒ Object
-
#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then sends a
keydown,keypress/input, andkeyupevent for each character in the text. -
#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Ensure that checkbox or radio element is unchecked.
-
#visible?(timeout: nil) ⇒ Boolean
Returns whether the element is [visible](../actionability.md#visible).
-
#wait_for(state: nil, timeout: nil) ⇒ Object
Returns when element specified by locator satisfies the
stateoption.
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#all ⇒ Object
When locator points to a list of elements, returns array of locators, pointing to respective elements.
NOTE: [‘method: Locator.all`] does not wait for elements to match the locator, and instead immediately returns whatever is present in the page.
When the list of elements changes dynamically, [‘method: Locator.all`] will produce unpredictable and flaky results.
When the list of elements is stable, but loaded dynamically, wait for the full list to finish loading before calling [‘method: Locator.all`].
Usage
“‘python sync for li in page.get_by_role(’listitem’).all():
li.click();
“‘
25 26 27 |
# File 'lib/playwright_api/locator.rb', line 25 def all wrap_impl(@impl.all) end |
#all_inner_texts ⇒ Object
Returns an array of node.innerText values for all matching nodes.
Usage
“‘python sync texts = page.get_by_role(“link”).all_inner_texts() “`
37 38 39 |
# File 'lib/playwright_api/locator.rb', line 37 def all_inner_texts wrap_impl(@impl.all_inner_texts) end |
#all_text_contents ⇒ Object
Returns an array of node.textContent values for all matching nodes.
Usage
“‘python sync texts = page.get_by_role(“link”).all_text_contents() “`
49 50 51 |
# File 'lib/playwright_api/locator.rb', line 49 def all_text_contents wrap_impl(@impl.all_text_contents) end |
#blur(timeout: nil) ⇒ Object
Calls [blur](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/blur) on the element.
55 56 57 |
# File 'lib/playwright_api/locator.rb', line 55 def blur(timeout: nil) wrap_impl(@impl.blur(timeout: unwrap_impl(timeout))) end |
#bounding_box(timeout: nil) ⇒ Object
This method returns the bounding box of the element matching the locator, or null if the element is not visible. The bounding box is calculated relative to the main frame viewport - which is usually the same as the browser window.
Details
Scrolling affects the returned bounding box, similarly to [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect). That means x and/or y may be negative.
Elements from child frames return the bounding box relative to the main frame, unlike the [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect).
Assuming the page is static, it is safe to use bounding box coordinates to perform input. For example, the following snippet should click the center of the element.
Usage
“‘python sync box = page.get_by_role(“button”).bounding_box() page.mouse.click(box + box / 2, box + box / 2) “`
81 82 83 |
# File 'lib/playwright_api/locator.rb', line 81 def bounding_box(timeout: nil) wrap_impl(@impl.bounding_box(timeout: unwrap_impl(timeout))) end |
#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Ensure that checkbox or radio element is checked.
Details
Performs the following steps:
-
Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.
-
Wait for [actionability](../actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now checked. If not, this method throws.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
Usage
“‘python sync page.get_by_role(“checkbox”).check() “`
108 109 110 111 112 113 114 115 |
# File 'lib/playwright_api/locator.rb', line 108 def check( force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.check(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#checked?(timeout: nil) ⇒ Boolean
Returns whether the element is checked. Throws if the element is not a checkbox or radio input.
Usage
“‘python sync checked = page.get_by_role(“checkbox”).is_checked() “`
700 701 702 |
# File 'lib/playwright_api/locator.rb', line 700 def checked?(timeout: nil) wrap_impl(@impl.checked?(timeout: unwrap_impl(timeout))) end |
#clear(force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Clear the input field.
Details
This method waits for [actionability](../actionability.md) checks, focuses the element, clears it and triggers an input event after clearing.
If the target element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be cleared instead.
Usage
“‘python sync page.get_by_role(“textbox”).clear() “`
131 132 133 |
# File 'lib/playwright_api/locator.rb', line 131 def clear(force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.clear(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Click an element.
Details
This method clicks the element by performing the following steps:
-
Wait for [actionability](../actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
Usage
Click a button:
“‘python sync page.get_by_role(“button”).click() “`
Shift-right-click at a specific position on a canvas:
“‘python sync page.locator(“canvas”).click(
="right", modifiers=["Shift"], position={"x": 23, "y": 32}
) “‘
166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/playwright_api/locator.rb', line 166 def click( button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.click(button: unwrap_impl(), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#count ⇒ Object
Returns the number of elements matching the locator.
Usage
“‘python sync count = page.get_by_role(“listitem”).count() “`
187 188 189 |
# File 'lib/playwright_api/locator.rb', line 187 def count wrap_impl(@impl.count) end |
#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Double-click an element.
Details
This method double clicks the element by performing the following steps:
-
Wait for [actionability](../actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to double click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will throw.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
NOTE: ‘element.dblclick()` dispatches two click events and a single dblclick event.
208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/playwright_api/locator.rb', line 208 def dblclick( button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.dblclick(button: unwrap_impl(), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#disabled?(timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](../actionability.md#enabled).
Usage
“‘python sync disabled = page.get_by_role(“button”).is_disabled() “`
712 713 714 |
# File 'lib/playwright_api/locator.rb', line 712 def disabled?(timeout: nil) wrap_impl(@impl.disabled?(timeout: unwrap_impl(timeout))) end |
#dispatch_event(type, eventInit: nil, timeout: nil) ⇒ Object
Programmatically dispatch an event on the matching element.
Usage
“‘python sync locator.dispatch_event(“click”) “`
Details
The snippet above dispatches the click event on the element. Regardless of the visibility state of the element, click is dispatched. This is equivalent to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).
Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.
Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:
-
[DragEvent](developer.mozilla.org/en-US/docs/Web/API/DragEvent/DragEvent)
-
[FocusEvent](developer.mozilla.org/en-US/docs/Web/API/FocusEvent/FocusEvent)
-
[KeyboardEvent](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/KeyboardEvent)
-
[MouseEvent](developer.mozilla.org/en-US/docs/Web/API/MouseEvent/MouseEvent)
-
[PointerEvent](developer.mozilla.org/en-US/docs/Web/API/PointerEvent/PointerEvent)
-
[TouchEvent](developer.mozilla.org/en-US/docs/Web/API/TouchEvent/TouchEvent)
-
[Event](developer.mozilla.org/en-US/docs/Web/API/Event/Event)
You can also specify JSHandle as the property value if you want live objects to be passed into the event:
“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = page.evaluate_handle(“new DataTransfer()”) locator.dispatch_event(“#source”, “dragstart”, data_transfer) “`
256 257 258 |
# File 'lib/playwright_api/locator.rb', line 256 def dispatch_event(type, eventInit: nil, timeout: nil) wrap_impl(@impl.dispatch_event(unwrap_impl(type), eventInit: unwrap_impl(eventInit), timeout: unwrap_impl(timeout))) end |
#drag_to(target, force: nil, noWaitAfter: nil, sourcePosition: nil, targetPosition: nil, timeout: nil, trial: nil) ⇒ Object
Drag the source element towards the target element and drop it.
Details
This method drags the locator to another target locator or target position. It will first move to the source element, perform a mousedown, then move to the target element or position and perform a mouseup.
Usage
“‘python sync source = page.locator(“#source”) target = page.locator(“#target”)
source.drag_to(target) # or specify exact positions relative to the top-left corners of the elements: source.drag_to(
target,
source_position={"x": 34, "y": 7},
target_position={"x": 10, "y": 20}
) “‘
283 284 285 286 287 288 289 290 291 292 |
# File 'lib/playwright_api/locator.rb', line 283 def drag_to( target, force: nil, noWaitAfter: nil, sourcePosition: nil, targetPosition: nil, timeout: nil, trial: nil) wrap_impl(@impl.drag_to(unwrap_impl(target), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), sourcePosition: unwrap_impl(sourcePosition), targetPosition: unwrap_impl(targetPosition), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#editable?(timeout: nil) ⇒ Boolean
Returns whether the element is [editable](../actionability.md#editable).
Usage
“‘python sync editable = page.get_by_role(“textbox”).is_editable() “`
724 725 726 |
# File 'lib/playwright_api/locator.rb', line 724 def editable?(timeout: nil) wrap_impl(@impl.editable?(timeout: unwrap_impl(timeout))) end |
#element_handle(timeout: nil) ⇒ Object
Resolves given locator to the first matching DOM element. If there are no matching elements, waits for one. If multiple elements match the locator, throws.
296 297 298 |
# File 'lib/playwright_api/locator.rb', line 296 def element_handle(timeout: nil) wrap_impl(@impl.element_handle(timeout: unwrap_impl(timeout))) end |
#element_handles ⇒ Object
Resolves given locator to all matching DOM elements. If there are no matching elements, returns an empty list.
302 303 304 |
# File 'lib/playwright_api/locator.rb', line 302 def element_handles wrap_impl(@impl.element_handles) end |
#enabled?(timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](../actionability.md#enabled).
Usage
“‘python sync enabled = page.get_by_role(“button”).is_enabled() “`
736 737 738 |
# File 'lib/playwright_api/locator.rb', line 736 def enabled?(timeout: nil) wrap_impl(@impl.enabled?(timeout: unwrap_impl(timeout))) end |
#evaluate(expression, arg: nil, timeout: nil) ⇒ Object
Execute JavaScript code in the page, taking the matching element as an argument.
Details
Returns the return value of expression, called with the matching element as a first argument, and arg as a second argument.
If expression returns a [Promise], this method will wait for the promise to resolve and return its value.
If expression throws or rejects, this method throws.
Usage
“‘python sync tweets = page.locator(“.tweet .retweets”) assert tweets.evaluate(“node => node.innerText”) == “10 retweets” “`
323 324 325 |
# File 'lib/playwright_api/locator.rb', line 323 def evaluate(expression, arg: nil, timeout: nil) wrap_impl(@impl.evaluate(unwrap_impl(expression), arg: unwrap_impl(arg), timeout: unwrap_impl(timeout))) end |
#evaluate_all(expression, arg: nil) ⇒ Object
Execute JavaScript code in the page, taking all matching elements as an argument.
Details
Returns the return value of expression, called with an array of all matching elements as a first argument, and arg as a second argument.
If expression returns a [Promise], this method will wait for the promise to resolve and return its value.
If expression throws or rejects, this method throws.
Usage
“‘python sync locator = page.locator(“div”) more_than_ten = locator.evaluate_all(“(divs, min) => divs.length > min”, 10) “`
344 345 346 |
# File 'lib/playwright_api/locator.rb', line 344 def evaluate_all(expression, arg: nil) wrap_impl(@impl.evaluate_all(unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#evaluate_handle(expression, arg: nil, timeout: nil) ⇒ Object
Execute JavaScript code in the page, taking the matching element as an argument, and return a JSHandle with the result.
Details
Returns the return value of expression as a`JSHandle`, called with the matching element as a first argument, and arg as a second argument.
The only difference between [‘method: Locator.evaluate`] and [`method: Locator.evaluateHandle`] is that [`method: Locator.evaluateHandle`] returns JSHandle.
If expression returns a [Promise], this method will wait for the promise to resolve and return its value.
If expression throws or rejects, this method throws.
See [‘method: Page.evaluateHandle`] for more details.
362 363 364 |
# File 'lib/playwright_api/locator.rb', line 362 def evaluate_handle(expression, arg: nil, timeout: nil) wrap_impl(@impl.evaluate_handle(unwrap_impl(expression), arg: unwrap_impl(arg), timeout: unwrap_impl(timeout))) end |
#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Set a value to the input field.
Usage
“‘python sync page.get_by_role(“textbox”).fill(“example value”) “`
Details
This method waits for [actionability](../actionability.md) checks, focuses the element, fills it and triggers an input event after filling. Note that you can pass an empty string to clear the input field.
If the target element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be filled instead.
To send fine-grained keyboard events, use [‘method: Locator.type`].
382 383 384 |
# File 'lib/playwright_api/locator.rb', line 382 def fill(value, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.fill(unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#filter(has: nil, hasNot: nil, hasNotText: nil, hasText: nil) ⇒ Object
This method narrows existing locator according to the options, for example filters by text. It can be chained to filter multiple times.
Usage
“‘python sync row_locator = page.locator(“tr”) # … row_locator
.filter(has_text="text in column 1")
.filter(has=page.get_by_role("button", name="column 2 button"))
.screenshot()
“‘
400 401 402 |
# File 'lib/playwright_api/locator.rb', line 400 def filter(has: nil, hasNot: nil, hasNotText: nil, hasText: nil) wrap_impl(@impl.filter(has: unwrap_impl(has), hasNot: unwrap_impl(hasNot), hasNotText: unwrap_impl(hasNotText), hasText: unwrap_impl(hasText))) end |
#first ⇒ Object
Returns locator to the first matching element.
406 407 408 |
# File 'lib/playwright_api/locator.rb', line 406 def first wrap_impl(@impl.first) end |
#focus(timeout: nil) ⇒ Object
Calls [focus](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/focus) on the matching element.
412 413 414 |
# File 'lib/playwright_api/locator.rb', line 412 def focus(timeout: nil) wrap_impl(@impl.focus(timeout: unwrap_impl(timeout))) end |
#frame_locator(selector) ⇒ Object
When working with iframes, you can create a frame locator that will enter the iframe and allow locating elements in that iframe:
Usage
“‘python sync locator = page.frame_locator(“iframe”).get_by_text(“Submit”) locator.click() “`
426 427 428 |
# File 'lib/playwright_api/locator.rb', line 426 def frame_locator(selector) wrap_impl(@impl.frame_locator(unwrap_impl(selector))) end |
#get_attribute(name, timeout: nil) ⇒ Object Also known as: []
Returns the matching element’s attribute value.
432 433 434 |
# File 'lib/playwright_api/locator.rb', line 432 def get_attribute(name, timeout: nil) wrap_impl(@impl.get_attribute(unwrap_impl(name), timeout: unwrap_impl(timeout))) end |
#get_by_alt_text(text, exact: nil) ⇒ Object
Allows locating elements by their alt text.
Usage
For example, this method will find the image by alt text “Playwright logo”:
“‘html <img alt=’Playwright logo’> “‘
“‘python sync page.get_by_alt_text(“Playwright logo”).click() “`
451 452 453 |
# File 'lib/playwright_api/locator.rb', line 451 def get_by_alt_text(text, exact: nil) wrap_impl(@impl.get_by_alt_text(unwrap_impl(text), exact: unwrap_impl(exact))) end |
#get_by_label(text, exact: nil) ⇒ Object
Allows locating input elements by the text of the associated ‘<label>` or aria-labelledby element, or by the aria-label attribute.
Usage
For example, this method will find inputs by label “Username” and “Password” in the following DOM:
“‘html <input aria-label=“Username”> <label for=“password-input”>Password:</label> <input id=“password-input”> “`
“‘python sync page.get_by_label(“Username”).fill(“john”) page.get_by_label(“Password”).fill(“secret”) “`
472 473 474 |
# File 'lib/playwright_api/locator.rb', line 472 def get_by_label(text, exact: nil) wrap_impl(@impl.get_by_label(unwrap_impl(text), exact: unwrap_impl(exact))) end |
#get_by_placeholder(text, exact: nil) ⇒ Object
Allows locating input elements by the placeholder text.
Usage
For example, consider the following DOM structure.
“‘html <input type=“email” placeholder=“[email protected]” /> “`
You can fill the input after locating it by the placeholder text:
“‘python sync page.get_by_placeholder(“[email protected]”).fill(“[email protected]”) “`
492 493 494 |
# File 'lib/playwright_api/locator.rb', line 492 def get_by_placeholder(text, exact: nil) wrap_impl(@impl.get_by_placeholder(unwrap_impl(text), exact: unwrap_impl(exact))) end |
#get_by_role(role, checked: nil, disabled: nil, exact: nil, expanded: nil, includeHidden: nil, level: nil, name: nil, pressed: nil, selected: nil) ⇒ Object
Allows locating elements by their [ARIA role](www.w3.org/TR/wai-aria-1.2/#roles), [ARIA attributes](www.w3.org/TR/wai-aria-1.2/#aria-attributes) and [accessible name](w3c.github.io/accname/#dfn-accessible-name).
Usage
Consider the following DOM structure.
“‘html <h3>Sign up</h3> <label>
<input type="checkbox" /> Subscribe
</label> <br/> <button>Submit</button> “‘
You can locate each element by it’s implicit role:
“‘python sync expect(page.get_by_role(“heading”, name=“Sign up”)).to_be_visible()
page.get_by_role(“checkbox”, name=“Subscribe”).check()
page.get_by_role(“button”, name=re.compile(“submit”, re.IGNORECASE)).click() “‘
Details
Role selector **does not replace** accessibility audits and conformance tests, but rather gives early feedback about the ARIA guidelines.
Many html elements have an implicitly [defined role](w3c.github.io/html-aam/#html-element-role-mappings) that is recognized by the role selector. You can find all the [supported roles here](www.w3.org/TR/wai-aria-1.2/#role_definitions). ARIA guidelines **do not recommend** duplicating implicit roles and attributes by setting role and/or aria-* attributes to default values.
527 528 529 530 531 532 533 534 535 536 537 538 539 |
# File 'lib/playwright_api/locator.rb', line 527 def get_by_role( role, checked: nil, disabled: nil, exact: nil, expanded: nil, includeHidden: nil, level: nil, name: nil, pressed: nil, selected: nil) wrap_impl(@impl.get_by_role(unwrap_impl(role), checked: unwrap_impl(checked), disabled: unwrap_impl(disabled), exact: unwrap_impl(exact), expanded: unwrap_impl(), includeHidden: unwrap_impl(includeHidden), level: unwrap_impl(level), name: unwrap_impl(name), pressed: unwrap_impl(pressed), selected: unwrap_impl(selected))) end |
#get_by_test_id(testId) ⇒ Object
Locate element by the test id.
Usage
Consider the following DOM structure.
“‘html <button data-testid=“directions”>Itinéraire</button> “`
You can locate the element by it’s test id:
“‘python sync page.get_by_test_id(“directions”).click() “`
Details
By default, the data-testid attribute is used as a test id. Use [‘method: Selectors.setTestIdAttribute`] to configure a different test id attribute if necessary.
561 562 563 |
# File 'lib/playwright_api/locator.rb', line 561 def get_by_test_id(testId) wrap_impl(@impl.get_by_test_id(unwrap_impl(testId))) end |
#get_by_text(text, exact: nil) ⇒ Object
Allows locating elements that contain given text.
See also [‘method: Locator.filter`] that allows to match by another criteria, like an accessible role, and then filter by the text content.
Usage
Consider the following DOM structure:
“‘html <div>Hello <span>world</span></div> <div>Hello</div> “`
You can locate by text substring, exact string, or a regular expression:
“‘python sync # Matches <span> page.get_by_text(“world”)
# Matches first <div> page.get_by_text(“Hello world”)
# Matches second <div> page.get_by_text(“Hello”, exact=True)
# Matches both <div>s page.get_by_text(re.compile(“Hello”))
# Matches second <div> page.get_by_text(re.compile(“^hello$”, re.IGNORECASE)) “‘
Details
Matching by text always normalizes whitespace, even with exact match. For example, it turns multiple spaces into one, turns line breaks into spaces and ignores leading and trailing whitespace.
Input elements of the type button and submit are matched by their value instead of the text content. For example, locating by text ‘“Log in”` matches `<input type=button value=“Log in”>`.
603 604 605 |
# File 'lib/playwright_api/locator.rb', line 603 def get_by_text(text, exact: nil) wrap_impl(@impl.get_by_text(unwrap_impl(text), exact: unwrap_impl(exact))) end |
#get_by_title(text, exact: nil) ⇒ Object
Allows locating elements by their title attribute.
Usage
Consider the following DOM structure.
“‘html <span title=’Issues count’>25 issues</span> “‘
You can check the issues count after locating it by the title text:
“‘python sync expect(page.get_by_title(“Issues count”)).to_have_text(“25 issues”) “`
623 624 625 |
# File 'lib/playwright_api/locator.rb', line 623 def get_by_title(text, exact: nil) wrap_impl(@impl.get_by_title(unwrap_impl(text), exact: unwrap_impl(exact))) end |
#hidden?(timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](../actionability.md#visible).
Usage
“‘python sync hidden = page.get_by_role(“button”).is_hidden() “`
748 749 750 |
# File 'lib/playwright_api/locator.rb', line 748 def hidden?(timeout: nil) wrap_impl(@impl.hidden?(timeout: unwrap_impl(timeout))) end |
#highlight ⇒ Object
Highlight the corresponding element(s) on the screen. Useful for debugging, don’t commit the code that uses [‘method: Locator.highlight`].
629 630 631 |
# File 'lib/playwright_api/locator.rb', line 629 def highlight wrap_impl(@impl.highlight) end |
#hover(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Hover over the matching element.
Usage
“‘python sync page.get_by_role(“link”).hover() “`
Details
This method hovers over the element by performing the following steps:
-
Wait for [actionability](../actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to hover over the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
654 655 656 657 658 659 660 661 662 |
# File 'lib/playwright_api/locator.rb', line 654 def hover( force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.hover(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#inner_html(timeout: nil) ⇒ Object
Returns the [element.innerHTML](developer.mozilla.org/en-US/docs/Web/API/Element/innerHTML).
666 667 668 |
# File 'lib/playwright_api/locator.rb', line 666 def inner_html(timeout: nil) wrap_impl(@impl.inner_html(timeout: unwrap_impl(timeout))) end |
#inner_text(timeout: nil) ⇒ Object
Returns the [element.innerText](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/innerText).
672 673 674 |
# File 'lib/playwright_api/locator.rb', line 672 def inner_text(timeout: nil) wrap_impl(@impl.inner_text(timeout: unwrap_impl(timeout))) end |
#input_value(timeout: nil) ⇒ Object
Returns the value for the matching ‘<input>` or `<textarea>` or `<select>` element.
Usage
“‘python sync value = page.get_by_role(“textbox”).input_value() “`
Details
Throws elements that are not an input, textarea or a select. However, if the element is inside the ‘<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), returns the value of the control.
688 689 690 |
# File 'lib/playwright_api/locator.rb', line 688 def input_value(timeout: nil) wrap_impl(@impl.input_value(timeout: unwrap_impl(timeout))) end |
#last ⇒ Object
Returns locator to the last matching element.
Usage
“‘python sync banana = page.get_by_role(“listitem”).last() “`
772 773 774 |
# File 'lib/playwright_api/locator.rb', line 772 def last wrap_impl(@impl.last) end |
#locator(selectorOrLocator, has: nil, hasNot: nil, hasNotText: nil, hasText: nil) ⇒ Object
The method finds an element matching the specified selector in the locator’s subtree. It also accepts filter options, similar to [‘method: Locator.filter`] method.
[Learn more about locators](../locators.md).
780 781 782 783 784 785 786 787 |
# File 'lib/playwright_api/locator.rb', line 780 def locator( selectorOrLocator, has: nil, hasNot: nil, hasNotText: nil, hasText: nil) wrap_impl(@impl.locator(unwrap_impl(selectorOrLocator), has: unwrap_impl(has), hasNot: unwrap_impl(hasNot), hasNotText: unwrap_impl(hasNotText), hasText: unwrap_impl(hasText))) end |
#nth(index) ⇒ Object
Returns locator to the n-th matching element. It’s zero based, ‘nth(0)` selects the first element.
Usage
“‘python sync banana = page.get_by_role(“listitem”).nth(2) “`
797 798 799 |
# File 'lib/playwright_api/locator.rb', line 797 def nth(index) wrap_impl(@impl.nth(unwrap_impl(index))) end |
#or(locator) ⇒ Object
Creates a locator that matches either of the two locators.
Usage
Consider a scenario where you’d like to click on a “New email” button, but sometimes a security settings dialog shows up instead. In this case, you can wait for either a “New email” button, or a dialog and act accordingly.
“‘python sync new_email = page.get_by_role(“button”, name=“New”) dialog = page.get_by_text(“Confirm security settings”) expect(new_email.or_(dialog)).to_be_visible() if (dialog.is_visible())
page.get_by_role("button", name="Dismiss").click()
new_email.click() “‘
816 817 818 |
# File 'lib/playwright_api/locator.rb', line 816 def or(locator) wrap_impl(@impl.or(unwrap_impl(locator))) end |
#page ⇒ Object
A page this locator belongs to.
822 823 824 |
# File 'lib/playwright_api/locator.rb', line 822 def page wrap_impl(@impl.page) end |
#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the matching element and presses a combination of the keys.
Usage
“‘python sync page.get_by_role(“textbox”).press(“Backspace”) “`
Details
Focuses the element, and then uses [‘method: Keyboard.down`] and [`method: Keyboard.up`].
key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:
F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.
Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.
Holding down Shift will type the text that corresponds to the key in the upper case.
If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.
Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When specified with the modifier, modifier is pressed and being held while the subsequent key is being pressed.
856 857 858 |
# File 'lib/playwright_api/locator.rb', line 856 def press(key, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.press(unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#screenshot(animations: nil, caret: nil, mask: nil, omitBackground: nil, path: nil, quality: nil, scale: nil, timeout: nil, type: nil) ⇒ Object
Take a screenshot of the element matching the locator.
Usage
“‘python sync page.get_by_role(“link”).screenshot() “`
Disable animations and save screenshot to a file:
“‘python sync page.get_by_role(“link”).screenshot(animations=“disabled”, path=“link.png”) “`
Details
This method captures a screenshot of the page, clipped to the size and position of a particular element matching the locator. If the element is covered by other elements, it will not be actually visible on the screenshot. If the element is a scrollable container, only the currently scrolled content will be visible on the screenshot.
This method waits for the [actionability](../actionability.md) checks, then scrolls element into view before taking a screenshot. If the element is detached from DOM, the method throws an error.
Returns the buffer with the captured screenshot.
883 884 885 886 887 888 889 890 891 892 893 894 |
# File 'lib/playwright_api/locator.rb', line 883 def screenshot( animations: nil, caret: nil, mask: nil, omitBackground: nil, path: nil, quality: nil, scale: nil, timeout: nil, type: nil) wrap_impl(@impl.screenshot(animations: unwrap_impl(animations), caret: unwrap_impl(caret), mask: unwrap_impl(mask), omitBackground: unwrap_impl(omitBackground), path: unwrap_impl(path), quality: unwrap_impl(quality), scale: unwrap_impl(scale), timeout: unwrap_impl(timeout), type: unwrap_impl(type))) end |
#scroll_into_view_if_needed(timeout: nil) ⇒ Object
This method waits for [actionability](../actionability.md) checks, then tries to scroll element into view, unless it is completely visible as defined by [IntersectionObserver](developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API)‘s ratio.
900 901 902 |
# File 'lib/playwright_api/locator.rb', line 900 def scroll_into_view_if_needed(timeout: nil) wrap_impl(@impl.scroll_into_view_if_needed(timeout: unwrap_impl(timeout))) end |
#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Selects option or options in ‘<select>`.
Details
This method waits for [actionability](../actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.
If the target element is not a ‘<select>` element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be used instead.
Returns the array of option values that have been successfully selected.
Triggers a change and input event once all the provided options have been selected.
Usage
“‘html <select multiple>
<option value="red">Red</div>
<option value="green">Green</div>
<option value="blue">Blue</div>
</select> “‘
“‘python sync # single selection matching the value or label element.select_option(“blue”) # single selection matching the label element.select_option(label=“blue”) # multiple selection for blue, red and second option element.select_option(value=[“red”, “green”, “blue”]) “`
935 936 937 938 939 940 941 942 943 944 |
# File 'lib/playwright_api/locator.rb', line 935 def select_option( element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.select_option(element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#select_text(force: nil, timeout: nil) ⇒ Object
This method waits for [actionability](../actionability.md) checks, then focuses the element and selects all its text content.
If the element is inside the ‘<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), focuses and selects text in the control instead.
951 952 953 |
# File 'lib/playwright_api/locator.rb', line 951 def select_text(force: nil, timeout: nil) wrap_impl(@impl.select_text(force: unwrap_impl(force), timeout: unwrap_impl(timeout))) end |
#set_checked(checked, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object Also known as: checked=
Set the state of a checkbox or a radio element.
Usage
“‘python sync page.get_by_role(“checkbox”).set_checked(True) “`
Details
This method checks or unchecks an element by performing the following steps:
-
Ensure that matched element is a checkbox or a radio input. If not, this method throws.
-
If the element already has the right checked state, this method returns immediately.
-
Wait for [actionability](../actionability.md) checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now checked or unchecked. If not, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
977 978 979 980 981 982 983 984 985 |
# File 'lib/playwright_api/locator.rb', line 977 def set_checked( checked, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.set_checked(unwrap_impl(checked), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object Also known as: input_files=
Upload file or multiple files into ‘<input type=file>`.
Usage
“‘python sync # Select one file page.get_by_label(“Upload file”).set_input_files(’myfile.pdf’)
# Select multiple files page.get_by_label(“Upload files”).set_input_files([‘file1.txt’, ‘file2.txt’])
# Remove all the selected files page.get_by_label(“Upload file”).set_input_files([])
# Upload buffer from memory page.get_by_label(“Upload file”).set_input_files(
files=[
{"name": "test.txt", "mimeType": "text/plain", "buffer": b"this is a test"}
],
) “‘
Details
Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the current working directory. For empty array, clears the selected files.
This method expects Locator to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input). However, if the element is inside the ‘<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), targets the control instead.
1018 1019 1020 |
# File 'lib/playwright_api/locator.rb', line 1018 def set_input_files(files, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.set_input_files(unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Perform a tap gesture on the element matching the locator.
Details
This method taps the element by performing the following steps:
-
Wait for [actionability](../actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
NOTE: ‘element.tap()` requires that the hasTouch option of the browser context be set to true.
1040 1041 1042 1043 1044 1045 1046 1047 1048 |
# File 'lib/playwright_api/locator.rb', line 1040 def tap_point( force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.tap_point(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#text_content(timeout: nil) ⇒ Object
Returns the [node.textContent](developer.mozilla.org/en-US/docs/Web/API/Node/textContent).
1052 1053 1054 |
# File 'lib/playwright_api/locator.rb', line 1052 def text_content(timeout: nil) wrap_impl(@impl.text_content(timeout: unwrap_impl(timeout))) end |
#to_s ⇒ Object
1128 1129 1130 |
# File 'lib/playwright_api/locator.rb', line 1128 def to_s wrap_impl(@impl.to_s) end |
#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then sends a keydown, keypress/input, and keyup event for each character in the text.
To press a special key, like Control or ArrowDown, use [‘method: Locator.press`].
Usage
“‘python sync element.type(“hello”) # types instantly element.type(“world”, delay=100) # types slower, like a user “`
An example of typing into a text field and then submitting the form:
“‘python sync element = page.get_by_label(“Password”) element.type(“my password”) element.press(“Enter”) “`
1075 1076 1077 |
# File 'lib/playwright_api/locator.rb', line 1075 def type(text, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.type(unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
Ensure that checkbox or radio element is unchecked.
Usage
“‘python sync page.get_by_role(“checkbox”).uncheck() “`
Details
This method unchecks the element by performing the following steps:
-
Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.
-
Wait for [actionability](../actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now unchecked. If not, this method throws.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
1102 1103 1104 1105 1106 1107 1108 1109 |
# File 'lib/playwright_api/locator.rb', line 1102 def uncheck( force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.uncheck(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#visible?(timeout: nil) ⇒ Boolean
Returns whether the element is [visible](../actionability.md#visible).
Usage
“‘python sync visible = page.get_by_role(“button”).is_visible() “`
760 761 762 |
# File 'lib/playwright_api/locator.rb', line 760 def visible?(timeout: nil) wrap_impl(@impl.visible?(timeout: unwrap_impl(timeout))) end |
#wait_for(state: nil, timeout: nil) ⇒ Object
Returns when element specified by locator satisfies the state option.
If target element already satisfies the condition, the method returns immediately. Otherwise, waits for up to timeout milliseconds until the condition is met.
Usage
“‘python sync order_sent = page.locator(“#order-sent”) order_sent.wait_for() “`
1123 1124 1125 |
# File 'lib/playwright_api/locator.rb', line 1123 def wait_for(state: nil, timeout: nil) wrap_impl(@impl.wait_for(state: unwrap_impl(state), timeout: unwrap_impl(timeout))) end |