Class: Playwright::Locator
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Locator
- Defined in:
- lib/playwright_api/locator.rb
Overview
Locator represents a view to the element(s) on the page. It captures the logic sufficient to retrieve the element at any
given moment. Locator can be created with the [method: Page.locator] method.
locator = page.locator("text=Submit")
locator.click()
The difference between the Locator and ElementHandle is that the latter points to a particular element, while Locator
captures the logic of how to retrieve that element.
In the example below, handle points to a particular DOM element on page. If that element changes text or is used by React to render an entirely different component, handle is still pointing to that very DOM element. This can lead to unexpected behaviors.
handle = page.query_selector("text=Submit")
handle.hover()
handle.click()
With the locator, every time the element is used, up-to-date DOM element is located in the page using the selector. So
in the snippet below, underlying DOM element is going to be located twice.
locator = page.locator("text=Submit")
locator.hover()
locator.click()
Strictness
Locators are strict. This means that all operations on locators that imply some target DOM element will throw if more than one element matches given selector.
# Throws if there are several buttons in DOM:
page.locator('button').click()
# Works because we explicitly tell locator to pick the first element:
page.locator('button').first.click()
# Works because count knows what to do with multiple matches:
page.locator('button').count()
Instance Method Summary collapse
-
#all_inner_texts ⇒ Object
Returns an array of
node.innerTextvalues for all matching nodes. -
#all_text_contents ⇒ Object
Returns an array of
node.textContentvalues for all matching nodes. -
#bounding_box(timeout: nil) ⇒ Object
This method returns the bounding box of the element, or
nullif the element is not visible. -
#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps: 1.
-
#checked?(timeout: nil) ⇒ Boolean
Returns whether the element is checked.
-
#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method clicks the element by performing the following steps: 1.
-
#count ⇒ Object
Returns the number of elements matching given selector.
-
#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method double clicks the element by performing the following steps: 1.
-
#disabled?(timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of enabled.
-
#dispatch_event(type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the
clickevent on the element. -
#editable?(timeout: nil) ⇒ Boolean
Returns whether the element is editable.
-
#element_handle(timeout: nil) ⇒ Object
Resolves given locator to the first matching DOM element.
-
#element_handles ⇒ Object
Resolves given locator to all matching DOM elements.
-
#enabled?(timeout: nil) ⇒ Boolean
Returns whether the element is enabled.
-
#evaluate(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of
expression. -
#evaluate_all(expression, arg: nil) ⇒ Object
The method finds all elements matching the specified locator and passes an array of matched elements as a first argument to
expression. -
#evaluate_handle(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of
expressionas aJSHandle. -
#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for actionability checks, focuses the element, fills it and triggers an
inputevent after filling. -
#first ⇒ Object
Returns locator to the first matching element.
-
#focus(timeout: nil) ⇒ Object
Calls focus on the element.
-
#get_attribute(name, timeout: nil) ⇒ Object
Returns element attribute value.
-
#hidden?(timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of visible.
-
#hover(force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method hovers over the element by performing the following steps: 1.
-
#inner_html(timeout: nil) ⇒ Object
Returns the
element.innerHTML. -
#inner_text(timeout: nil) ⇒ Object
Returns the
element.innerText. -
#input_value(timeout: nil) ⇒ Object
Returns
input.valuefor<input>or<textarea>or<select>element. -
#last ⇒ Object
Returns locator to the last matching element.
-
#locator(selector) ⇒ Object
The method finds an element matching the specified selector in the
Locator's subtree. -
#nth(index) ⇒ Object
Returns locator to the n-th matching element.
-
#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then uses [
method: Keyboard.down] and [method: Keyboard.up]. -
#screenshot(omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) ⇒ Object
Returns the buffer with the captured screenshot.
-
#scroll_into_view_if_needed(timeout: nil) ⇒ Object
This method waits for actionability checks, then tries to scroll element into view, unless it is completely visible as defined by IntersectionObserver's
ratio. -
#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for actionability checks, waits until all specified options are present in the
<select>element and selects these options. -
#select_text(force: nil, timeout: nil) ⇒ Object
This method waits for actionability checks, then focuses the element and selects all its text content.
-
#set_checked(checked, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
(also: #checked=)
This method checks or unchecks an element by performing the following steps: 1.
-
#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object
(also: #input_files=)
This method expects
elementto point to an input element. -
#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method taps the element by performing the following steps: 1.
-
#text_content(timeout: nil) ⇒ Object
Returns the
node.textContent. - #to_s ⇒ Object
-
#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then sends a
keydown,keypress/input, andkeyupevent for each character in the text. -
#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps: 1.
-
#visible?(timeout: nil) ⇒ Boolean
Returns whether the element is visible.
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#all_inner_texts ⇒ Object
Returns an array of node.innerText values for all matching nodes.
50 51 52 |
# File 'lib/playwright_api/locator.rb', line 50 def all_inner_texts wrap_impl(@impl.all_inner_texts) end |
#all_text_contents ⇒ Object
Returns an array of node.textContent values for all matching nodes.
55 56 57 |
# File 'lib/playwright_api/locator.rb', line 55 def all_text_contents wrap_impl(@impl.all_text_contents) end |
#bounding_box(timeout: nil) ⇒ Object
This method returns the bounding box of the element, or null if the element is not visible. The bounding box is
calculated relative to the main frame viewport - which is usually the same as the browser window.
Scrolling affects the returned bonding box, similarly to
Element.getBoundingClientRect. That
means x and/or y may be negative.
Elements from child frames return the bounding box relative to the main frame, unlike the Element.getBoundingClientRect.
Assuming the page is static, it is safe to use bounding box coordinates to perform input. For example, the following snippet should click the center of the element.
box = element.bounding_box()
page.mouse.click(box["x"] + box["width"] / 2, box["y"] + box["height"] / 2)
76 77 78 |
# File 'lib/playwright_api/locator.rb', line 76 def bounding_box(timeout: nil) wrap_impl(@impl.bounding_box(timeout: unwrap_impl(timeout))) end |
#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps:
- Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.
- Wait for actionability checks on the element, unless
forceoption is set. - Scroll the element into view if needed.
- Use [
property: Page.mouse] to click in the center of the element. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. - Ensure that the element is now checked. If not, this method throws.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
93 94 95 96 97 98 99 100 |
# File 'lib/playwright_api/locator.rb', line 93 def check( force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.check(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#checked?(timeout: nil) ⇒ Boolean
Returns whether the element is checked. Throws if the element is not a checkbox or radio input.
307 308 309 |
# File 'lib/playwright_api/locator.rb', line 307 def checked?(timeout: nil) wrap_impl(@impl.checked?(timeout: unwrap_impl(timeout))) end |
#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method clicks the element by performing the following steps:
- Wait for actionability checks on the element, unless
forceoption is set. - Scroll the element into view if needed.
- Use [
property: Page.mouse] to click in the center of the element, or the specifiedposition. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
112 113 114 115 116 117 118 119 120 121 122 123 |
# File 'lib/playwright_api/locator.rb', line 112 def click( button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.click(button: unwrap_impl(), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#count ⇒ Object
Returns the number of elements matching given selector.
126 127 128 |
# File 'lib/playwright_api/locator.rb', line 126 def count wrap_impl(@impl.count) end |
#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method double clicks the element by performing the following steps:
- Wait for actionability checks on the element, unless
forceoption is set. - Scroll the element into view if needed.
- Use [
property: Page.mouse] to double click in the center of the element, or the specifiedposition. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. Note that if the first click of thedblclick()triggers a navigation event, this method will throw.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
NOTE:
element.dblclick()dispatches twoclickevents and a singledblclickevent.
143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/playwright_api/locator.rb', line 143 def dblclick( button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.dblclick(button: unwrap_impl(), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#disabled?(timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of enabled.
312 313 314 |
# File 'lib/playwright_api/locator.rb', line 312 def disabled?(timeout: nil) wrap_impl(@impl.disabled?(timeout: unwrap_impl(timeout))) end |
#dispatch_event(type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the click event on the element. Regardless of the visibility state of the element,
click is dispatched. This is equivalent to calling
element.click().
element.dispatch_event("click")
Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties
and dispatches it on the element. Events are composed, cancelable and bubble by default.
Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:
You can also specify JSHandle as the property value if you want live objects to be passed into the event:
# note you can only create data_transfer in chromium and firefox
data_transfer = page.evaluate_handle("new DataTransfer()")
element.dispatch_event("#source", "dragstart", {"dataTransfer": data_transfer})
182 183 184 |
# File 'lib/playwright_api/locator.rb', line 182 def dispatch_event(type, eventInit: nil, timeout: nil) wrap_impl(@impl.dispatch_event(unwrap_impl(type), eventInit: unwrap_impl(eventInit), timeout: unwrap_impl(timeout))) end |
#editable?(timeout: nil) ⇒ Boolean
Returns whether the element is editable.
317 318 319 |
# File 'lib/playwright_api/locator.rb', line 317 def editable?(timeout: nil) wrap_impl(@impl.editable?(timeout: unwrap_impl(timeout))) end |
#element_handle(timeout: nil) ⇒ Object
Resolves given locator to the first matching DOM element. If no elements matching the query are visible, waits for them up to a given timeout. If multiple elements match the selector, throws.
188 189 190 |
# File 'lib/playwright_api/locator.rb', line 188 def element_handle(timeout: nil) wrap_impl(@impl.element_handle(timeout: unwrap_impl(timeout))) end |
#element_handles ⇒ Object
Resolves given locator to all matching DOM elements.
193 194 195 |
# File 'lib/playwright_api/locator.rb', line 193 def element_handles wrap_impl(@impl.element_handles) end |
#enabled?(timeout: nil) ⇒ Boolean
Returns whether the element is enabled.
322 323 324 |
# File 'lib/playwright_api/locator.rb', line 322 def enabled?(timeout: nil) wrap_impl(@impl.enabled?(timeout: unwrap_impl(timeout))) end |
#evaluate(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of expression.
This method passes this handle as the first argument to expression.
If expression returns a [Promise], then handle.evaluate would wait for the promise to resolve and return its value.
Examples:
tweets = page.locator(".tweet .retweets")
assert tweets.evaluate("node => node.innerText") == "10 retweets"
209 210 211 |
# File 'lib/playwright_api/locator.rb', line 209 def evaluate(expression, arg: nil, timeout: nil) wrap_impl(@impl.evaluate(unwrap_impl(expression), arg: unwrap_impl(arg), timeout: unwrap_impl(timeout))) end |
#evaluate_all(expression, arg: nil) ⇒ Object
The method finds all elements matching the specified locator and passes an array of matched elements as a first argument
to expression. Returns the result of expression invocation.
If expression returns a [Promise], then [method: Locator.evaluateAll] would wait for the promise to resolve and
return its value.
Examples:
elements = page.locator("div")
div_counts = elements("(divs, min) => divs.length >= min", 10)
225 226 227 |
# File 'lib/playwright_api/locator.rb', line 225 def evaluate_all(expression, arg: nil) wrap_impl(@impl.evaluate_all(unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#evaluate_handle(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of expression as a JSHandle.
This method passes this handle as the first argument to expression.
The only difference between [method: Locator.evaluate] and [method: Locator.evaluateHandle] is that
[method: Locator.evaluateHandle] returns JSHandle.
If the function passed to the [method: Locator.evaluateHandle] returns a [Promise], then
[method: Locator.evaluateHandle] would wait for the promise to resolve and return its value.
See [method: Page.evaluateHandle] for more details.
240 241 242 |
# File 'lib/playwright_api/locator.rb', line 240 def evaluate_handle(expression, arg: nil, timeout: nil) wrap_impl(@impl.evaluate_handle(unwrap_impl(expression), arg: unwrap_impl(arg), timeout: unwrap_impl(timeout))) end |
#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for actionability checks, focuses the element, fills it and triggers an input
event after filling. Note that you can pass an empty string to clear the input field.
If the target element is not an <input>, <textarea> or [contenteditable] element, this method throws an error.
However, if the element is inside the <label> element that has an associated
control, the control will be filled
instead.
To send fine-grained keyboard events, use [method: Locator.type].
253 254 255 |
# File 'lib/playwright_api/locator.rb', line 253 def fill(value, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.fill(unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#first ⇒ Object
Returns locator to the first matching element.
258 259 260 |
# File 'lib/playwright_api/locator.rb', line 258 def first wrap_impl(@impl.first) end |
#focus(timeout: nil) ⇒ Object
Calls focus on the element.
263 264 265 |
# File 'lib/playwright_api/locator.rb', line 263 def focus(timeout: nil) wrap_impl(@impl.focus(timeout: unwrap_impl(timeout))) end |
#get_attribute(name, timeout: nil) ⇒ Object
Returns element attribute value.
268 269 270 |
# File 'lib/playwright_api/locator.rb', line 268 def get_attribute(name, timeout: nil) wrap_impl(@impl.get_attribute(unwrap_impl(name), timeout: unwrap_impl(timeout))) end |
#hidden?(timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of visible.
327 328 329 |
# File 'lib/playwright_api/locator.rb', line 327 def hidden?(timeout: nil) wrap_impl(@impl.hidden?(timeout: unwrap_impl(timeout))) end |
#hover(force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method hovers over the element by performing the following steps:
- Wait for actionability checks on the element, unless
forceoption is set. - Scroll the element into view if needed.
- Use [
property: Page.mouse] to hover over the center of the element, or the specifiedposition. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
282 283 284 285 286 287 288 289 |
# File 'lib/playwright_api/locator.rb', line 282 def hover( force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.hover(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#inner_html(timeout: nil) ⇒ Object
Returns the element.innerHTML.
292 293 294 |
# File 'lib/playwright_api/locator.rb', line 292 def inner_html(timeout: nil) wrap_impl(@impl.inner_html(timeout: unwrap_impl(timeout))) end |
#inner_text(timeout: nil) ⇒ Object
Returns the element.innerText.
297 298 299 |
# File 'lib/playwright_api/locator.rb', line 297 def inner_text(timeout: nil) wrap_impl(@impl.inner_text(timeout: unwrap_impl(timeout))) end |
#input_value(timeout: nil) ⇒ Object
Returns input.value for <input> or <textarea> or <select> element. Throws for non-input elements.
302 303 304 |
# File 'lib/playwright_api/locator.rb', line 302 def input_value(timeout: nil) wrap_impl(@impl.input_value(timeout: unwrap_impl(timeout))) end |
#last ⇒ Object
Returns locator to the last matching element.
337 338 339 |
# File 'lib/playwright_api/locator.rb', line 337 def last wrap_impl(@impl.last) end |
#locator(selector) ⇒ Object
The method finds an element matching the specified selector in the Locator's subtree. See
Working with selectors for more details.
343 344 345 |
# File 'lib/playwright_api/locator.rb', line 343 def locator(selector) wrap_impl(@impl.locator(unwrap_impl(selector))) end |
#nth(index) ⇒ Object
Returns locator to the n-th matching element.
348 349 350 |
# File 'lib/playwright_api/locator.rb', line 348 def nth(index) wrap_impl(@impl.nth(unwrap_impl(index))) end |
#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then uses [method: Keyboard.down] and [method: Keyboard.up].
key can specify the intended keyboardEvent.key
value or a single character to generate the text for. A superset of the key values can be found
here. Examples of the keys are:
F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab,
Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.
Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.
Holding down Shift will type the text that corresponds to the key in the upper case.
If key is a single character, it is case-sensitive, so the values a and A will generate different respective
texts.
Shortcuts such as key: "Control+o" or key: "Control+Shift+T" are supported as well. When specified with the
modifier, modifier is pressed and being held while the subsequent key is being pressed.
370 371 372 |
# File 'lib/playwright_api/locator.rb', line 370 def press(key, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.press(unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#screenshot(omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) ⇒ Object
Returns the buffer with the captured screenshot.
This method waits for the actionability checks, then scrolls element into view before taking a screenshot. If the element is detached from DOM, the method throws an error.
378 379 380 381 382 383 384 385 |
# File 'lib/playwright_api/locator.rb', line 378 def screenshot( omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) wrap_impl(@impl.screenshot(omitBackground: unwrap_impl(omitBackground), path: unwrap_impl(path), quality: unwrap_impl(quality), timeout: unwrap_impl(timeout), type: unwrap_impl(type))) end |
#scroll_into_view_if_needed(timeout: nil) ⇒ Object
This method waits for actionability checks, then tries to scroll element into view, unless it is
completely visible as defined by
IntersectionObserver's ratio.
390 391 392 |
# File 'lib/playwright_api/locator.rb', line 390 def scroll_into_view_if_needed(timeout: nil) wrap_impl(@impl.scroll_into_view_if_needed(timeout: unwrap_impl(timeout))) end |
#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for actionability checks, waits until all specified options are present in the
<select> element and selects these options.
If the target element is not a <select> element, this method throws an error. However, if the element is inside the
<label> element that has an associated
control, the control will be used instead.
Returns the array of option values that have been successfully selected.
Triggers a change and input event once all the provided options have been selected.
# single selection matching the value
element.select_option("blue")
# single selection matching both the label
element.select_option(label="blue")
# multiple selection
element.select_option(value=["red", "green", "blue"])
# single selection matching the value
element.select_option("blue")
# single selection matching both the value and the label
element.select_option(label="blue")
# multiple selection
element.select_option("red", "green", "blue")
# multiple selection for blue, red and second option
element.select_option(value="blue", { index: 2 }, "red")
424 425 426 427 428 429 430 431 432 433 |
# File 'lib/playwright_api/locator.rb', line 424 def select_option( element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.select_option(element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#select_text(force: nil, timeout: nil) ⇒ Object
This method waits for actionability checks, then focuses the element and selects all its text content.
437 438 439 |
# File 'lib/playwright_api/locator.rb', line 437 def select_text(force: nil, timeout: nil) wrap_impl(@impl.select_text(force: unwrap_impl(force), timeout: unwrap_impl(timeout))) end |
#set_checked(checked, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object Also known as: checked=
This method checks or unchecks an element by performing the following steps:
- Ensure that matched element is a checkbox or a radio input. If not, this method throws.
- If the element already has the right checked state, this method returns immediately.
- Wait for actionability checks on the matched element, unless
forceoption is set. If the element is detached during the checks, the whole action is retried. - Scroll the element into view if needed.
- Use [
property: Page.mouse] to click in the center of the element. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. - Ensure that the element is now checked or unchecked. If not, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
453 454 455 456 457 458 459 460 461 |
# File 'lib/playwright_api/locator.rb', line 453 def set_checked( checked, force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.set_checked(unwrap_impl(checked), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object Also known as: input_files=
This method expects element to point to an
input element.
Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they
are resolved relative to the the current working directory. For empty array, clears the selected files.
469 470 471 |
# File 'lib/playwright_api/locator.rb', line 469 def set_input_files(files, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.set_input_files(unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method taps the element by performing the following steps:
- Wait for actionability checks on the element, unless
forceoption is set. - Scroll the element into view if needed.
- Use [
property: Page.touchscreen] to tap the center of the element, or the specifiedposition. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
NOTE:
element.tap()requires that thehasTouchoption of the browser context be set to true.
486 487 488 489 490 491 492 493 494 |
# File 'lib/playwright_api/locator.rb', line 486 def tap_point( force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.tap_point(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#text_content(timeout: nil) ⇒ Object
Returns the node.textContent.
497 498 499 |
# File 'lib/playwright_api/locator.rb', line 497 def text_content(timeout: nil) wrap_impl(@impl.text_content(timeout: unwrap_impl(timeout))) end |
#to_s ⇒ Object
544 545 546 |
# File 'lib/playwright_api/locator.rb', line 544 def to_s wrap_impl(@impl.to_s) end |
#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then sends a keydown, keypress/input, and keyup event for each character in the text.
To press a special key, like Control or ArrowDown, use [method: Locator.press].
element.type("hello") # types instantly
element.type("world", delay=100) # types slower, like a user
An example of typing into a text field and then submitting the form:
element = page.locator("input")
element.type("some text")
element.press("Enter")
517 518 519 |
# File 'lib/playwright_api/locator.rb', line 517 def type(text, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.type(unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps:
- Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.
- Wait for actionability checks on the element, unless
forceoption is set. - Scroll the element into view if needed.
- Use [
property: Page.mouse] to click in the center of the element. - Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. - Ensure that the element is now unchecked. If not, this method throws.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing
zero timeout disables this.
534 535 536 537 538 539 540 541 |
# File 'lib/playwright_api/locator.rb', line 534 def uncheck( force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.uncheck(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#visible?(timeout: nil) ⇒ Boolean
Returns whether the element is visible.
332 333 334 |
# File 'lib/playwright_api/locator.rb', line 332 def visible?(timeout: nil) wrap_impl(@impl.visible?(timeout: unwrap_impl(timeout))) end |