Class: Playwright::Locator
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Locator
- Defined in:
- lib/playwright_api/locator.rb
Overview
Locator represents a view to the element(s) on the page. It captures the logic sufficient to retrieve the element at any given moment. Locator can be created with the [‘method: Page.locator`] method.
“‘python sync locator = page.locator(“text=Submit”) locator.click() “`
The difference between the Locator and ElementHandle is that the latter points to a particular element, while Locator captures the logic of how to retrieve that element.
In the example below, handle points to a particular DOM element on page. If that element changes text or is used by React to render an entirely different component, handle is still pointing to that very DOM element. This can lead to unexpected behaviors.
“‘python sync handle = page.query_selector(“text=Submit”) handle.hover() handle.click() “`
With the locator, every time the element is used, up-to-date DOM element is located in the page using the selector. So in the snippet below, underlying DOM element is going to be located twice.
“‘python sync locator = page.locator(“text=Submit”) locator.hover() locator.click() “`
Instance Method Summary collapse
-
#all_inner_texts ⇒ Object
Returns an array of
node.innerTextvalues for all matching nodes. -
#all_text_contents ⇒ Object
Returns an array of
node.textContentvalues for all matching nodes. -
#bounding_box(timeout: nil) ⇒ Object
This method returns the bounding box of the element, or
nullif the element is not visible. -
#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps: 1.
-
#checked?(timeout: nil) ⇒ Boolean
Returns whether the element is checked.
-
#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method clicks the element by performing the following steps: 1.
-
#count ⇒ Object
Returns the number of elements matching given selector.
-
#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method double clicks the element by performing the following steps: 1.
-
#disabled?(timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).
-
#dispatch_event(type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the
clickevent on the element. -
#editable?(timeout: nil) ⇒ Boolean
Returns whether the element is [editable](./actionability.md#editable).
-
#element_handle(timeout: nil) ⇒ Object
Resolves given locator to the first matching DOM element.
-
#element_handles ⇒ Object
Resolves given locator to all matching DOM elements.
-
#enabled?(timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](./actionability.md#enabled).
-
#evaluate(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of
expression. -
#evaluate_all(expression, arg: nil) ⇒ Object
The method finds all elements matching the specified locator and passes an array of matched elements as a first argument to
expression. -
#evaluate_handle(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of
expressionas aJSHandle. -
#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers an
inputevent after filling. -
#first ⇒ Object
Returns locator to the first matching element.
-
#focus(timeout: nil) ⇒ Object
Calls [focus](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/focus) on the element.
-
#get_attribute(name, timeout: nil) ⇒ Object
Returns element attribute value.
-
#hidden?(timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).
-
#hover(force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method hovers over the element by performing the following steps: 1.
-
#inner_html(timeout: nil) ⇒ Object
Returns the
element.innerHTML. -
#inner_text(timeout: nil) ⇒ Object
Returns the
element.innerText. -
#input_value(timeout: nil) ⇒ Object
Returns
input.valuefor ‘<input>` or `<textarea>` element. -
#last ⇒ Object
Returns locator to the last matching element.
-
#locator(selector) ⇒ Object
The method finds an element matching the specified selector in the
Locator‘s subtree. -
#nth(index) ⇒ Object
Returns locator to the n-th matching element.
-
#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then uses [‘method: Keyboard.down`] and [`method: Keyboard.up`].
-
#screenshot(omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) ⇒ Object
Returns the buffer with the captured screenshot.
-
#scroll_into_view_if_needed(timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, then tries to scroll element into view, unless it is completely visible as defined by [IntersectionObserver](developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API)‘s
ratio. -
#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.
-
#select_text(force: nil, timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, then focuses the element and selects all its text content.
-
#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object
(also: #input_files=)
This method expects
elementto point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input). -
#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method taps the element by performing the following steps: 1.
-
#text_content(timeout: nil) ⇒ Object
Returns the
node.textContent. - #to_s ⇒ Object
-
#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then sends a
keydown,keypress/input, andkeyupevent for each character in the text. -
#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps: 1.
-
#visible?(timeout: nil) ⇒ Boolean
Returns whether the element is [visible](./actionability.md#visible).
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#all_inner_texts ⇒ Object
Returns an array of node.innerText values for all matching nodes.
34 35 36 |
# File 'lib/playwright_api/locator.rb', line 34 def all_inner_texts wrap_impl(@impl.all_inner_texts) end |
#all_text_contents ⇒ Object
Returns an array of node.textContent values for all matching nodes.
39 40 41 |
# File 'lib/playwright_api/locator.rb', line 39 def all_text_contents wrap_impl(@impl.all_text_contents) end |
#bounding_box(timeout: nil) ⇒ Object
This method returns the bounding box of the element, or null if the element is not visible. The bounding box is calculated relative to the main frame viewport - which is usually the same as the browser window.
Scrolling affects the returned bonding box, similarly to [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect). That means x and/or y may be negative.
Elements from child frames return the bounding box relative to the main frame, unlike the [Element.getBoundingClientRect](developer.mozilla.org/en-US/docs/Web/API/Element/getBoundingClientRect).
Assuming the page is static, it is safe to use bounding box coordinates to perform input. For example, the following snippet should click the center of the element.
“‘python sync box = element.bounding_box() page.mouse.click(box + box / 2, box + box / 2) “`
60 61 62 |
# File 'lib/playwright_api/locator.rb', line 60 def bounding_box(timeout: nil) wrap_impl(@impl.bounding_box(timeout: unwrap_impl(timeout))) end |
#check(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps:
-
Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already checked, this method returns immediately.
-
Wait for [actionability](./actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now checked. If not, this method throws.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
77 78 79 80 81 82 83 84 |
# File 'lib/playwright_api/locator.rb', line 77 def check( force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.check(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#checked?(timeout: nil) ⇒ Boolean
Returns whether the element is checked. Throws if the element is not a checkbox or radio input.
291 292 293 |
# File 'lib/playwright_api/locator.rb', line 291 def checked?(timeout: nil) wrap_impl(@impl.checked?(timeout: unwrap_impl(timeout))) end |
#click(button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method clicks the element by performing the following steps:
-
Wait for [actionability](./actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
96 97 98 99 100 101 102 103 104 105 106 107 |
# File 'lib/playwright_api/locator.rb', line 96 def click( button: nil, clickCount: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.click(button: unwrap_impl(), clickCount: unwrap_impl(clickCount), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#count ⇒ Object
Returns the number of elements matching given selector.
110 111 112 |
# File 'lib/playwright_api/locator.rb', line 110 def count wrap_impl(@impl.count) end |
#dblclick(button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method double clicks the element by performing the following steps:
-
Wait for [actionability](./actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to double click in the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. Note that if the first click of the ‘dblclick()` triggers a navigation event, this method will throw.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
> NOTE: ‘element.dblclick()` dispatches two click events and a single dblclick event.
127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/playwright_api/locator.rb', line 127 def dblclick( button: nil, delay: nil, force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.dblclick(button: unwrap_impl(), delay: unwrap_impl(delay), force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#disabled?(timeout: nil) ⇒ Boolean
Returns whether the element is disabled, the opposite of [enabled](./actionability.md#enabled).
296 297 298 |
# File 'lib/playwright_api/locator.rb', line 296 def disabled?(timeout: nil) wrap_impl(@impl.disabled?(timeout: unwrap_impl(timeout))) end |
#dispatch_event(type, eventInit: nil, timeout: nil) ⇒ Object
The snippet below dispatches the click event on the element. Regardless of the visibility state of the element, click is dispatched. This is equivalent to calling [element.click()](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/click).
“‘python sync element.dispatch_event(“click”) “`
Under the hood, it creates an instance of an event based on the given type, initializes it with eventInit properties and dispatches it on the element. Events are composed, cancelable and bubble by default.
Since eventInit is event-specific, please refer to the events documentation for the lists of initial properties:
-
[DragEvent](developer.mozilla.org/en-US/docs/Web/API/DragEvent/DragEvent)
-
[FocusEvent](developer.mozilla.org/en-US/docs/Web/API/FocusEvent/FocusEvent)
-
[KeyboardEvent](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/KeyboardEvent)
-
[MouseEvent](developer.mozilla.org/en-US/docs/Web/API/MouseEvent/MouseEvent)
-
[PointerEvent](developer.mozilla.org/en-US/docs/Web/API/PointerEvent/PointerEvent)
-
[TouchEvent](developer.mozilla.org/en-US/docs/Web/API/TouchEvent/TouchEvent)
-
[Event](developer.mozilla.org/en-US/docs/Web/API/Event/Event)
You can also specify JSHandle as the property value if you want live objects to be passed into the event:
“‘python sync # note you can only create data_transfer in chromium and firefox data_transfer = page.evaluate_handle(“new DataTransfer()”) element.dispatch_event(“#source”, “dragstart”, data_transfer) “`
166 167 168 |
# File 'lib/playwright_api/locator.rb', line 166 def dispatch_event(type, eventInit: nil, timeout: nil) wrap_impl(@impl.dispatch_event(unwrap_impl(type), eventInit: unwrap_impl(eventInit), timeout: unwrap_impl(timeout))) end |
#editable?(timeout: nil) ⇒ Boolean
Returns whether the element is [editable](./actionability.md#editable).
301 302 303 |
# File 'lib/playwright_api/locator.rb', line 301 def editable?(timeout: nil) wrap_impl(@impl.editable?(timeout: unwrap_impl(timeout))) end |
#element_handle(timeout: nil) ⇒ Object
Resolves given locator to the first matching DOM element. If no elements matching the query are visible, waits for them up to a given timeout. If multiple elements match the selector, throws.
172 173 174 |
# File 'lib/playwright_api/locator.rb', line 172 def element_handle(timeout: nil) wrap_impl(@impl.element_handle(timeout: unwrap_impl(timeout))) end |
#element_handles ⇒ Object
Resolves given locator to all matching DOM elements.
177 178 179 |
# File 'lib/playwright_api/locator.rb', line 177 def element_handles wrap_impl(@impl.element_handles) end |
#enabled?(timeout: nil) ⇒ Boolean
Returns whether the element is [enabled](./actionability.md#enabled).
306 307 308 |
# File 'lib/playwright_api/locator.rb', line 306 def enabled?(timeout: nil) wrap_impl(@impl.enabled?(timeout: unwrap_impl(timeout))) end |
#evaluate(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of expression.
This method passes this handle as the first argument to expression.
If expression returns a [Promise], then handle.evaluate would wait for the promise to resolve and return its value.
Examples:
“‘python sync tweets = page.locator(“.tweet .retweets”) assert tweets.evaluate(“node => node.innerText”) == “10 retweets” “`
193 194 195 |
# File 'lib/playwright_api/locator.rb', line 193 def evaluate(expression, arg: nil, timeout: nil) wrap_impl(@impl.evaluate(unwrap_impl(expression), arg: unwrap_impl(arg), timeout: unwrap_impl(timeout))) end |
#evaluate_all(expression, arg: nil) ⇒ Object
The method finds all elements matching the specified locator and passes an array of matched elements as a first argument to expression. Returns the result of expression invocation.
If expression returns a [Promise], then [Locator.evaluateAll] would wait for the promise to resolve and return its value.
Examples:
“‘python sync elements = page.locator(“div”) div_counts = elements(“(divs, min) => divs.length >= min”, 10) “`
209 210 211 |
# File 'lib/playwright_api/locator.rb', line 209 def evaluate_all(expression, arg: nil) wrap_impl(@impl.evaluate_all(unwrap_impl(expression), arg: unwrap_impl(arg))) end |
#evaluate_handle(expression, arg: nil, timeout: nil) ⇒ Object
Returns the return value of expression as a JSHandle.
This method passes this handle as the first argument to expression.
The only difference between [‘method: Locator.evaluate`] and [`method: Locator.evaluateHandle`] is that
- ‘method: Locator.evaluateHandle`
-
returns
JSHandle.
If the function passed to the [‘method: Locator.evaluateHandle`] returns a [Promise], then
- ‘method: Locator.evaluateHandle`
-
would wait for the promise to resolve and return its value.
See [‘method: Page.evaluateHandle`] for more details.
224 225 226 |
# File 'lib/playwright_api/locator.rb', line 224 def evaluate_handle(expression, arg: nil, timeout: nil) wrap_impl(@impl.evaluate_handle(unwrap_impl(expression), arg: unwrap_impl(arg), timeout: unwrap_impl(timeout))) end |
#fill(value, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, focuses the element, fills it and triggers an input event after filling. Note that you can pass an empty string to clear the input field.
If the target element is not an ‘<input>`, `<textarea>` or [contenteditable] element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be filled instead.
To send fine-grained keyboard events, use [‘method: Locator.type`].
237 238 239 |
# File 'lib/playwright_api/locator.rb', line 237 def fill(value, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.fill(unwrap_impl(value), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#first ⇒ Object
Returns locator to the first matching element.
242 243 244 |
# File 'lib/playwright_api/locator.rb', line 242 def first wrap_impl(@impl.first) end |
#focus(timeout: nil) ⇒ Object
Calls [focus](developer.mozilla.org/en-US/docs/Web/API/HTMLElement/focus) on the element.
247 248 249 |
# File 'lib/playwright_api/locator.rb', line 247 def focus(timeout: nil) wrap_impl(@impl.focus(timeout: unwrap_impl(timeout))) end |
#get_attribute(name, timeout: nil) ⇒ Object
Returns element attribute value.
252 253 254 |
# File 'lib/playwright_api/locator.rb', line 252 def get_attribute(name, timeout: nil) wrap_impl(@impl.get_attribute(unwrap_impl(name), timeout: unwrap_impl(timeout))) end |
#hidden?(timeout: nil) ⇒ Boolean
Returns whether the element is hidden, the opposite of [visible](./actionability.md#visible).
311 312 313 |
# File 'lib/playwright_api/locator.rb', line 311 def hidden?(timeout: nil) wrap_impl(@impl.hidden?(timeout: unwrap_impl(timeout))) end |
#hover(force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method hovers over the element by performing the following steps:
-
Wait for [actionability](./actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to hover over the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
266 267 268 269 270 271 272 273 |
# File 'lib/playwright_api/locator.rb', line 266 def hover( force: nil, modifiers: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.hover(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#inner_html(timeout: nil) ⇒ Object
Returns the element.innerHTML.
276 277 278 |
# File 'lib/playwright_api/locator.rb', line 276 def inner_html(timeout: nil) wrap_impl(@impl.inner_html(timeout: unwrap_impl(timeout))) end |
#inner_text(timeout: nil) ⇒ Object
Returns the element.innerText.
281 282 283 |
# File 'lib/playwright_api/locator.rb', line 281 def inner_text(timeout: nil) wrap_impl(@impl.inner_text(timeout: unwrap_impl(timeout))) end |
#input_value(timeout: nil) ⇒ Object
Returns input.value for ‘<input>` or `<textarea>` element. Throws for non-input elements.
286 287 288 |
# File 'lib/playwright_api/locator.rb', line 286 def input_value(timeout: nil) wrap_impl(@impl.input_value(timeout: unwrap_impl(timeout))) end |
#last ⇒ Object
Returns locator to the last matching element.
321 322 323 |
# File 'lib/playwright_api/locator.rb', line 321 def last wrap_impl(@impl.last) end |
#locator(selector) ⇒ Object
The method finds an element matching the specified selector in the Locator‘s subtree. See [Working with selectors](./selectors.md) for more details.
327 328 329 |
# File 'lib/playwright_api/locator.rb', line 327 def locator(selector) wrap_impl(@impl.locator(unwrap_impl(selector))) end |
#nth(index) ⇒ Object
Returns locator to the n-th matching element.
332 333 334 |
# File 'lib/playwright_api/locator.rb', line 332 def nth(index) wrap_impl(@impl.nth(unwrap_impl(index))) end |
#press(key, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then uses [‘method: Keyboard.down`] and [`method: Keyboard.up`].
key can specify the intended [keyboardEvent.key](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key) value or a single character to generate the text for. A superset of the key values can be found [here](developer.mozilla.org/en-US/docs/Web/API/KeyboardEvent/key/Key_Values). Examples of the keys are:
F1 - F12, Digit0- Digit9, KeyA- KeyZ, Backquote, Minus, Equal, Backslash, Backspace, Tab, Delete, Escape, ArrowDown, End, Enter, Home, Insert, PageDown, PageUp, ArrowRight, ArrowUp, etc.
Following modification shortcuts are also supported: Shift, Control, Alt, Meta, ShiftLeft.
Holding down Shift will type the text that corresponds to the key in the upper case.
If key is a single character, it is case-sensitive, so the values a and A will generate different respective texts.
Shortcuts such as ‘key: “Control+o”` or `key: “Control+Shift+T”` are supported as well. When specified with the modifier, modifier is pressed and being held while the subsequent key is being pressed.
354 355 356 |
# File 'lib/playwright_api/locator.rb', line 354 def press(key, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.press(unwrap_impl(key), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#screenshot(omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) ⇒ Object
Returns the buffer with the captured screenshot.
This method waits for the [actionability](./actionability.md) checks, then scrolls element into view before taking a screenshot. If the element is detached from DOM, the method throws an error.
362 363 364 365 366 367 368 369 |
# File 'lib/playwright_api/locator.rb', line 362 def screenshot( omitBackground: nil, path: nil, quality: nil, timeout: nil, type: nil) wrap_impl(@impl.screenshot(omitBackground: unwrap_impl(omitBackground), path: unwrap_impl(path), quality: unwrap_impl(quality), timeout: unwrap_impl(timeout), type: unwrap_impl(type))) end |
#scroll_into_view_if_needed(timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, then tries to scroll element into view, unless it is completely visible as defined by [IntersectionObserver](developer.mozilla.org/en-US/docs/Web/API/Intersection_Observer_API)‘s ratio.
374 375 376 |
# File 'lib/playwright_api/locator.rb', line 374 def scroll_into_view_if_needed(timeout: nil) wrap_impl(@impl.scroll_into_view_if_needed(timeout: unwrap_impl(timeout))) end |
#select_option(element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, waits until all specified options are present in the ‘<select>` element and selects these options.
If the target element is not a ‘<select>` element, this method throws an error. However, if the element is inside the `<label>` element that has an associated [control](developer.mozilla.org/en-US/docs/Web/API/HTMLLabelElement/control), the control will be used instead.
Returns the array of option values that have been successfully selected.
Triggers a change and input event once all the provided options have been selected.
“‘python sync # single selection matching the value element.select_option(“blue”) # single selection matching both the label element.select_option(label=“blue”) # multiple selection element.select_option(value=[“red”, “green”, “blue”]) “`
“‘python sync # single selection matching the value element.select_option(“blue”) # single selection matching both the value and the label element.select_option(label=“blue”) # multiple selection element.select_option(“red”, “green”, “blue”) # multiple selection for blue, red and second option element.select_option(value=“blue”, { index: 2 }, “red”) “`
408 409 410 411 412 413 414 415 416 417 |
# File 'lib/playwright_api/locator.rb', line 408 def select_option( element: nil, index: nil, value: nil, label: nil, force: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.select_option(element: unwrap_impl(element), index: unwrap_impl(index), value: unwrap_impl(value), label: unwrap_impl(label), force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#select_text(force: nil, timeout: nil) ⇒ Object
This method waits for [actionability](./actionability.md) checks, then focuses the element and selects all its text content.
421 422 423 |
# File 'lib/playwright_api/locator.rb', line 421 def select_text(force: nil, timeout: nil) wrap_impl(@impl.select_text(force: unwrap_impl(force), timeout: unwrap_impl(timeout))) end |
#set_input_files(files, noWaitAfter: nil, timeout: nil) ⇒ Object Also known as: input_files=
This method expects element to point to an [input element](developer.mozilla.org/en-US/docs/Web/HTML/Element/input).
Sets the value of the file input to these file paths or files. If some of the filePaths are relative paths, then they are resolved relative to the the current working directory. For empty array, clears the selected files.
430 431 432 |
# File 'lib/playwright_api/locator.rb', line 430 def set_input_files(files, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.set_input_files(unwrap_impl(files), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#tap_point(force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method taps the element by performing the following steps:
-
Wait for [actionability](./actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.touchscreen`] to tap the center of the element, or the specified
position. -
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
> NOTE: ‘element.tap()` requires that the hasTouch option of the browser context be set to true.
447 448 449 450 451 452 453 454 455 |
# File 'lib/playwright_api/locator.rb', line 447 def tap_point( force: nil, modifiers: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.tap_point(force: unwrap_impl(force), modifiers: unwrap_impl(modifiers), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#text_content(timeout: nil) ⇒ Object
Returns the node.textContent.
458 459 460 |
# File 'lib/playwright_api/locator.rb', line 458 def text_content(timeout: nil) wrap_impl(@impl.text_content(timeout: unwrap_impl(timeout))) end |
#to_s ⇒ Object
505 506 507 |
# File 'lib/playwright_api/locator.rb', line 505 def to_s wrap_impl(@impl.to_s) end |
#type(text, delay: nil, noWaitAfter: nil, timeout: nil) ⇒ Object
Focuses the element, and then sends a keydown, keypress/input, and keyup event for each character in the text.
To press a special key, like Control or ArrowDown, use [‘method: Locator.press`].
“‘python sync element.type(“hello”) # types instantly element.type(“world”, delay=100) # types slower, like a user “`
An example of typing into a text field and then submitting the form:
“‘python sync element = page.locator(“input”) element.type(“some text”) element.press(“Enter”) “`
478 479 480 |
# File 'lib/playwright_api/locator.rb', line 478 def type(text, delay: nil, noWaitAfter: nil, timeout: nil) wrap_impl(@impl.type(unwrap_impl(text), delay: unwrap_impl(delay), noWaitAfter: unwrap_impl(noWaitAfter), timeout: unwrap_impl(timeout))) end |
#uncheck(force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) ⇒ Object
This method checks the element by performing the following steps:
-
Ensure that element is a checkbox or a radio input. If not, this method throws. If the element is already unchecked, this method returns immediately.
-
Wait for [actionability](./actionability.md) checks on the element, unless
forceoption is set. -
Scroll the element into view if needed.
-
Use [‘property: Page.mouse`] to click in the center of the element.
-
Wait for initiated navigations to either succeed or fail, unless
noWaitAfteroption is set. -
Ensure that the element is now unchecked. If not, this method throws.
If the element is detached from the DOM at any moment during the action, this method throws.
When all steps combined have not finished during the specified timeout, this method throws a TimeoutError. Passing zero timeout disables this.
495 496 497 498 499 500 501 502 |
# File 'lib/playwright_api/locator.rb', line 495 def uncheck( force: nil, noWaitAfter: nil, position: nil, timeout: nil, trial: nil) wrap_impl(@impl.uncheck(force: unwrap_impl(force), noWaitAfter: unwrap_impl(noWaitAfter), position: unwrap_impl(position), timeout: unwrap_impl(timeout), trial: unwrap_impl(trial))) end |
#visible?(timeout: nil) ⇒ Boolean
Returns whether the element is [visible](./actionability.md#visible).
316 317 318 |
# File 'lib/playwright_api/locator.rb', line 316 def visible?(timeout: nil) wrap_impl(@impl.visible?(timeout: unwrap_impl(timeout))) end |