Class: Playwright::Request

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/request.rb

Overview

Whenever the page sends a request for a network resource the following sequence of events are emitted by Page:

  • [event: Page.request] emitted when the request is issued by the page.
  • [event: Page.response] emitted when/if the response status and headers are received for the request.
  • [event: Page.requestFinished] emitted when the response body is downloaded and the request is complete.

If request fails at some point, then instead of 'requestfinished' event (and possibly instead of 'response' event), the [event: Page.requestFailed] event is emitted.

NOTE: HTTP Error responses, such as 404 or 503, are still successful responses from HTTP standpoint, so request will complete with 'requestfinished' event.

If request gets a 'redirect' response, the request is successfully finished with the 'requestfinished' event, and a new request is issued to a redirected url.

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#initialize, unwrap, wrap

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#all_headersObject

An object with all the request HTTP headers associated with this request. The header names are lower-cased.



18
19
20
# File 'lib/playwright_api/request.rb', line 18

def all_headers
  wrap_impl(@impl.all_headers)
end

#apply_fallback_overrides(overrides) ⇒ Object



155
156
157
# File 'lib/playwright_api/request.rb', line 155

def apply_fallback_overrides(overrides)
  wrap_impl(@impl.apply_fallback_overrides(unwrap_impl(overrides)))
end

#failureObject

The method returns null unless this request has failed, as reported by requestfailed event.

Example of logging of all the failed requests:

page.on("requestfailed", lambda request: print(request.url + " " + request.failure))


29
30
31
# File 'lib/playwright_api/request.rb', line 29

def failure
  wrap_impl(@impl.failure)
end

#frameObject

Returns the Frame that initiated this request.



34
35
36
# File 'lib/playwright_api/request.rb', line 34

def frame
  wrap_impl(@impl.frame)
end

#header_value(name) ⇒ Object

Returns the value of the header matching the name. The name is case insensitive.



52
53
54
# File 'lib/playwright_api/request.rb', line 52

def header_value(name)
  wrap_impl(@impl.header_value(unwrap_impl(name)))
end

#header_values(name) ⇒ Object



160
161
162
# File 'lib/playwright_api/request.rb', line 160

def header_values(name)
  wrap_impl(@impl.header_values(unwrap_impl(name)))
end

#headersObject

An object with the request HTTP headers. The header names are lower-cased. Note that this method does not return security-related headers, including cookie-related ones. You can use [method: Request.allHeaders] for complete list of headers that include cookie information.



41
42
43
# File 'lib/playwright_api/request.rb', line 41

def headers
  wrap_impl(@impl.headers)
end

#headers_arrayObject

An array with all the request HTTP headers associated with this request. Unlike [method: Request.allHeaders], header names are NOT lower-cased. Headers with multiple entries, such as Set-Cookie, appear in the array multiple times.



47
48
49
# File 'lib/playwright_api/request.rb', line 47

def headers_array
  wrap_impl(@impl.headers_array)
end

#methodObject

Request's method (GET, POST, etc.)



62
63
64
# File 'lib/playwright_api/request.rb', line 62

def method
  wrap_impl(@impl.method)
end

Whether this request is driving frame's navigation.

Returns:

  • (Boolean)


57
58
59
# File 'lib/playwright_api/request.rb', line 57

def navigation_request?
  wrap_impl(@impl.navigation_request?)
end

#off(event, callback) ⇒ Object

-- inherited from EventEmitter --



166
167
168
# File 'lib/playwright_api/request.rb', line 166

def off(event, callback)
  event_emitter_proxy.off(event, callback)
end

#on(event, callback) ⇒ Object

-- inherited from EventEmitter --



178
179
180
# File 'lib/playwright_api/request.rb', line 178

def on(event, callback)
  event_emitter_proxy.on(event, callback)
end

#once(event, callback) ⇒ Object

-- inherited from EventEmitter --



172
173
174
# File 'lib/playwright_api/request.rb', line 172

def once(event, callback)
  event_emitter_proxy.once(event, callback)
end

#post_dataObject

Request's post body, if any.



67
68
69
# File 'lib/playwright_api/request.rb', line 67

def post_data
  wrap_impl(@impl.post_data)
end

#post_data_bufferObject

Request's post body in a binary form, if any.



72
73
74
# File 'lib/playwright_api/request.rb', line 72

def post_data_buffer
  wrap_impl(@impl.post_data_buffer)
end

#post_data_jsonObject

Returns parsed request's body for form-urlencoded and JSON as a fallback if any.

When the response is application/x-www-form-urlencoded then a key/value object of the values will be returned. Otherwise it will be parsed as JSON.



80
81
82
# File 'lib/playwright_api/request.rb', line 80

def post_data_json
  wrap_impl(@impl.post_data_json)
end

#redirected_fromObject

Request that was redirected by the server to this one, if any.

When the server responds with a redirect, Playwright creates a new Request object. The two requests are connected by redirectedFrom() and redirectedTo() methods. When multiple server redirects has happened, it is possible to construct the whole redirect chain by repeatedly calling redirectedFrom().

For example, if the website http://example.com redirects to https://example.com:

response = page.goto("http://example.com")
print(response.request.redirected_from.url) # "http://example.com"

If the website https://google.com has no redirects:

response = page.goto("https://google.com")
print(response.request.redirected_from) # None


103
104
105
# File 'lib/playwright_api/request.rb', line 103

def redirected_from
  wrap_impl(@impl.redirected_from)
end

#redirected_toObject

New request issued by the browser if the server responded with redirect.

This method is the opposite of [method: Request.redirectedFrom]:

assert request.redirected_from.redirected_to == request


114
115
116
# File 'lib/playwright_api/request.rb', line 114

def redirected_to
  wrap_impl(@impl.redirected_to)
end

#resource_typeObject

Contains the request's resource type as it was perceived by the rendering engine. ResourceType will be one of the following: document, stylesheet, image, media, font, script, texttrack, xhr, fetch, eventsource, websocket, manifest, other.



121
122
123
# File 'lib/playwright_api/request.rb', line 121

def resource_type
  wrap_impl(@impl.resource_type)
end

#responseObject

Returns the matching Response object, or null if the response was not received due to error.



126
127
128
# File 'lib/playwright_api/request.rb', line 126

def response
  wrap_impl(@impl.response)
end

#sizesObject

Returns resource size information for given request.



131
132
133
# File 'lib/playwright_api/request.rb', line 131

def sizes
  wrap_impl(@impl.sizes)
end

#timingObject

Returns resource timing information for given request. Most of the timing values become available upon the response, responseEnd becomes available when request finishes. Find more information at Resource Timing API.

with page.expect_event("requestfinished") as request_info:
    page.goto("http://example.com")
request = request_info.value
print(request.timing)


145
146
147
# File 'lib/playwright_api/request.rb', line 145

def timing
  wrap_impl(@impl.timing)
end

#urlObject

URL of the request.



150
151
152
# File 'lib/playwright_api/request.rb', line 150

def url
  wrap_impl(@impl.url)
end