Class: Playwright::Request
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Request
- Defined in:
- lib/playwright_api/request.rb
Overview
Whenever the page sends a request for a network resource the following sequence of events are emitted by Page:
- ‘event: Page.request`
-
emitted when the request is issued by the page.
- ‘event: Page.response`
-
emitted when/if the response status and headers are received for the request.
- ‘event: Page.requestFinished`
-
emitted when the response body is downloaded and the request is complete.
If request fails at some point, then instead of ‘’requestfinished’‘ event (and possibly instead of ’response’ event), the [‘event: Page.requestFailed`] event is emitted.
> NOTE: HTTP Error responses, such as 404 or 503, are still successful responses from HTTP standpoint, so request will complete with ‘’requestfinished’‘ event.
If request gets a ‘redirect’ response, the request is successfully finished with the ‘requestfinished’ event, and a new request is issued to a redirected url.
Instance Method Summary collapse
-
#failure ⇒ Object
The method returns
nullunless this request has failed, as reported byrequestfailedevent. -
#frame ⇒ Object
Returns the
Framethat initiated this request. -
#headers ⇒ Object
An object with HTTP headers associated with the request.
-
#method ⇒ Object
Request’s method (GET, POST, etc.).
-
#navigation_request? ⇒ Boolean
Whether this request is driving frame’s navigation.
-
#off(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#on(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#once(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#post_data ⇒ Object
Request’s post body, if any.
-
#post_data_buffer ⇒ Object
Request’s post body in a binary form, if any.
-
#post_data_json ⇒ Object
Returns parsed request’s body for
form-urlencodedand JSON as a fallback if any. -
#redirected_from ⇒ Object
Request that was redirected by the server to this one, if any.
-
#redirected_to ⇒ Object
New request issued by the browser if the server responded with redirect.
-
#resource_type ⇒ Object
Contains the request’s resource type as it was perceived by the rendering engine.
-
#response ⇒ Object
Returns the matching
Responseobject, ornullif the response was not received due to error. -
#timing ⇒ Object
Returns resource timing information for given request.
-
#url ⇒ Object
URL of the request.
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#failure ⇒ Object
The method returns null unless this request has failed, as reported by requestfailed event.
Example of logging of all the failed requests:
“‘py page.on(“requestfailed”, lambda request: print(request.url + “ ” + request.failure)) “`
24 25 26 |
# File 'lib/playwright_api/request.rb', line 24 def failure wrap_impl(@impl.failure) end |
#frame ⇒ Object
Returns the Frame that initiated this request.
29 30 31 |
# File 'lib/playwright_api/request.rb', line 29 def frame wrap_impl(@impl.frame) end |
#headers ⇒ Object
An object with HTTP headers associated with the request. All header names are lower-case.
34 35 36 |
# File 'lib/playwright_api/request.rb', line 34 def headers wrap_impl(@impl.headers) end |
#method ⇒ Object
Request’s method (GET, POST, etc.)
44 45 46 |
# File 'lib/playwright_api/request.rb', line 44 def method wrap_impl(@impl.method) end |
#navigation_request? ⇒ Boolean
Whether this request is driving frame’s navigation.
39 40 41 |
# File 'lib/playwright_api/request.rb', line 39 def wrap_impl(@impl.) end |
#off(event, callback) ⇒ Object
– inherited from EventEmitter –
145 146 147 |
# File 'lib/playwright_api/request.rb', line 145 def off(event, callback) event_emitter_proxy.off(event, callback) end |
#on(event, callback) ⇒ Object
– inherited from EventEmitter –
139 140 141 |
# File 'lib/playwright_api/request.rb', line 139 def on(event, callback) event_emitter_proxy.on(event, callback) end |
#once(event, callback) ⇒ Object
– inherited from EventEmitter –
133 134 135 |
# File 'lib/playwright_api/request.rb', line 133 def once(event, callback) event_emitter_proxy.once(event, callback) end |
#post_data ⇒ Object
Request’s post body, if any.
49 50 51 |
# File 'lib/playwright_api/request.rb', line 49 def post_data wrap_impl(@impl.post_data) end |
#post_data_buffer ⇒ Object
Request’s post body in a binary form, if any.
54 55 56 |
# File 'lib/playwright_api/request.rb', line 54 def post_data_buffer wrap_impl(@impl.post_data_buffer) end |
#post_data_json ⇒ Object
Returns parsed request’s body for form-urlencoded and JSON as a fallback if any.
When the response is application/x-www-form-urlencoded then a key/value object of the values will be returned. Otherwise it will be parsed as JSON.
62 63 64 |
# File 'lib/playwright_api/request.rb', line 62 def post_data_json wrap_impl(@impl.post_data_json) end |
#redirected_from ⇒ Object
Request that was redirected by the server to this one, if any.
When the server responds with a redirect, Playwright creates a new Request object. The two requests are connected by ‘redirectedFrom()` and `redirectedTo()` methods. When multiple server redirects has happened, it is possible to construct the whole redirect chain by repeatedly calling `redirectedFrom()`.
For example, if the website http://example.com redirects to https://example.com:
“‘python sync response = page.goto(“example.com”) print(response.request.redirected_from.url) # “example.com” “`
If the website https://google.com has no redirects:
“‘python sync response = page.goto(“google.com”) print(response.request.redirected_from) # None “`
85 86 87 |
# File 'lib/playwright_api/request.rb', line 85 def redirected_from wrap_impl(@impl.redirected_from) end |
#redirected_to ⇒ Object
New request issued by the browser if the server responded with redirect.
This method is the opposite of [‘method: Request.redirectedFrom`]:
“‘py assert request.redirected_from.redirected_to == request “`
96 97 98 |
# File 'lib/playwright_api/request.rb', line 96 def redirected_to wrap_impl(@impl.redirected_to) end |
#resource_type ⇒ Object
Contains the request’s resource type as it was perceived by the rendering engine. ResourceType will be one of the following: document, stylesheet, image, media, font, script, texttrack, xhr, fetch, eventsource, websocket, manifest, other.
103 104 105 |
# File 'lib/playwright_api/request.rb', line 103 def resource_type wrap_impl(@impl.resource_type) end |
#response ⇒ Object
Returns the matching Response object, or null if the response was not received due to error.
108 109 110 |
# File 'lib/playwright_api/request.rb', line 108 def response wrap_impl(@impl.response) end |
#timing ⇒ Object
Returns resource timing information for given request. Most of the timing values become available upon the response, responseEnd becomes available when request finishes. Find more information at [Resource Timing API](developer.mozilla.org/en-US/docs/Web/API/PerformanceResourceTiming).
“‘python sync with page.expect_event(“requestfinished”) as request_info:
page.goto("http://example.com")
request = request_info.value print(request.timing) “‘
122 123 124 |
# File 'lib/playwright_api/request.rb', line 122 def timing wrap_impl(@impl.timing) end |
#url ⇒ Object
URL of the request.
127 128 129 |
# File 'lib/playwright_api/request.rb', line 127 def url wrap_impl(@impl.url) end |