Class: Playwright::Touchscreen

Inherits:
PlaywrightApi show all
Defined in:
lib/playwright_api/touchscreen.rb

Overview

The Touchscreen class operates in main-frame CSS pixels relative to the top-left corner of the viewport. Methods on the touchscreen can only be used in browser contexts that have been intialized with hasTouch set to true.

Instance Method Summary collapse

Methods inherited from PlaywrightApi

#==, from_channel_owner, #initialize

Constructor Details

This class inherits a constructor from Playwright::PlaywrightApi

Instance Method Details

#tap_point(x, y) ⇒ Object

Dispatches a touchstart and touchend event with a single touch at the position (x,y).

Raises:

  • (NotImplementedError)


7
8
9
# File 'lib/playwright_api/touchscreen.rb', line 7

def tap_point(x, y)
  raise NotImplementedError.new('tap_point is not implemented yet.')
end