Class: Playwright::Worker
- Inherits:
-
PlaywrightApi
- Object
- PlaywrightApi
- Playwright::Worker
- Defined in:
- lib/playwright_api/worker.rb
Overview
The Worker class represents a [WebWorker](developer.mozilla.org/en-US/docs/Web/API/Web_Workers_API). worker event is emitted on the page object to signal a worker creation. close event is emitted on the worker object when the worker is gone.
“‘py def handle_worker(worker):
print("worker created: " + worker.url)
worker.on("close", lambda: print("worker destroyed: " + worker.url))
page.on(‘worker’, handle_worker)
print(“current workers:”) for worker in page.workers:
print(" " + worker.url)
“‘
Instance Method Summary collapse
-
#evaluate(expression, arg: nil) ⇒ Object
Returns the return value of
expression. -
#evaluate_handle(expression, arg: nil) ⇒ Object
Returns the return value of
expressionas aJSHandle. -
#off(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#on(event, callback) ⇒ Object
– inherited from EventEmitter –.
-
#once(event, callback) ⇒ Object
– inherited from EventEmitter –.
- #url ⇒ Object
Methods inherited from PlaywrightApi
Constructor Details
This class inherits a constructor from Playwright::PlaywrightApi
Instance Method Details
#evaluate(expression, arg: nil) ⇒ Object
Returns the return value of expression.
If the function passed to the [‘method: Worker.evaluate`] returns a [Promise], then [`method: Worker.evaluate`] would wait for the promise to resolve and return its value.
If the function passed to the [‘method: Worker.evaluate`] returns a non- value, then
- ‘method: Worker.evaluate`
-
returns
undefined. Playwright also supports transferring some additional values that are
not serializable by JSON: -0, NaN, Infinity, -Infinity.
27 28 29 |
# File 'lib/playwright_api/worker.rb', line 27 def evaluate(expression, arg: nil) raise NotImplementedError.new('evaluate is not implemented yet.') end |
#evaluate_handle(expression, arg: nil) ⇒ Object
Returns the return value of expression as a JSHandle.
The only difference between [‘method: Worker.evaluate`] and [`method: Worker.evaluateHandle`] is that
- ‘method: Worker.evaluateHandle`
-
returns
JSHandle.
If the function passed to the [‘method: Worker.evaluateHandle`] returns a [Promise], then
- ‘method: Worker.evaluateHandle`
-
would wait for the promise to resolve and return its value.
38 39 40 |
# File 'lib/playwright_api/worker.rb', line 38 def evaluate_handle(expression, arg: nil) raise NotImplementedError.new('evaluate_handle is not implemented yet.') end |
#off(event, callback) ⇒ Object
– inherited from EventEmitter –
60 61 62 |
# File 'lib/playwright_api/worker.rb', line 60 def off(event, callback) event_emitter_proxy.off(event, callback) end |
#on(event, callback) ⇒ Object
– inherited from EventEmitter –
54 55 56 |
# File 'lib/playwright_api/worker.rb', line 54 def on(event, callback) event_emitter_proxy.on(event, callback) end |
#once(event, callback) ⇒ Object
– inherited from EventEmitter –
48 49 50 |
# File 'lib/playwright_api/worker.rb', line 48 def once(event, callback) event_emitter_proxy.once(event, callback) end |
#url ⇒ Object
42 43 44 |
# File 'lib/playwright_api/worker.rb', line 42 def url raise NotImplementedError.new('url is not implemented yet.') end |